@@ -46,8 +46,8 @@ func NewCmdApplyChannel(f Factory, out io.Writer) *cobra.Command {
 	var options ApplyChannelOptions
 
 	cmd := &cobra.Command{
-		Use:   "channel",
-		Short: "Apply channel",
+		Use:   "channel CHANNEL",
+		Short: "Applies updates from the given channel",
 		RunE: func(cmd *cobra.Command, args []string) error {
 			ctx := context.TODO()
 			return RunApplyChannel(ctx, f, out, &options, args)
@@ -167,13 +167,10 @@ func applyMenu(ctx context.Context, menu *channels.AddonMenu, k8sClient kubernet
 		RESTMapper: restMapper,
 	}
 
-	/*
-		applier := &channels.ClientApplier{
-			Client:     dynamicClient,
-			RESTMapper: restMapper,
-		}
-	*/
-	applier := &channels.KubectlApplier{}
+	applier := &channels.ClientApplier{
+		Client:     dynamicClient,
+		RESTMapper: restMapper,
+	}
 
 	var merr error
 
