@@ -31,7 +31,9 @@ import (
 	"github.com/google/go-containerregistry/pkg/v1/remote"
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
+	"go.uber.org/multierr"
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/util/sets"
 	"k8s.io/klog/v2"
@@ -40,7 +42,6 @@ import (
 
 	kopsbase "k8s.io/kops"
 	"k8s.io/kops/cmd/kops/util"
-	"k8s.io/kops/pkg/apis/kops"
 	api "k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/apis/kops/registry"
 	kopsutil "k8s.io/kops/pkg/apis/kops/util"
@@ -61,18 +62,18 @@ import (
 
 type CreateClusterOptions struct {
 	cloudup.NewClusterOptions
-	Yes                  bool
-	Target               string
-	MasterVolumeSize     int32
-	NodeVolumeSize       int32
-	ContainerRuntime     string
-	OutDir               string
-	DisableSubnetTags    bool
-	NetworkCIDR          string
-	DNSZone              string
-	NodeSecurityGroups   []string
-	MasterSecurityGroups []string
-	AssociatePublicIP    *bool
+	Yes                        bool
+	Target                     string
+	ControlPlaneVolumeSize     int32
+	NodeVolumeSize             int32
+	ContainerRuntime           string
+	OutDir                     string
+	DisableSubnetTags          bool
+	NetworkCIDR                string
+	DNSZone                    string
+	NodeSecurityGroups         []string
+	ControlPlaneSecurityGroups []string
+	AssociatePublicIP          *bool
 
 	// SSHPublicKeys is a map of the SSH public keys we should configure; required on AWS, not required on GCE
 	SSHPublicKeys map[string][]byte
@@ -85,12 +86,12 @@ type CreateClusterOptions struct {
 	// CloudLabels are cloud-provider-level tags for instance groups and volumes.
 	CloudLabels string
 
-	// Specify tenancy (default or dedicated) for masters and nodes
-	MasterTenancy string
-	NodeTenancy   string
+	// Specify tenancy (default or dedicated) for control-plane and worker nodes
+	ControlPlaneTenancy string
+	NodeTenancy         string
 
-	// Allow custom public master name
-	MasterPublicName string
+	// Allow custom public Kubernetes API name.
+	APIPublicName string
 
 	OpenstackNetworkID string
 
@@ -126,19 +127,19 @@ var (
 		--zones=us-east-1a \
 		--node-count=2
 
-	# Create a cluster in AWS with High Availability masters. This cluster
+	# Create a cluster in AWS with a High Availability control plane. This cluster
 	# has also been configured for private networking in a kops-managed VPC.
 	# The bastion flag is set to create an entrypoint for admins to SSH.
 	export KOPS_STATE_STORE="s3://my-state-store"
-	export MASTER_SIZE="c5.large"
+	export CONTROL_PLANE_SIZE="c5.large"
 	export NODE_SIZE="m5.large"
 	export ZONES="us-east-1a,us-east-1b,us-east-1c"
 	kops create cluster k8s-cluster.example.com \
 	    --node-count 3 \
 		--zones $ZONES \
 		--node-size $NODE_SIZE \
-		--master-size $MASTER_SIZE \
-		--master-zones $ZONES \
+		--control-plane-size $CONTROL_PLANE_SIZE \
+		--control-plane-zones $ZONES \
 		--networking cilium \
 		--topology private \
 		--bastion="true" \
@@ -150,7 +151,7 @@ var (
 	kops create cluster k8s-cluster.example.com \
 		--cloud digitalocean \
 		--zones $ZONES \
-		--master-zones $ZONES \
+		--control-plane-zones $ZONES \
 		--node-count 3 \
 		--yes
 
@@ -200,12 +201,12 @@ func NewCmdCreateCluster(f *util.Factory, out io.Writer) *cobra.Command {
 				}
 			}
 
-			return RunCreateCluster(context.TODO(), f, out, options)
+			return RunCreateCluster(cmd.Context(), f, out, options)
 		},
 	}
 
 	cmd.Flags().BoolVarP(&options.Yes, "yes", "y", options.Yes, "Specify --yes to immediately create the cluster")
-	cmd.Flags().StringVar(&options.Target, "target", options.Target, fmt.Sprintf("Valid targets: %s, %s, %s. Set this flag to %s if you want kOps to generate terraform", cloudup.TargetDirect, cloudup.TargetTerraform, cloudup.TargetCloudformation, cloudup.TargetTerraform))
+	cmd.Flags().StringVar(&options.Target, "target", options.Target, fmt.Sprintf("Valid targets: %s, %s. Set this flag to %s if you want kOps to generate terraform", cloudup.TargetDirect, cloudup.TargetTerraform, cloudup.TargetTerraform))
 	cmd.RegisterFlagCompletionFunc("target", completeCreateClusterTarget(options))
 
 	// Configuration / state location
@@ -236,18 +237,21 @@ func NewCmdCreateCluster(f *util.Factory, out io.Writer) *cobra.Command {
 	})
 
 	cmd.Flags().StringSliceVar(&options.Zones, "zones", options.Zones, "Zones in which to run the cluster")
-	cmd.RegisterFlagCompletionFunc("zones", completeZone(options))
-	cmd.Flags().StringSliceVar(&options.MasterZones, "master-zones", options.MasterZones, "Zones in which to run masters (must be an odd number)")
-	cmd.RegisterFlagCompletionFunc("master-zones", completeZone(options))
+	cmd.RegisterFlagCompletionFunc("zones", completeZone(options, &rootCommand))
+	cmd.Flags().StringSliceVar(&options.ControlPlaneZones, "control-plane-zones", options.ControlPlaneZones, "Zones in which to run control-plane nodes. (must be an odd number)")
+	cmd.RegisterFlagCompletionFunc("control-plane-zones", completeZone(options, &rootCommand))
 
 	if featureflag.ClusterAddons.Enabled() {
 		cmd.Flags().StringSliceVar(&options.AddonPaths, "add", options.AddonPaths, "Paths to addons we should add to the cluster")
 		// TODO complete VFS paths
 	}
 
-	cmd.Flags().StringVar(&options.KubernetesVersion, "kubernetes-version", options.KubernetesVersion, "Version of kubernetes to run (defaults to version in channel)")
+	cmd.Flags().StringVar(&options.KubernetesVersion, "kubernetes-version", options.KubernetesVersion, "Version of Kubernetes to run (defaults to version in channel)")
 	cmd.RegisterFlagCompletionFunc("kubernetes-version", completeKubernetesVersion)
 
+	cmd.Flags().StringSliceVar(&options.KubernetesFeatureGates, "kubernetes-feature-gates", options.KubernetesFeatureGates, "List of Kubernetes feature gates to enable/disable")
+	cmd.RegisterFlagCompletionFunc("kubernetes-version", completeKubernetesFeatureGates)
+
 	cmd.Flags().StringVar(&options.ContainerRuntime, "container-runtime", options.ContainerRuntime, "Container runtime to use: containerd, docker")
 	cmd.RegisterFlagCompletionFunc("container-runtime", func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		return []string{"containerd", "docker"}, cobra.ShellCompDirectiveNoFileComp
@@ -258,25 +262,28 @@ func NewCmdCreateCluster(f *util.Factory, out io.Writer) *cobra.Command {
 		return []string{"pub"}, cobra.ShellCompDirectiveFilterFileExt
 	})
 
-	cmd.Flags().Int32Var(&options.MasterCount, "master-count", options.MasterCount, "Number of masters. Defaults to one master per master-zone")
+	cmd.Flags().Int32Var(&options.ControlPlaneCount, "control-plane-count", options.ControlPlaneCount, "Number of control-plane nodes. Defaults to one control-plane node per control-plane-zone")
 	cmd.Flags().Int32Var(&options.NodeCount, "node-count", options.NodeCount, "Total number of worker nodes. Defaults to one node per zone")
 
 	cmd.Flags().StringVar(&options.Image, "image", options.Image, "Machine image for all instances")
 	cmd.RegisterFlagCompletionFunc("image", completeInstanceImage)
 	cmd.Flags().StringVar(&options.NodeImage, "node-image", options.NodeImage, "Machine image for worker nodes. Takes precedence over --image")
 	cmd.RegisterFlagCompletionFunc("node-image", completeInstanceImage)
-	cmd.Flags().StringVar(&options.MasterImage, "master-image", options.MasterImage, "Machine image for masters. Takes precedence over --image")
-	cmd.RegisterFlagCompletionFunc("master-image", completeInstanceImage)
+	cmd.Flags().StringVar(&options.ControlPlaneImage, "control-plane-image", options.ControlPlaneImage, "Machine image for control-plane nodes. Takes precedence over --image")
+	cmd.RegisterFlagCompletionFunc("control-plane-image", completeInstanceImage)
+	cmd.Flags().StringVar(&options.BastionImage, "bastion-image", options.BastionImage, "Machine image for bastions. Takes precedence over --image")
+	cmd.RegisterFlagCompletionFunc("bastion-image", completeInstanceImage)
 
 	cmd.Flags().StringVar(&options.NodeSize, "node-size", options.NodeSize, "Machine type for worker nodes")
 	cmd.RegisterFlagCompletionFunc("node-size", completeMachineType)
-	cmd.Flags().StringVar(&options.MasterSize, "master-size", options.MasterSize, "Machine type for masters")
-	cmd.RegisterFlagCompletionFunc("master-size", completeMachineType)
+	cmd.Flags().StringVar(&options.ControlPlaneSize, "control-plane-size", options.ControlPlaneSize, "Machine type for control-plane nodes")
+	cmd.RegisterFlagCompletionFunc("control-plane-size", completeMachineType)
 
-	cmd.Flags().Int32Var(&options.MasterVolumeSize, "master-volume-size", options.MasterVolumeSize, "Instance volume size (in GB) for masters")
+	cmd.Flags().Int32Var(&options.ControlPlaneVolumeSize, "control-plane-volume-size", options.ControlPlaneVolumeSize, "Instance volume size (in GB) for control-plane nodes")
 	cmd.Flags().Int32Var(&options.NodeVolumeSize, "node-volume-size", options.NodeVolumeSize, "Instance volume size (in GB) for worker nodes")
 
 	cmd.Flags().StringVar(&options.NetworkID, "vpc", options.NetworkID, "Shared Network or VPC to use")
+	cmd.Flags().MarkDeprecated("vpc", "use --network-id instead")
 	cmd.RegisterFlagCompletionFunc("vpc", completeNetworkID)
 	cmd.Flags().StringVar(&options.NetworkID, "network-id", options.NetworkID, "Shared Network or VPC to use")
 	cmd.RegisterFlagCompletionFunc("network-id", completeNetworkID)
@@ -311,20 +318,20 @@ func NewCmdCreateCluster(f *util.Factory, out io.Writer) *cobra.Command {
 	})
 
 	// TODO: Can we deprecate this flag - it is awkward?
-	cmd.Flags().BoolVar(&associatePublicIP, "associate-public-ip", false, "Specify --associate-public-ip=[true|false] to enable/disable association of public IP for master ASG and nodes. Default is 'true'.")
+	cmd.Flags().BoolVar(&associatePublicIP, "associate-public-ip", false, "Specify --associate-public-ip=[true|false] to enable/disable association of public IP for control-plane ASG and nodes. Default is 'true'.")
 
 	cmd.Flags().BoolVar(&options.IPv6, "ipv6", false, "Use IPv6 for the pod network (AWS only)")
 
-	cmd.Flags().StringSliceVar(&options.NodeSecurityGroups, "node-security-groups", options.NodeSecurityGroups, "Additional precreated security groups to add to worker nodes.")
+	cmd.Flags().StringSliceVar(&options.NodeSecurityGroups, "node-security-groups", options.NodeSecurityGroups, "Additional pre-created security groups to add to worker nodes.")
 	cmd.RegisterFlagCompletionFunc("node-security-groups", completeSecurityGroup)
-	cmd.Flags().StringSliceVar(&options.MasterSecurityGroups, "master-security-groups", options.MasterSecurityGroups, "Additional precreated security groups to add to masters.")
-	cmd.RegisterFlagCompletionFunc("master-security-groups", completeSecurityGroup)
+	cmd.Flags().StringSliceVar(&options.ControlPlaneSecurityGroups, "control-plane-security-groups", options.ControlPlaneSecurityGroups, "Additional pre-created security groups to add to control-plane nodes.")
+	cmd.RegisterFlagCompletionFunc("control-plane-security-groups", completeSecurityGroup)
 
 	cmd.Flags().StringVar(&options.Channel, "channel", options.Channel, "Channel for default versions and configuration to use")
 	cmd.RegisterFlagCompletionFunc("channel", completeChannel)
 
 	// Network topology
-	cmd.Flags().StringVarP(&options.Topology, "topology", "t", options.Topology, "Network topology for the cluster: public or private")
+	cmd.Flags().StringVarP(&options.Topology, "topology", "t", options.Topology, "Network topology for the cluster: 'public' or 'private'. Defaults to 'public' for IPv4 clusters and 'private' for IPv6 clusters.")
 	cmd.RegisterFlagCompletionFunc("topology", func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		return []string{api.TopologyPublic, api.TopologyPrivate}, cobra.ShellCompDirectiveNoFileComp
 	})
@@ -336,9 +343,10 @@ func NewCmdCreateCluster(f *util.Factory, out io.Writer) *cobra.Command {
 	})
 
 	// DNS
-	cmd.Flags().StringVar(&options.DNSType, "dns", options.DNSType, "DNS type to use: public or private")
+	supportedDnsTypes := []string{"public", "private", "none"}
+	cmd.Flags().StringVar(&options.DNSType, "dns", options.DNSType, "DNS type to use: "+strings.Join(supportedDnsTypes, ", "))
 	cmd.RegisterFlagCompletionFunc("dns", func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
-		return []string{"public", "private"}, cobra.ShellCompDirectiveNoFileComp
+		return supportedDnsTypes, cobra.ShellCompDirectiveNoFileComp
 	})
 
 	// Bastion
@@ -350,26 +358,27 @@ func NewCmdCreateCluster(f *util.Factory, out io.Writer) *cobra.Command {
 		return nil, cobra.ShellCompDirectiveNoFileComp
 	})
 
-	// Master and Node Tenancy
-	cmd.Flags().StringVar(&options.MasterTenancy, "master-tenancy", options.MasterTenancy, "Tenancy of the master group (AWS only): default or dedicated")
-	cmd.RegisterFlagCompletionFunc("master-tenancy", completeTenancy)
+	// Control Plane and Worker Node Tenancy
+	cmd.Flags().StringVar(&options.ControlPlaneTenancy, "control-plane-tenancy", options.ControlPlaneTenancy, "Tenancy of the control-plane group (AWS only): default or dedicated")
+	cmd.RegisterFlagCompletionFunc("control-plane-tenancy", completeTenancy)
 	cmd.Flags().StringVar(&options.NodeTenancy, "node-tenancy", options.NodeTenancy, "Tenancy of the node group (AWS only): default or dedicated")
 	cmd.RegisterFlagCompletionFunc("node-tenancy", completeTenancy)
 
-	cmd.Flags().StringVar(&options.APILoadBalancerClass, "api-loadbalancer-class", options.APILoadBalancerClass, "Class of loadbalancer for the Kubernetes API (AWS only): classic or network")
+	cmd.Flags().StringVar(&options.APILoadBalancerClass, "api-loadbalancer-class", options.APILoadBalancerClass, "Class of load balancer for the Kubernetes API (AWS only): classic or network")
+	cmd.Flags().MarkDeprecated("api-loadbalancer-class", "network load balancer should be used for all newly created clusters")
 	cmd.RegisterFlagCompletionFunc("api-loadbalancer-class", func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		return []string{"classic", "network"}, cobra.ShellCompDirectiveNoFileComp
 	})
-	cmd.Flags().StringVar(&options.APILoadBalancerType, "api-loadbalancer-type", options.APILoadBalancerType, "Type of loadbalancer for the Kubernetes API: public or internal")
+	cmd.Flags().StringVar(&options.APILoadBalancerType, "api-loadbalancer-type", options.APILoadBalancerType, "Type of load balancer for the Kubernetes API: public or internal")
 	cmd.RegisterFlagCompletionFunc("api-loadbalancer-type", func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		return []string{"public", "internal"}, cobra.ShellCompDirectiveNoFileComp
 	})
-	cmd.Flags().StringVar(&options.APISSLCertificate, "api-ssl-certificate", options.APISSLCertificate, "ARN of the SSL Certificate to use for the Kubernetes API loadbalancer (AWS only)")
+	cmd.Flags().StringVar(&options.APISSLCertificate, "api-ssl-certificate", options.APISSLCertificate, "ARN of the SSL Certificate to use for the Kubernetes API load balancer (AWS only)")
 	cmd.RegisterFlagCompletionFunc("api-ssl-certificate", completeSSLCertificate)
 
-	// Allow custom public master name
-	cmd.Flags().StringVar(&options.MasterPublicName, "master-public-name", options.MasterPublicName, "Domain name of the public Kubernetes API")
-	cmd.RegisterFlagCompletionFunc("master-public-name", func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+	// Allow custom public Kuberneters API name.
+	cmd.Flags().StringVar(&options.APIPublicName, "api-public-name", options.APIPublicName, "Domain name of the public Kubernetes API")
+	cmd.RegisterFlagCompletionFunc("api-public-name", func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		return nil, cobra.ShellCompDirectiveNoFileComp
 	})
 
@@ -427,10 +436,10 @@ func NewCmdCreateCluster(f *util.Factory, out io.Writer) *cobra.Command {
 	cmd.RegisterFlagCompletionFunc("os-ext-net", completeOpenstackExternalNet)
 	cmd.Flags().StringVar(&options.OpenstackExternalSubnet, "os-ext-subnet", options.OpenstackExternalSubnet, "External floating subnet to use with the openstack router")
 	cmd.RegisterFlagCompletionFunc("os-ext-subnet", completeOpenstackExternalSubnet)
-	cmd.Flags().StringVar(&options.OpenstackLBSubnet, "os-lb-floating-subnet", options.OpenstackLBSubnet, "External subnet to use with the kubernetes api")
+	cmd.Flags().StringVar(&options.OpenstackLBSubnet, "os-lb-floating-subnet", options.OpenstackLBSubnet, "External subnet to use with the Kubernetes API")
 	cmd.RegisterFlagCompletionFunc("os-lb-floating-subnet", completeOpenstackLBSubnet)
 	cmd.Flags().BoolVar(&options.OpenstackStorageIgnoreAZ, "os-kubelet-ignore-az", options.OpenstackStorageIgnoreAZ, "Attach volumes across availability zones")
-	cmd.Flags().BoolVar(&options.OpenstackLBOctavia, "os-octavia", options.OpenstackLBOctavia, "Use octavia loadbalancer API")
+	cmd.Flags().BoolVar(&options.OpenstackLBOctavia, "os-octavia", options.OpenstackLBOctavia, "Use octavia load balancer API")
 	cmd.Flags().StringVar(&options.OpenstackOctaviaProvider, "os-octavia-provider", options.OpenstackOctaviaProvider, "Octavia provider to use")
 	cmd.RegisterFlagCompletionFunc("os-octavia-provider", completeOpenstackOctaviaProvider)
 	cmd.Flags().StringVar(&options.OpenstackDNSServers, "os-dns-servers", options.OpenstackDNSServers, "comma separated list of DNS Servers which is used in network")
@@ -442,6 +451,22 @@ func NewCmdCreateCluster(f *util.Factory, out io.Writer) *cobra.Command {
 		switch name {
 		case "override":
 			name = "set"
+		case "master-count":
+			name = "control-plane-count"
+		case "master-image":
+			name = "control-plane-image"
+		case "master-public-name":
+			name = "api-public-name"
+		case "master-security-groups":
+			name = "control-plane-security-groups"
+		case "master-size":
+			name = "control-plane-size"
+		case "master-tenancy":
+			name = "control-plane-tenancy"
+		case "master-volume-size":
+			name = "control-plane-volume-size"
+		case "master-zones":
+			name = "control-plane-zones"
 		}
 		return pflag.NormalizedName(name)
 	})
@@ -479,8 +504,6 @@ func RunCreateCluster(ctx context.Context, f *util.Factory, out io.Writer, c *Cr
 	if c.OutDir == "" {
 		if c.Target == cloudup.TargetTerraform {
 			c.OutDir = "out/terraform"
-		} else if c.Target == cloudup.TargetCloudformation {
-			c.OutDir = "out/cloudformation"
 		} else {
 			c.OutDir = "out"
 		}
@@ -522,12 +545,12 @@ func RunCreateCluster(ctx context.Context, f *util.Factory, out io.Writer, c *Cr
 	cluster := clusterResult.Cluster
 	instanceGroups := clusterResult.InstanceGroups
 
-	var masters []*api.InstanceGroup
+	var controlPlanes []*api.InstanceGroup
 	var nodes []*api.InstanceGroup
 	for _, ig := range instanceGroups {
 		switch ig.Spec.Role {
-		case api.InstanceGroupRoleMaster:
-			masters = append(masters, ig)
+		case api.InstanceGroupRoleControlPlane:
+			controlPlanes = append(controlPlanes, ig)
 		case api.InstanceGroupRoleNode:
 			nodes = append(nodes, ig)
 		}
@@ -547,9 +570,9 @@ func RunCreateCluster(ctx context.Context, f *util.Factory, out io.Writer, c *Cr
 		}
 	}
 
-	if c.MasterTenancy != "" {
-		for _, group := range masters {
-			group.Spec.Tenancy = c.MasterTenancy
+	if c.ControlPlaneTenancy != "" {
+		for _, group := range controlPlanes {
+			group.Spec.Tenancy = c.ControlPlaneTenancy
 		}
 	}
 
@@ -565,21 +588,21 @@ func RunCreateCluster(ctx context.Context, f *util.Factory, out io.Writer, c *Cr
 		}
 	}
 
-	if len(c.MasterSecurityGroups) > 0 {
-		for _, group := range masters {
-			group.Spec.AdditionalSecurityGroups = c.MasterSecurityGroups
+	if len(c.ControlPlaneSecurityGroups) > 0 {
+		for _, group := range controlPlanes {
+			group.Spec.AdditionalSecurityGroups = c.ControlPlaneSecurityGroups
 		}
 	}
 
-	if c.MasterVolumeSize != 0 {
-		for _, group := range masters {
-			group.Spec.RootVolumeSize = fi.Int32(c.MasterVolumeSize)
+	if c.ControlPlaneVolumeSize != 0 {
+		for _, group := range controlPlanes {
+			group.Spec.RootVolumeSize = fi.PtrTo(c.ControlPlaneVolumeSize)
 		}
 	}
 
 	if c.NodeVolumeSize != 0 {
 		for _, group := range nodes {
-			group.Spec.RootVolumeSize = fi.Int32(c.NodeVolumeSize)
+			group.Spec.RootVolumeSize = fi.PtrTo(c.NodeVolumeSize)
 		}
 	}
 
@@ -592,15 +615,15 @@ func RunCreateCluster(ctx context.Context, f *util.Factory, out io.Writer, c *Cr
 	}
 
 	if c.NetworkCIDR != "" {
-		cluster.Spec.NetworkCIDR = c.NetworkCIDR
+		cluster.Spec.Networking.NetworkCIDR = c.NetworkCIDR
 	}
 
 	if c.DisableSubnetTags {
-		cluster.Spec.TagSubnets = fi.Bool(false)
+		cluster.Spec.Networking.TagSubnets = fi.PtrTo(false)
 	}
 
-	if c.MasterPublicName != "" {
-		cluster.Spec.MasterPublicName = c.MasterPublicName
+	if c.APIPublicName != "" {
+		cluster.Spec.API.PublicName = c.APIPublicName
 	}
 
 	if err := commands.UnsetClusterFields(c.Unsets, cluster); err != nil {
@@ -627,7 +650,7 @@ func RunCreateCluster(ctx context.Context, f *util.Factory, out io.Writer, c *Cr
 	}
 
 	assetBuilder := assets.NewAssetBuilder(cluster, false)
-	fullCluster, err := cloudup.PopulateClusterSpec(clientset, cluster, cloud, assetBuilder)
+	fullCluster, err := cloudup.PopulateClusterSpec(ctx, clientset, cluster, cloud, assetBuilder)
 	if err != nil {
 		return err
 	}
@@ -652,7 +675,7 @@ func RunCreateCluster(ctx context.Context, f *util.Factory, out io.Writer, c *Cr
 
 	{
 		// Build full IG spec to ensure we end up with a valid IG
-		fullInstanceGroups := []*kops.InstanceGroup{}
+		fullInstanceGroups := []*api.InstanceGroup{}
 		for _, group := range instanceGroups {
 			fullGroup, err := cloudup.PopulateInstanceGroupSpec(cluster, group, cloud, clusterResult.Channel)
 			if err != nil {
@@ -678,6 +701,20 @@ func RunCreateCluster(ctx context.Context, f *util.Factory, out io.Writer, c *Cr
 			obj = append(obj, group)
 		}
 
+		for name, key := range c.SSHPublicKeys {
+			obj = append(obj, &api.SSHCredential{
+				ObjectMeta: metav1.ObjectMeta{
+					Name: name,
+					Labels: map[string]string{
+						api.LabelClusterName: cluster.Name,
+					},
+				},
+				Spec: api.SSHCredentialSpec{
+					PublicKey: strings.TrimSpace(string(key)),
+				},
+			})
+		}
+
 		for _, o := range addons {
 			obj = append(obj, o.ToUnstructured())
 		}
@@ -712,17 +749,27 @@ func RunCreateCluster(ctx context.Context, f *util.Factory, out io.Writer, c *Cr
 		}
 
 		if autoloadSSHPublicKeys {
-			// Load from default location, if found
-			sshPublicKeyPath := "~/.ssh/id_rsa.pub"
-			c.SSHPublicKeys, err = loadSSHPublicKeys(sshPublicKeyPath)
-			if err != nil {
+			// Load from default locations, if found
+			sshPublicKeyPaths := []string{
+				"~/.ssh/id_rsa.pub",
+				"~/.ssh/id_ed25519.pub",
+			}
+			var merr error
+			for _, sshPublicKeyPath := range sshPublicKeyPaths {
+				c.SSHPublicKeys, err = loadSSHPublicKeys(sshPublicKeyPath)
+				if err == nil {
+					break
+				}
 				// Don't wrap file-not-found
 				if os.IsNotExist(err) {
 					klog.V(2).Infof("ssh key not found at %s", sshPublicKeyPath)
 				} else {
-					return fmt.Errorf("error reading SSH key file %q: %v", sshPublicKeyPath, err)
+					merr = multierr.Append(merr, err)
 				}
 			}
+			if merr != nil && len(c.SSHPublicKeys) == 0 {
+				return fmt.Errorf("error reading SSH public key files %q: %v", sshPublicKeyPaths, merr)
+			}
 		}
 	}
 
@@ -733,7 +780,7 @@ func RunCreateCluster(ctx context.Context, f *util.Factory, out io.Writer, c *Cr
 		}
 
 		for _, data := range c.SSHPublicKeys {
-			err = sshCredentialStore.AddSSHPublicKey(data)
+			err = sshCredentialStore.AddSSHPublicKey(ctx, data)
 			if err != nil {
 				return fmt.Errorf("error adding SSH public key: %v", err)
 			}
@@ -776,8 +823,8 @@ func RunCreateCluster(ctx context.Context, f *util.Factory, out io.Writer, c *Cr
 			if len(nodes) > 0 {
 				fmt.Fprintf(&sb, " * edit your node instance group: kops edit ig --name=%s %s\n", cluster.Name, nodes[0].ObjectMeta.Name)
 			}
-			if len(masters) > 0 {
-				fmt.Fprintf(&sb, " * edit your master instance group: kops edit ig --name=%s %s\n", cluster.Name, masters[0].ObjectMeta.Name)
+			if len(controlPlanes) > 0 {
+				fmt.Fprintf(&sb, " * edit your control-plane instance group: kops edit ig --name=%s %s\n", cluster.Name, controlPlanes[0].ObjectMeta.Name)
 			}
 			fmt.Fprintf(&sb, "\n")
 			fmt.Fprintf(&sb, "Finally configure your cluster with: kops update cluster --name %s --yes --admin\n", cluster.Name)
@@ -809,7 +856,7 @@ func parseCloudLabels(s string) (map[string]string, error) {
 	r.TrimLeadingSpace = true
 	kvPairs, err := r.ReadAll()
 	if err != nil {
-		return nil, fmt.Errorf("One or more key=value pairs are malformed:\n%s\n:%v", records, err)
+		return nil, fmt.Errorf("one or more key=value pairs are malformed:\n%s\n:%w", records, err)
 	}
 
 	m := make(map[string]string, len(kvPairs))
@@ -833,28 +880,17 @@ func loadSSHPublicKeys(sshPublicKey string) (map[string][]byte, error) {
 	return sshPublicKeys, nil
 }
 
-func completeZone(options *CreateClusterOptions) func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+func completeZone(options *CreateClusterOptions, rootCommand *RootCmd) func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 	return func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
-		var allClouds []api.CloudProviderID
 		if options.CloudProvider != "" {
-			allClouds = []api.CloudProviderID{api.CloudProviderID(options.CloudProvider)}
-		} else {
-			allClouds = clouds.SupportedClouds()
+			return zones.WellKnownZonesForCloud(api.CloudProviderID(options.CloudProvider), toComplete), cobra.ShellCompDirectiveNoFileComp
 		}
 
-		var allZones []string
-		for _, c := range allClouds {
-			zones := zones.WellKnownZonesForCloud(c)
-			for _, z := range zones {
-				if options.CloudProvider == "" {
-					allZones = append(allZones, z+"\t"+string(c))
-				} else {
-					allZones = append(allZones, z)
-				}
-			}
+		cloud, err := clouds.GuessCloudForPath(rootCommand.RegistryPath)
+		if err != nil {
+			return commandutils.CompletionError("listing cloud zones", err)
 		}
-		sort.Strings(allZones)
-		return allZones, cobra.ShellCompDirectiveNoFileComp
+		return zones.WellKnownZonesForCloud(cloud, toComplete), cobra.ShellCompDirectiveNoFileComp
 	}
 }
 
@@ -903,6 +939,11 @@ func completeKubernetesVersion(cmd *cobra.Command, args []string, toComplete str
 	return versions.List(), cobra.ShellCompDirectiveNoFileComp
 }
 
+func completeKubernetesFeatureGates(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+	// TODO check if there's a way to get the full list of feature gates from k8s libs
+	return nil, cobra.ShellCompDirectiveNoFileComp
+}
+
 func completeInstanceImage(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 	// TODO call into cloud provider(s) to get list of valid images
 	return nil, cobra.ShellCompDirectiveNoFileComp
@@ -937,6 +978,7 @@ func completeNetworking(options *CreateClusterOptions) func(cmd *cobra.Command,
 			"cni",
 			"calico",
 			"cilium",
+			"cilium-eni",
 			"cilium-etcd",
 		}
 
@@ -974,9 +1016,6 @@ func completeCreateClusterTarget(options *CreateClusterOptions) func(cmd *cobra.
 				completions = append(completions, cloudup.TargetTerraform)
 			}
 		}
-		if options.CloudProvider == string(api.CloudProviderAWS) {
-			completions = append(completions, cloudup.TargetCloudformation)
-		}
 		return completions, cobra.ShellCompDirectiveNoFileComp
 	}
 }
