@@ -22,7 +22,6 @@ import (
 	"fmt"
 	"io"
 	"os"
-	"path/filepath"
 	"strings"
 	"time"
 
@@ -108,13 +107,13 @@ func NewCmdUpdateCluster(f *util.Factory, out io.Writer) *cobra.Command {
 		Args:              rootCommand.clusterNameArgs(&options.ClusterName),
 		ValidArgsFunction: commandutils.CompleteClusterName(f, true, false),
 		RunE: func(cmd *cobra.Command, args []string) error {
-			_, err := RunUpdateCluster(context.TODO(), f, out, options)
+			_, err := RunUpdateCluster(cmd.Context(), f, out, options)
 			return err
 		},
 	}
 
 	cmd.Flags().BoolVarP(&options.Yes, "yes", "y", options.Yes, "Create cloud resources, without --yes update is in dry run mode")
-	cmd.Flags().StringVar(&options.Target, "target", options.Target, "Target - direct, terraform, cloudformation")
+	cmd.Flags().StringVar(&options.Target, "target", options.Target, "Target - direct, terraform")
 	cmd.RegisterFlagCompletionFunc("target", completeUpdateClusterTarget(f, options))
 	cmd.Flags().StringVar(&options.SSHPublicKey, "ssh-public-key", options.SSHPublicKey, "SSH public key to use (deprecated: use kops create secret instead)")
 	cmd.Flags().StringVar(&options.OutDir, "out", options.OutDir, "Path to write any local output")
@@ -139,11 +138,11 @@ func NewCmdUpdateCluster(f *util.Factory, out io.Writer) *cobra.Command {
 }
 
 type UpdateClusterResults struct {
-	// Target is the fi.Target we will operated against.  This can be used to get dryrun results (primarily for tests)
-	Target fi.Target
+	// Target is the fi.Target we will operate against.  This can be used to get dryrun results (primarily for tests)
+	Target fi.CloudupTarget
 
 	// TaskMap is the map of tasks that we built (output)
-	TaskMap map[string]fi.Task
+	TaskMap map[string]fi.CloudupTask
 
 	// ImageAssets are the image assets we use (output).
 	ImageAssets []*assets.ImageAsset
@@ -193,8 +192,6 @@ func RunUpdateCluster(ctx context.Context, f *util.Factory, out io.Writer, c *Up
 	if c.OutDir == "" {
 		if c.Target == cloudup.TargetTerraform {
 			c.OutDir = "out/terraform"
-		} else if c.Target == cloudup.TargetCloudformation {
-			c.OutDir = "out/cloudformation"
 		} else {
 			c.OutDir = "out"
 		}
@@ -233,7 +230,7 @@ func RunUpdateCluster(ctx context.Context, f *util.Factory, out io.Writer, c *Up
 		if err != nil {
 			return results, fmt.Errorf("error reading SSH key file %q: %v", c.SSHPublicKey, err)
 		}
-		err = sshCredentialStore.AddSSHPublicKey(authorized)
+		err = sshCredentialStore.AddSSHPublicKey(ctx, authorized)
 		if err != nil {
 			return results, fmt.Errorf("error adding SSH public key: %v", err)
 		}
@@ -304,7 +301,7 @@ func RunUpdateCluster(ctx context.Context, f *util.Factory, out io.Writer, c *Up
 	results.Cluster = cluster
 
 	if isDryrun && !c.GetAssets {
-		target := applyCmd.Target.(*fi.DryRunTarget)
+		target := applyCmd.Target.(*fi.CloudupDryRunTarget)
 		if target.HasChanges() {
 			fmt.Fprintf(out, "Must specify --yes to apply changes\n")
 		} else {
@@ -365,17 +362,6 @@ func RunUpdateCluster(ctx context.Context, f *util.Factory, out io.Writer, c *Up
 				fmt.Fprintf(sb, "   terraform apply\n")
 				fmt.Fprintf(sb, "\n")
 			}
-		} else if c.Target == cloudup.TargetCloudformation {
-			fmt.Fprintf(sb, "\n")
-			fmt.Fprintf(sb, "Cloudformation output has been placed into %s\n", c.OutDir)
-
-			if firstRun {
-				cfName := "kubernetes-" + strings.Replace(c.ClusterName, ".", "-", -1)
-				cfPath := filepath.Join(c.OutDir, "kubernetes.json")
-				fmt.Fprintf(sb, "Run this command to apply the configuration:\n")
-				fmt.Fprintf(sb, "   aws cloudformation create-stack --capabilities CAPABILITY_NAMED_IAM --stack-name %s --template-body file://%s\n", cfName, cfPath)
-				fmt.Fprintf(sb, "\n")
-			}
 		} else if firstRun {
 			fmt.Fprintf(sb, "\n")
 			fmt.Fprintf(sb, "Cluster is starting.  It should be ready in a few minutes.\n")
@@ -393,7 +379,7 @@ func RunUpdateCluster(ctx context.Context, f *util.Factory, out io.Writer, c *Up
 			fmt.Fprintf(sb, " * validate cluster: kops validate cluster --wait 10m\n")
 			fmt.Fprintf(sb, " * list nodes: kubectl get nodes --show-labels\n")
 			if !usesBastion(applyCmd.InstanceGroups) {
-				fmt.Fprintf(sb, " * ssh to the master: ssh -i ~/.ssh/id_rsa ubuntu@%s\n", cluster.Spec.MasterPublicName)
+				fmt.Fprintf(sb, " * ssh to a control-plane node: ssh -i ~/.ssh/id_rsa ubuntu@%s\n", cluster.Spec.API.PublicName)
 			} else {
 				bastionPublicName := findBastionPublicName(cluster)
 				if bastionPublicName != "" {
@@ -441,7 +427,7 @@ func usesBastion(instanceGroups []*kops.InstanceGroup) bool {
 }
 
 func findBastionPublicName(c *kops.Cluster) string {
-	topology := c.Spec.Topology
+	topology := c.Spec.Networking.Topology
 	if topology == nil {
 		return ""
 	}
@@ -470,15 +456,15 @@ func hasKubecfg(contextName string) (bool, error) {
 
 func completeUpdateClusterTarget(f commandutils.Factory, options *UpdateClusterOptions) func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 	return func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+		ctx := cmd.Context()
+
 		commandutils.ConfigureKlogForCompletion()
-		ctx := context.TODO()
 
 		cluster, _, _, directive := GetClusterForCompletion(ctx, f, nil)
 		if cluster == nil {
 			return []string{
 				cloudup.TargetDirect,
 				cloudup.TargetDryRun,
-				cloudup.TargetCloudformation,
 				cloudup.TargetTerraform,
 			}, directive
 		}
@@ -492,9 +478,6 @@ func completeUpdateClusterTarget(f commandutils.Factory, options *UpdateClusterO
 				completions = append(completions, cloudup.TargetTerraform)
 			}
 		}
-		if cluster.Spec.GetCloudProvider() == kops.CloudProviderAWS {
-			completions = append(completions, cloudup.TargetCloudformation)
-		}
 		return completions, cobra.ShellCompDirectiveNoFileComp
 	}
 }
