@@ -23,8 +23,8 @@ import (
 	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/intstr"
-
 	"k8s.io/kops/pkg/apis/kops/util"
+	"k8s.io/kops/pkg/dns"
 	"k8s.io/kops/upup/pkg/fi/utils"
 )
 
@@ -68,29 +68,6 @@ type ClusterSpec struct {
 	ContainerRuntime string `json:"containerRuntime,omitempty"`
 	// The version of kubernetes to install (optional, and can be a "spec" like stable)
 	KubernetesVersion string `json:"kubernetesVersion,omitempty"`
-	// Configuration of subnets we are targeting
-	Subnets []ClusterSubnetSpec `json:"subnets,omitempty"`
-	// Project is the cloud project we should use, required on GCE
-	Project string `json:"project,omitempty"`
-	// MasterPublicName is the external DNS name for the master nodes
-	MasterPublicName string `json:"masterPublicName,omitempty"`
-	// MasterInternalName is the internal DNS name for the master nodes
-	MasterInternalName string `json:"masterInternalName,omitempty"`
-	// NetworkCIDR is the CIDR used for the AWS VPC / DO/ GCE Network, or otherwise allocated to k8s
-	// This is a real CIDR, not the internal k8s network
-	// On AWS, it maps to the VPC CIDR.  It is not required on GCE.
-	// On DO, it maps to the VPC CIDR.
-	NetworkCIDR string `json:"networkCIDR,omitempty"`
-	// AdditionalNetworkCIDRs is a list of additional CIDR used for the AWS VPC
-	// or otherwise allocated to k8s. This is a real CIDR, not the internal k8s network
-	// On AWS, it maps to any additional CIDRs added to a VPC.
-	AdditionalNetworkCIDRs []string `json:"additionalNetworkCIDRs,omitempty"`
-	// NetworkID is an identifier of a network, if we want to reuse/share an existing network (e.g. an AWS VPC)
-	NetworkID string `json:"networkID,omitempty"`
-	// Topology defines the type of network topology to use on the cluster - default public
-	// This is heavily weighted towards AWS for the time being, but should also be agnostic enough
-	// to port out to GCE later if needed
-	Topology *TopologySpec `json:"topology,omitempty"`
 	// SecretStore is the VFS path to where secrets are stored
 	SecretStore string `json:"secretStore,omitempty"`
 	// KeyStore is the VFS path to where SSL keys and certificates are stored
@@ -100,41 +77,20 @@ type ClusterSpec struct {
 	// DNSZone is the DNS zone we should use when configuring DNS
 	// This is because some clouds let us define a managed zone foo.bar, and then have
 	// kubernetes.dev.foo.bar, without needing to define dev.foo.bar as a hosted zone.
-	// DNSZone will probably be a suffix of the MasterPublicName and MasterInternalName
+	// DNSZone will probably be a suffix of the MasterPublicName.
 	// Note that DNSZone can either by the host name of the zone (containing dots),
 	// or can be an identifier for the zone.
 	DNSZone string `json:"dnsZone,omitempty"`
 	// DNSControllerGossipConfig for the cluster assuming the use of gossip DNS
 	DNSControllerGossipConfig *DNSControllerGossipConfig `json:"dnsControllerGossipConfig,omitempty"`
-	// AdditionalSANs adds additional Subject Alternate Names to apiserver cert that kops generates
-	AdditionalSANs []string `json:"additionalSANs,omitempty"`
 	// ClusterDNSDomain is the suffix we use for internal DNS names (normally cluster.local)
 	ClusterDNSDomain string `json:"clusterDNSDomain,omitempty"`
-	// ServiceClusterIPRange is the CIDR, from the internal network, where we allocate IPs for services
-	ServiceClusterIPRange string `json:"serviceClusterIPRange,omitempty"`
-	// PodCIDR is the CIDR from which we allocate IPs for pods
-	PodCIDR string `json:"podCIDR,omitempty"`
-	// NonMasqueradeCIDR is the CIDR for the internal k8s network (on which pods & services live)
-	// It cannot overlap ServiceClusterIPRange
-	NonMasqueradeCIDR string `json:"nonMasqueradeCIDR,omitempty"`
 	// SSHAccess is a list of the CIDRs that can access SSH.
 	SSHAccess []string `json:"sshAccess,omitempty"`
 	// NodePortAccess is a list of the CIDRs that can access the node ports range (30000-32767).
 	NodePortAccess []string `json:"nodePortAccess,omitempty"`
-	// HTTPProxy defines connection information to support use of a private cluster behind an forward HTTP Proxy
-	EgressProxy *EgressProxySpec `json:"egressProxy,omitempty"`
 	// SSHKeyName specifies a preexisting SSH key to use
 	SSHKeyName *string `json:"sshKeyName,omitempty"`
-	// KubernetesAPIAccess is a list of the CIDRs that can access the Kubernetes API endpoint (master HTTPS)
-	KubernetesAPIAccess []string `json:"kubernetesAPIAccess,omitempty"`
-	// IsolateMasters determines whether we should lock down masters so that they are not on the pod network.
-	// true is the kube-up behaviour, but it is very surprising: it means that daemonsets only work on the master
-	// if they have hostNetwork=true.
-	// false is now the default, and it will:
-	//  * give the master a normal PodCIDR
-	//  * run kube-proxy on the master
-	//  * enable debugging handlers on the master, so kubectl logs works
-	IsolateMasters *bool `json:"isolateMasters,omitempty"`
 	// UpdatePolicy determines the policy for applying upgrades automatically.
 	// Valid values:
 	//   'automatic' (default): apply updates automatically (apply OS security upgrades, avoiding rebooting when possible)
@@ -160,28 +116,23 @@ type ClusterSpec struct {
 	// Kubelet is the kubelet configuration for nodes not belonging to the control plane.
 	// It can be overridden by the kubelet configuration specified in the instance group.
 	Kubelet *KubeletConfigSpec `json:"kubelet,omitempty"`
-	// MasterKubelet is the kubelet configuration for nodes belonging to the control plane
+	// ControlPlaneKubelet is the kubelet configuration for nodes belonging to the control plane
 	// It can be overridden by the kubelet configuration specified in the instance group.
-	MasterKubelet *KubeletConfigSpec  `json:"masterKubelet,omitempty"`
-	CloudConfig   *CloudConfiguration `json:"cloudConfig,omitempty"`
-	ExternalDNS   *ExternalDNSConfig  `json:"externalDNS,omitempty"`
-	NTP           *NTPConfig          `json:"ntp,omitempty"`
+	ControlPlaneKubelet *KubeletConfigSpec  `json:"controlPlaneKubelet,omitempty"`
+	CloudConfig         *CloudConfiguration `json:"cloudConfig,omitempty"`
+	ExternalDNS         *ExternalDNSConfig  `json:"externalDNS,omitempty"`
+	NTP                 *NTPConfig          `json:"ntp,omitempty"`
 
-	// NodeTerminationHandler determines the node termination handler configuration.
-	NodeTerminationHandler *NodeTerminationHandlerConfig `json:"nodeTerminationHandler,omitempty"`
 	// NodeProblemDetector determines the node problem detector configuration.
 	NodeProblemDetector *NodeProblemDetectorConfig `json:"nodeProblemDetector,omitempty"`
 	// MetricsServer determines the metrics server configuration.
 	MetricsServer *MetricsServerConfig `json:"metricsServer,omitempty"`
 	// CertManager determines the metrics server configuration.
 	CertManager *CertManagerConfig `json:"certManager,omitempty"`
-	// AWSLoadbalancerControllerConfig determines the AWS LB controller configuration.
-	AWSLoadBalancerController *AWSLoadBalancerControllerConfig `json:"awsLoadBalancerController,omitempty"`
-
-	// Networking configuration
-	Networking *NetworkingSpec `json:"networking,omitempty"`
-	// API field controls how the API is exposed outside the cluster
-	API *AccessSpec `json:"api,omitempty"`
+	// Networking configures networking.
+	Networking NetworkingSpec `json:"networking,omitempty"`
+	// API controls how the Kubernetes API is exposed.
+	API APISpec `json:"api,omitempty"`
 	// Authentication field controls how the cluster is configured for authentication
 	Authentication *AuthenticationSpec `json:"authentication,omitempty"`
 	// Authorization field controls how the cluster is configured for authorization
@@ -198,8 +149,6 @@ type ClusterSpec struct {
 	IAM *IAMSpec `json:"iam,omitempty"`
 	// EncryptionConfig controls if encryption is enabled
 	EncryptionConfig *bool `json:"encryptionConfig,omitempty"`
-	// TagSubnets controls if tags are added to subnets to enable use by load balancers (AWS only). Default: true.
-	TagSubnets *bool `json:"tagSubnets,omitempty"`
 	// Target allows for us to nest extra config for targets such as terraform
 	Target *TargetSpec `json:"target,omitempty"`
 	// UseHostCertificates will mount /etc/ssl/certs to inside needed containers.
@@ -213,20 +162,16 @@ type ClusterSpec struct {
 	RollingUpdate *RollingUpdate `json:"rollingUpdate,omitempty"`
 	// ClusterAutoscaler defines the cluster autoscaler configuration.
 	ClusterAutoscaler *ClusterAutoscalerConfig `json:"clusterAutoscaler,omitempty"`
-	// WarmPool defines the default warm pool settings for instance groups (AWS only).
-	WarmPool *WarmPoolSpec `json:"warmPool,omitempty"`
 	// ServiceAccountIssuerDiscovery configures the OIDC Issuer for ServiceAccounts.
 	ServiceAccountIssuerDiscovery *ServiceAccountIssuerDiscoveryConfig `json:"serviceAccountIssuerDiscovery,omitempty"`
 	// SnapshotController defines the CSI Snapshot Controller configuration.
 	SnapshotController *SnapshotControllerConfig `json:"snapshotController,omitempty"`
 	// Karpenter defines the Karpenter configuration.
 	Karpenter *KarpenterConfig `json:"karpenter,omitempty"`
-	// PodIdentityWebhook determines the EKS Pod Identity Webhook configuration.
-	PodIdentityWebhook *PodIdentityWebhookConfig `json:"podIdentityWebhook,omitempty"`
 }
 
-// PodIdentityWebhookConfig configures an EKS Pod Identity Webhook.
-type PodIdentityWebhookConfig struct {
+// PodIdentityWebhookSpec configures an EKS Pod Identity Webhook.
+type PodIdentityWebhookSpec struct {
 	Enabled  bool `json:"enabled,omitempty"`
 	Replicas int  `json:"replicas,omitempty"`
 }
@@ -245,20 +190,44 @@ type CloudProviderSpec struct {
 	Hetzner *HetznerSpec `json:"hetzner,omitempty"`
 	// Openstack configures the Openstack cloud provider.
 	Openstack *OpenstackSpec `json:"openstack,omitempty"`
+	// Scaleway configures the Scaleway cloud provider.
+	Scaleway *ScalewaySpec `json:"scaleway,omitempty"`
 }
 
 // AWSSpec configures the AWS cloud provider.
-type AWSSpec struct{}
+type AWSSpec struct {
+	// EBSCSIDriverSpec is the config for the EBS CSI driver.
+	EBSCSIDriver *EBSCSIDriverSpec `json:"ebsCSIDriver,omitempty"`
+	// NodeTerminationHandler determines the node termination handler configuration.
+	NodeTerminationHandler *NodeTerminationHandlerSpec `json:"nodeTerminationHandler,omitempty"`
+	// LoadbalancerController determines the Load Balancer Controller configuration.
+	LoadBalancerController *LoadBalancerControllerSpec `json:"loadBalancerController,omitempty"`
+	// PodIdentityWebhook determines the EKS Pod Identity Webhook configuration.
+	PodIdentityWebhook *PodIdentityWebhookSpec `json:"podIdentityWebhook,omitempty"`
+	// WarmPool defines the default warm pool settings for instance groups.
+	WarmPool *WarmPoolSpec `json:"warmPool,omitempty"`
+}
 
 // DOSpec configures the Digital Ocean cloud provider.
 type DOSpec struct{}
 
 // GCESpec configures the GCE cloud provider.
-type GCESpec struct{}
+type GCESpec struct {
+	// Project is the cloud project we should use.
+	Project string `json:"project"`
+	// ServiceAccount specifies the service account with which the GCE VM runs.
+	ServiceAccount string `json:"serviceAccount,omitempty"`
+	// PDCSIDriver is the config for the PD CSI driver.
+	PDCSIDriver *PDCSIDriver `json:"pdCSIDriver,omitempty"`
+}
 
 // HetznerSpec configures the Hetzner cloud provider.
 type HetznerSpec struct{}
 
+// ScalewaySpec configures the Scaleway cloud provider
+type ScalewaySpec struct {
+}
+
 type KarpenterConfig struct {
 	Enabled bool `json:"enabled,omitempty"`
 }
@@ -445,12 +414,18 @@ type RBACAuthorizationSpec struct{}
 
 type AlwaysAllowAuthorizationSpec struct{}
 
-// AccessSpec provides configuration details related to kubeapi dns and ELB access
-type AccessSpec struct {
-	// DNS will be used to provide config on kube-apiserver ELB DNS
+// APISpec provides configuration details related to the Kubernetes API.
+type APISpec struct {
+	// DNS will be used to provide configuration for the Kubernetes API's DNS server.
 	DNS *DNSAccessSpec `json:"dns,omitempty"`
-	// LoadBalancer is the configuration for the kube-apiserver ELB
+	// LoadBalancer is the configuration for the Kubernetes API load balancer.
 	LoadBalancer *LoadBalancerAccessSpec `json:"loadBalancer,omitempty"`
+	// PublicName is the external DNS name for the Kubernetes API.
+	PublicName string `json:"publicName,omitempty"`
+	// AdditionalSANs adds additional Subject Alternate Names to the Kubernetes API certificate.
+	AdditionalSANs []string `json:"additionalSANs,omitempty"`
+	// Access is a list of the CIDRs that can access the Kubernetes API endpoint.
+	Access []string `json:"access,omitempty"`
 }
 
 type DNSAccessSpec struct{}
@@ -561,6 +536,8 @@ type KubeDNSConfig struct {
 type NodeLocalDNSConfig struct {
 	// Enabled activates the node-local-dns addon.
 	Enabled *bool `json:"enabled,omitempty"`
+	// ExternalCoreFile is used to provide a complete NodeLocalDNS CoreFile by the user - ignores other provided flags which modify the CoreFile.
+	ExternalCoreFile string `json:"externalCoreFile,omitempty"`
 	// Image overrides the default docker image used for node-local-dns addon.
 	Image *string `json:"image,omitempty"`
 	// Local listen IP address. It can be any IP in the 169.254.20.0/16 space or any other IP address that can be guaranteed to not collide with any existing IP.
@@ -709,6 +686,7 @@ const (
 )
 
 // ClusterSubnetSpec defines a subnet
+// TODO: move to networking.go
 type ClusterSubnetSpec struct {
 	// Name is the name of the subnet
 	Name string `json:"name,omitempty"`
@@ -720,8 +698,8 @@ type ClusterSubnetSpec struct {
 	Zone string `json:"zone,omitempty"`
 	// Region is the region the subnet is in, set for subnets that are regionally scoped
 	Region string `json:"region,omitempty"`
-	// ProviderID is the cloud provider id for the objects associated with the zone (the subnet on AWS)
-	ProviderID string `json:"id,omitempty"`
+	// ID is the cloud provider ID for the objects associated with the zone (the subnet on AWS).
+	ID string `json:"id,omitempty"`
 	// Egress defines the method of traffic egress for this subnet
 	Egress string `json:"egress,omitempty"`
 	// Type define which one if the internal types (public, utility, private) the network is
@@ -778,17 +756,10 @@ func (t *TerraformSpec) IsEmpty() bool {
 // store them (i.e. we don't need to 'lock them')
 func (c *Cluster) FillDefaults() error {
 	// Topology support
-	if c.Spec.Topology == nil {
-		c.Spec.Topology = &TopologySpec{Masters: TopologyPublic, Nodes: TopologyPublic}
-		c.Spec.Topology.DNS = &DNSSpec{Type: DNSTypePublic}
+	if c.Spec.Networking.Topology == nil {
+		c.Spec.Networking.Topology = &TopologySpec{ControlPlane: TopologyPublic, Nodes: TopologyPublic, DNS: DNSTypePublic}
 	}
 
-	if c.Spec.Networking == nil {
-		c.Spec.Networking = &NetworkingSpec{}
-	}
-
-	c.fillClusterSpecNetworkingSpec()
-
 	if c.Spec.Channel == "" {
 		c.Spec.Channel = DefaultChannel
 	}
@@ -797,52 +768,12 @@ func (c *Cluster) FillDefaults() error {
 		return fmt.Errorf("cluster Name not set in FillDefaults")
 	}
 
-	if c.Spec.MasterInternalName == "" {
-		c.Spec.MasterInternalName = "api.internal." + c.ObjectMeta.Name
-	}
-
-	if c.Spec.MasterPublicName == "" {
-		c.Spec.MasterPublicName = "api." + c.ObjectMeta.Name
-	}
-
 	return nil
 }
 
-// fillClusterSpecNetworking provides default value if c.Spec.NetworkingSpec is nil
-func (c *Cluster) fillClusterSpecNetworkingSpec() {
-	if c.Spec.Networking.Kubenet != nil {
-		// OK
-	} else if c.Spec.Networking.CNI != nil {
-		// OK
-	} else if c.Spec.Networking.External != nil {
-		// OK
-	} else if c.Spec.Networking.Kopeio != nil {
-		// OK
-	} else if c.Spec.Networking.Weave != nil {
-		// OK
-	} else if c.Spec.Networking.Flannel != nil {
-		// OK
-	} else if c.Spec.Networking.Calico != nil {
-		// OK
-	} else if c.Spec.Networking.Canal != nil {
-		// OK
-	} else if c.Spec.Networking.Kuberouter != nil {
-		// OK
-	} else if c.Spec.Networking.AmazonVPC != nil {
-		// OK
-	} else if c.Spec.Networking.Cilium != nil {
-		// OK
-	} else if c.Spec.Networking.GCE != nil {
-		// OK
-	} else {
-		// No networking model selected; choose Kubenet
-		c.Spec.Networking.Kubenet = &KubenetNetworkingSpec{}
-	}
-}
-
 // SharedVPC is a simple helper function which makes the templates for a shared VPC clearer
 func (c *Cluster) SharedVPC() bool {
-	return c.Spec.NetworkID != ""
+	return c.Spec.Networking.NetworkID != ""
 }
 
 // IsKubernetesGTE checks if the version is >= the specified version.
@@ -890,8 +821,40 @@ func (c *Cluster) IsSharedAzureRouteTable() bool {
 	return c.Spec.CloudProvider.Azure.RouteTableName != ""
 }
 
+func (c *Cluster) IsGossip() bool {
+	if c.UsesNoneDNS() || !dns.IsGossipClusterName(c.Name) {
+		return false
+	}
+	return true
+}
+
+func (c *Cluster) UsesPublicDNS() bool {
+	if c.Spec.Networking.Topology == nil || c.Spec.Networking.Topology.DNS == "" || c.Spec.Networking.Topology.DNS == DNSTypePublic {
+		return true
+	}
+	return false
+}
+
+func (c *Cluster) UsesPrivateDNS() bool {
+	if c.Spec.Networking.Topology != nil && c.Spec.Networking.Topology.DNS == DNSTypePrivate {
+		return true
+	}
+	return false
+}
+
+func (c *Cluster) UsesNoneDNS() bool {
+	if c.Spec.Networking.Topology != nil && c.Spec.Networking.Topology.DNS == DNSTypeNone {
+		return true
+	}
+	return false
+}
+
+func (c *Cluster) APIInternalName() string {
+	return "api.internal." + c.ObjectMeta.Name
+}
+
 func (c *ClusterSpec) IsIPv6Only() bool {
-	return utils.IsIPv6CIDR(c.NonMasqueradeCIDR)
+	return utils.IsIPv6CIDR(c.Networking.NonMasqueradeCIDR)
 }
 
 func (c *ClusterSpec) IsKopsControllerIPAM() bool {
@@ -911,6 +874,8 @@ func (c *ClusterSpec) GetCloudProvider() CloudProviderID {
 		return CloudProviderHetzner
 	} else if c.CloudProvider.Openstack != nil {
 		return CloudProviderOpenstack
+	} else if c.CloudProvider.Scaleway != nil {
+		return CloudProviderScaleway
 	}
 	return ""
 }
@@ -1022,7 +987,7 @@ func (in *WarmPoolSpec) IsEnabled() bool {
 func (in *WarmPoolSpec) ResolveDefaults(ig *InstanceGroup) *WarmPoolSpec {
 	igWarmPool := ig.Spec.WarmPool
 	if igWarmPool == nil {
-		if in == nil || (ig.Spec.Role == InstanceGroupRoleMaster || ig.Spec.Role == InstanceGroupRoleBastion) {
+		if in == nil || (ig.Spec.Role == InstanceGroupRoleControlPlane || ig.Spec.Role == InstanceGroupRoleBastion) {
 			var zero int64
 			return &WarmPoolSpec{
 				MaxSize: &zero,
@@ -1031,7 +996,7 @@ func (in *WarmPoolSpec) ResolveDefaults(ig *InstanceGroup) *WarmPoolSpec {
 		return in
 	}
 
-	if in == nil || (ig.Spec.Role == InstanceGroupRoleMaster || ig.Spec.Role == InstanceGroupRoleBastion) {
+	if in == nil || (ig.Spec.Role == InstanceGroupRoleControlPlane || ig.Spec.Role == InstanceGroupRoleBastion) {
 		return igWarmPool
 	}
 
