@@ -696,6 +696,8 @@ type CloudControllerManagerConfig struct {
 	// CPURequest of NodeTerminationHandler container.
 	// Default: 200m
 	CPURequest *resource.Quantity `json:"cpuRequest,omitempty"`
+	// NodeStatusUpdateFrequency is the duration between node status updates. (default: 5m)
+	NodeStatusUpdateFrequency *metav1.Duration `json:"nodeStatusUpdateFrequency,omitempty" flag:"node-status-update-frequency"`
 }
 
 // KubeSchedulerConfig is the configuration for the kube-scheduler
@@ -782,13 +784,16 @@ type OpenstackLoadbalancerConfig struct {
 }
 
 type OpenstackBlockStorageConfig struct {
-	Version    *string `json:"bs-version,omitempty"`
-	IgnoreAZ   *bool   `json:"ignore-volume-az,omitempty"`
-	OverrideAZ *string `json:"override-volume-az,omitempty"`
+	Version                  *string `json:"bs-version,omitempty"`
+	IgnoreAZ                 *bool   `json:"ignore-volume-az,omitempty"`
+	OverrideAZ               *string `json:"override-volume-az,omitempty"`
+	IgnoreVolumeMicroVersion *bool   `json:"ignore-volume-microversion,omitempty"`
 	// CreateStorageClass provisions a default class for the Cinder plugin
 	CreateStorageClass *bool  `json:"createStorageClass,omitempty"`
 	CSIPluginImage     string `json:"csiPluginImage,omitempty"`
 	CSITopologySupport *bool  `json:"csiTopologySupport,omitempty"`
+	// ClusterName sets the --cluster flag for the cinder-csi-plugin to the provided name
+	ClusterName string `json:"clusterName,omitempty"`
 }
 
 // OpenstackMonitor defines the config for a health monitor
@@ -865,22 +870,16 @@ type CloudConfiguration struct {
 	NodeInstancePrefix *string `json:"nodeInstancePrefix,omitempty"`
 	// NodeIPFamilies controls the IP families reported for each node (AWS only).
 	NodeIPFamilies []string `json:"nodeIPFamilies,omitempty"`
-	// GCEServiceAccount specifies the service account with which the GCE VM runs
-	GCEServiceAccount string `json:"gceServiceAccount,omitempty"`
 	// AWS cloud-config options
 	DisableSecurityGroupIngress *bool   `json:"disableSecurityGroupIngress,omitempty"`
 	ElbSecurityGroup            *string `json:"elbSecurityGroup,omitempty"`
 	// Spotinst cloud-config specs
 	SpotinstProduct     *string `json:"spotinstProduct,omitempty"`
 	SpotinstOrientation *string `json:"spotinstOrientation,omitempty"`
-	// AWSEBSCSIDriver is the config for the AWS EBS CSI driver
-	AWSEBSCSIDriver *AWSEBSCSIDriver `json:"awsEBSCSIDriver,omitempty"`
-	// GCPPDCSIDriver is the config for the GCP PD CSI driver
-	GCPPDCSIDriver *GCPPDCSIDriver `json:"gcpPDCSIDriver,omitempty"`
 }
 
-// AWSEBSCSIDriver is the config for the AWS EBS CSI driver
-type AWSEBSCSIDriver struct {
+// EBSCSIDriverSpec is the config for the AWS EBS CSI driver
+type EBSCSIDriverSpec struct {
 	// Enabled enables the AWS EBS CSI driver
 	// Default: false
 	Enabled *bool `json:"enabled,omitempty"`
@@ -904,8 +903,8 @@ type AWSEBSCSIDriver struct {
 	PodAnnotations map[string]string `json:"podAnnotations,omitempty"`
 }
 
-// GCPPDCSIDriver is the config for the GCP PD CSI driver
-type GCPPDCSIDriver struct {
+// PDCSIDriver is the config for the GCP PD CSI driver
+type PDCSIDriver struct {
 	// Enabled enables the GCP PD CSI driver
 	Enabled *bool `json:"enabled,omitempty"`
 }
@@ -918,28 +917,33 @@ type SnapshotControllerConfig struct {
 	InstallDefaultClass bool `json:"installDefaultClass,omitempty"`
 }
 
-// NodeTerminationHandlerConfig determines the node termination handler configuration.
-type NodeTerminationHandlerConfig struct {
+// NodeTerminationHandlerSpec determines the node termination handler configuration.
+type NodeTerminationHandlerSpec struct {
 	// Enabled enables the node termination handler.
 	// Default: true
 	Enabled *bool `json:"enabled,omitempty"`
 	// EnableSpotInterruptionDraining makes node termination handler drain nodes when spot interruption termination notice is received.
+	// Cannot be disabled in queue-processor mode.
 	// Default: true
 	EnableSpotInterruptionDraining *bool `json:"enableSpotInterruptionDraining,omitempty"`
 	// EnableScheduledEventDraining makes node termination handler drain nodes before the maintenance window starts for an EC2 instance scheduled event.
-	// Default: false
+	// Cannot be disabled in queue-processor mode.
+	// Default: true
 	EnableScheduledEventDraining *bool `json:"enableScheduledEventDraining,omitempty"`
-	// EnableRebalanceMonitoring makes node termination handler cordon nodes when the rebalance recommendation notice is received
+	// EnableRebalanceMonitoring makes node termination handler cordon nodes when the rebalance recommendation notice is received.
+	// In queue-processor mode, cannot be enabled without rebalance draining.
 	// Default: false
 	EnableRebalanceMonitoring *bool `json:"enableRebalanceMonitoring,omitempty"`
-	// EnableRebalanceDraining makes node termination handler drain nodes when the rebalance recommendation notice is received
+	// EnableRebalanceDraining makes node termination handler drain nodes when the rebalance recommendation notice is received.
 	// Default: false
 	EnableRebalanceDraining *bool `json:"enableRebalanceDraining,omitempty"`
 
 	// EnablePrometheusMetrics enables the "/metrics" endpoint.
+	// Default: false
 	EnablePrometheusMetrics *bool `json:"prometheusEnable,omitempty"`
 
 	// EnableSQSTerminationDraining enables queue-processor mode which drains nodes when an SQS termination event is received.
+	// Default: true
 	EnableSQSTerminationDraining *bool `json:"enableSQSTerminationDraining,omitempty"`
 
 	// ExcludeFromLoadBalancers makes node termination handler will mark for exclusion from load balancers before node are cordoned.
@@ -961,6 +965,10 @@ type NodeTerminationHandlerConfig struct {
 	Version *string `json:"version,omitempty"`
 }
 
+func (n *NodeTerminationHandlerSpec) IsQueueMode() bool {
+	return n != nil && n.Enabled != nil && *n.Enabled && (n.EnableSQSTerminationDraining == nil || *n.EnableSQSTerminationDraining)
+}
+
 // NodeProblemDetector determines the node problem detector configuration.
 type NodeProblemDetectorConfig struct {
 	// Enabled enables the NodeProblemDetector.
@@ -991,9 +999,9 @@ type ClusterAutoscalerConfig struct {
 	// Expander determines the strategy for which instance group gets expanded.
 	// Supported values: least-waste, most-pods, random, price, priority.
 	// The price expander is only supported on GCE.
-	// The priority expander requires additional configuration via a ConfigMap.
+	// By default, kOps will generate the priority expander ConfigMap based on the `autoscale` and `autoscalePriority` fields in the InstanceGroup specs.
 	// Default: least-waste
-	Expander *string `json:"expander,omitempty"`
+	Expander string `json:"expander,omitempty"`
 	// BalanceSimilarNodeGroups makes cluster autoscaler treat similar node groups as one.
 	// Default: false
 	BalanceSimilarNodeGroups *bool `json:"balanceSimilarNodeGroups,omitempty"`
@@ -1038,6 +1046,12 @@ type ClusterAutoscalerConfig struct {
 	// PodAnnotations are the annotations added to cluster autoscaler pods when they are created.
 	// Default: none
 	PodAnnotations map[string]string `json:"podAnnotations,omitempty"`
+	// CreatePriorityExpenderConfig makes kOps create the priority-expander ConfigMap
+	// Default: true
+	CreatePriorityExpenderConfig *bool `json:"createPriorityExpanderConfig,omitempty"`
+	// CustomPriorityExpanderConfig overides the priority-expander ConfigMap with the provided configuration. Any InstanceGroup configuration will be ignored if this is set.
+	// This could be useful in order to use regex on priorities configuration
+	CustomPriorityExpanderConfig map[string][]string `json:"customPriorityExpanderConfig,omitempty"`
 }
 
 // MetricsServerConfig determines the metrics server configuration.
@@ -1079,8 +1093,8 @@ type CertManagerConfig struct {
 	HostedZoneIDs []string `json:"hostedZoneIDs,omitempty"`
 }
 
-// AWSLoadBalancerControllerConfig determines the AWS LB controller configuration.
-type AWSLoadBalancerControllerConfig struct {
+// LoadBalancerControllerSpec determines the AWS LB controller configuration.
+type LoadBalancerControllerSpec struct {
 	// Enabled enables the loadbalancer controller.
 	// Default: false
 	Enabled *bool `json:"enabled,omitempty"`
