@@ -16,10 +16,24 @@ limitations under the License.
 
 package v1alpha2
 
-import "k8s.io/apimachinery/pkg/api/resource"
+import (
+	"k8s.io/apimachinery/pkg/api/resource"
+)
 
 // NetworkingSpec allows selection and configuration of a networking plugin
 type NetworkingSpec struct {
+	NetworkID              string              `json:"-"`
+	NetworkCIDR            string              `json:"-"`
+	AdditionalNetworkCIDRs []string            `json:"-"`
+	Subnets                []ClusterSubnetSpec `json:"-"`
+	TagSubnets             *bool               `json:"-"`
+	Topology               *TopologySpec       `json:"-"`
+	EgressProxy            *EgressProxySpec    `json:"-"`
+	NonMasqueradeCIDR      string              `json:"-"`
+	PodCIDR                string              `json:"-"`
+	ServiceClusterIPRange  string              `json:"-"`
+	IsolateControlPlane    *bool               `json:"-"`
+
 	Classic    *ClassicNetworkingSpec    `json:"classic,omitempty"`
 	Kubenet    *KubenetNetworkingSpec    `json:"kubenet,omitempty"`
 	External   *ExternalNetworkingSpec   `json:"external,omitempty"`
@@ -29,7 +43,7 @@ type NetworkingSpec struct {
 	Flannel    *FlannelNetworkingSpec    `json:"flannel,omitempty"`
 	Calico     *CalicoNetworkingSpec     `json:"calico,omitempty"`
 	Canal      *CanalNetworkingSpec      `json:"canal,omitempty"`
-	Kuberouter *KuberouterNetworkingSpec `json:"kuberouter,omitempty"`
+	KubeRouter *KuberouterNetworkingSpec `json:"kuberouter,omitempty"`
 	Romana     *RomanaNetworkingSpec     `json:"romana,omitempty"`
 	AmazonVPC  *AmazonVPCNetworkingSpec  `json:"amazonvpc,omitempty"`
 	Cilium     *CiliumNetworkingSpec     `json:"cilium,omitempty"`
@@ -37,6 +51,12 @@ type NetworkingSpec struct {
 	GCE        *GCENetworkingSpec        `json:"gce,omitempty"`
 }
 
+func (s *NetworkingSpec) IsEmpty() bool {
+	return s.Classic == nil && s.Kubenet == nil && s.External == nil && s.CNI == nil && s.Kopeio == nil &&
+		s.Weave == nil && s.Flannel == nil && s.Calico == nil && s.Canal == nil && s.KubeRouter == nil &&
+		s.Romana == nil && s.AmazonVPC == nil && s.Cilium == nil && s.LyftVPC == nil && s.GCE == nil
+}
+
 // ClassicNetworkingSpec is the specification of classic networking mode, integrated into kubernetes.
 // Support been removed since Kubernetes 1.4.
 type ClassicNetworkingSpec struct{}
@@ -108,8 +128,8 @@ type CalicoNetworkingSpec struct {
 	// AllowIPForwarding enable ip_forwarding setting within the container namespace.
 	// (default: false)
 	AllowIPForwarding bool `json:"allowIPForwarding,omitempty"`
-	// AWSSrcDstCheck enables/disables ENI source/destination checks (AWS only)
-	// Options: Disable (default), Enable, or DoNothing
+	// AWSSrcDstCheck enables/disables ENI source/destination checks (AWS IPv4 only)
+	// Options: Disable (default for IPv4), Enable, or DoNothing
 	AWSSrcDstCheck string `json:"awsSrcDstCheck,omitempty"`
 	// BPFEnabled enables the eBPF dataplane mode.
 	BPFEnabled bool `json:"bpfEnabled,omitempty"`
