@@ -36,7 +36,6 @@ import (
 	"k8s.io/apimachinery/pkg/util/validation/field"
 
 	"k8s.io/kops/pkg/apis/kops"
-	"k8s.io/kops/pkg/dns"
 	"k8s.io/kops/pkg/featureflag"
 	"k8s.io/kops/pkg/model/components"
 	"k8s.io/kops/pkg/model/iam"
@@ -81,7 +80,11 @@ func newValidateCluster(cluster *kops.Cluster) field.ErrorList {
 func validateClusterSpec(spec *kops.ClusterSpec, c *kops.Cluster, fieldPath *field.Path) field.ErrorList {
 	allErrs := field.ErrorList{}
 
-	allErrs = append(allErrs, validateSubnets(spec, fieldPath.Child("subnets"))...)
+	allErrs = append(allErrs, validateSubnets(spec, fieldPath.Child("networking", "subnets"))...)
+
+	if spec.CloudProvider.AWS != nil {
+		allErrs = append(allErrs, validateAWS(c, spec.CloudProvider.AWS, fieldPath.Child("cloudProvider", "aws"))...)
+	}
 
 	// SSHAccess
 	for i, cidr := range spec.SSHAccess {
@@ -95,7 +98,7 @@ func validateClusterSpec(spec *kops.ClusterSpec, c *kops.Cluster, fieldPath *fie
 	}
 
 	// KubernetesAPIAccess
-	for i, cidr := range spec.KubernetesAPIAccess {
+	for i, cidr := range spec.API.Access {
 		if strings.HasPrefix(cidr, "pl-") {
 			if spec.GetCloudProvider() != kops.CloudProviderAWS {
 				allErrs = append(allErrs, field.Invalid(fieldPath.Child("kubernetesAPIAccess").Index(i), cidr, "Prefix List ID only supported for AWS"))
@@ -117,12 +120,12 @@ func validateClusterSpec(spec *kops.ClusterSpec, c *kops.Cluster, fieldPath *fie
 	}
 
 	// AdditionalNetworkCIDRs
-	for i, cidr := range spec.AdditionalNetworkCIDRs {
-		allErrs = append(allErrs, validateCIDR(cidr, fieldPath.Child("additionalNetworkCIDRs").Index(i))...)
+	for i, cidr := range spec.Networking.AdditionalNetworkCIDRs {
+		allErrs = append(allErrs, validateCIDR(cidr, fieldPath.Child("networking", "additionalNetworkCIDRs").Index(i))...)
 	}
 
-	if spec.Topology != nil {
-		allErrs = append(allErrs, validateTopology(c, spec.Topology, fieldPath.Child("topology"))...)
+	if spec.Networking.Topology != nil {
+		allErrs = append(allErrs, validateTopology(c, spec.Networking.Topology, fieldPath.Child("networking", "topology"))...)
 	}
 
 	// UpdatePolicy
@@ -155,15 +158,13 @@ func validateClusterSpec(spec *kops.ClusterSpec, c *kops.Cluster, fieldPath *fie
 		allErrs = append(allErrs, validateKubelet(spec.Kubelet, c, fieldPath.Child("kubelet"))...)
 	}
 
-	if spec.MasterKubelet != nil {
-		allErrs = append(allErrs, validateKubelet(spec.MasterKubelet, c, fieldPath.Child("masterKubelet"))...)
+	if spec.ControlPlaneKubelet != nil {
+		allErrs = append(allErrs, validateKubelet(spec.ControlPlaneKubelet, c, fieldPath.Child("controlPlaneKubelet"))...)
 	}
 
-	if spec.Networking != nil {
-		allErrs = append(allErrs, validateNetworking(c, spec.Networking, fieldPath.Child("networking"))...)
-		if spec.Networking.Calico != nil {
-			allErrs = append(allErrs, validateNetworkingCalico(&c.Spec, spec.Networking.Calico, fieldPath.Child("networking", "calico"))...)
-		}
+	allErrs = append(allErrs, validateNetworking(c, &spec.Networking, fieldPath.Child("networking"))...)
+	if spec.Networking.Calico != nil {
+		allErrs = append(allErrs, validateNetworkingCalico(&c.Spec, spec.Networking.Calico, fieldPath.Child("networking", "calico"))...)
 	}
 
 	if spec.NodeAuthorization != nil {
@@ -178,18 +179,10 @@ func validateClusterSpec(spec *kops.ClusterSpec, c *kops.Cluster, fieldPath *fie
 		allErrs = append(allErrs, validateExternalDNS(c, spec.ExternalDNS, fieldPath.Child("externalDNS"))...)
 	}
 
-	if spec.NodeTerminationHandler != nil {
-		allErrs = append(allErrs, validateNodeTerminationHandler(c, spec.NodeTerminationHandler, fieldPath.Child("nodeTerminationHandler"))...)
-	}
-
 	if spec.MetricsServer != nil {
 		allErrs = append(allErrs, validateMetricsServer(c, spec.MetricsServer, fieldPath.Child("metricsServer"))...)
 	}
 
-	if spec.AWSLoadBalancerController != nil {
-		allErrs = append(allErrs, validateAWSLoadBalancerController(c, spec.AWSLoadBalancerController, fieldPath.Child("awsLoadBalanceController"))...)
-	}
-
 	if spec.SnapshotController != nil {
 		allErrs = append(allErrs, validateSnapshotController(c, spec.SnapshotController, fieldPath.Child("snapshotController"))...)
 	}
@@ -244,7 +237,7 @@ func validateClusterSpec(spec *kops.ClusterSpec, c *kops.Cluster, fieldPath *fie
 		allErrs = append(allErrs, validateRollingUpdate(spec.RollingUpdate, fieldPath.Child("rollingUpdate"), false)...)
 	}
 
-	if spec.API != nil && spec.API.LoadBalancer != nil {
+	if spec.API.LoadBalancer != nil {
 		lbSpec := spec.API.LoadBalancer
 		lbPath := fieldPath.Child("api", "loadBalancer")
 		if spec.GetCloudProvider() == kops.CloudProviderAWS {
@@ -254,13 +247,13 @@ func validateClusterSpec(spec *kops.ClusterSpec, c *kops.Cluster, fieldPath *fie
 				allErrs = append(allErrs, field.Forbidden(lbPath, "sslCertificate requires network loadbalancer. See https://github.com/kubernetes/kops/blob/master/permalinks/acm_nlb.md"))
 			}
 			if lbSpec.Class == kops.LoadBalancerClassNetwork && lbSpec.UseForInternalAPI && lbSpec.Type == kops.LoadBalancerTypeInternal {
-				allErrs = append(allErrs, field.Forbidden(lbPath, "useForInternalApi cannot be used with internal NLB due lack of hairpinning support"))
+				allErrs = append(allErrs, field.Forbidden(lbPath, "useForInternalAPI cannot be used with internal NLB due lack of hairpinning support"))
 			}
 		}
 
 		if lbSpec.Type == kops.LoadBalancerTypeInternal {
 			var hasPrivate bool
-			for _, subnet := range spec.Subnets {
+			for _, subnet := range spec.Networking.Subnets {
 				if subnet.Type == kops.SubnetTypePrivate {
 					hasPrivate = true
 					break
@@ -276,46 +269,53 @@ func validateClusterSpec(spec *kops.ClusterSpec, c *kops.Cluster, fieldPath *fie
 		allErrs = append(allErrs, validateCloudConfiguration(spec.CloudConfig, spec, fieldPath.Child("cloudConfig"))...)
 	}
 
-	if spec.WarmPool != nil {
-		if spec.GetCloudProvider() != kops.CloudProviderAWS {
-			allErrs = append(allErrs, field.Forbidden(field.NewPath("spec", "warmPool"), "warm pool only supported on AWS"))
-		} else {
-			allErrs = append(allErrs, validateWarmPool(spec.WarmPool, fieldPath.Child("warmPool"))...)
-		}
-	}
-
 	if spec.IAM != nil {
 		if spec.IAM.Legacy {
 			allErrs = append(allErrs, field.Forbidden(fieldPath.Child("iam", "legacy"), "legacy IAM permissions are no longer supported"))
 		}
 
 		if len(spec.IAM.ServiceAccountExternalPermissions) > 0 {
-			if spec.ServiceAccountIssuerDiscovery == nil || !spec.ServiceAccountIssuerDiscovery.EnableAWSOIDCProvider {
-				allErrs = append(allErrs, field.Forbidden(fieldPath.Child("iam", "serviceAccountExternalPermissions"), "serviceAccountExternalPermissions requires AWS OIDC Provider to be enabled"))
-			}
 			allErrs = append(allErrs, validateSAExternalPermissions(spec.IAM.ServiceAccountExternalPermissions, fieldPath.Child("iam", "serviceAccountExternalPermissions"))...)
 		}
 	}
 
 	if spec.Karpenter != nil && spec.Karpenter.Enabled {
-		if !featureflag.Karpenter.Enabled() {
-			allErrs = append(allErrs, field.Forbidden(fieldPath.Child("karpenter", "enabled"), "karpenter requires the Karpenter feature flag"))
+		fldPath := fieldPath.Child("karpenter", "enabled")
+		if !fi.ValueOf(spec.IAM.UseServiceAccountExternalPermissions) {
+			allErrs = append(allErrs, field.Forbidden(fldPath, "Karpenter requires that service accounts use external permissions"))
 		}
-		if c.IsKubernetesLT("1.21") {
-			allErrs = append(allErrs, field.Forbidden(fieldPath.Child("karpenter", "enabled"), "karpenter requires Kubernetes 1.21 or greater"))
+		if !featureflag.Karpenter.Enabled() {
+			allErrs = append(allErrs, field.Forbidden(fldPath, "karpenter requires the Karpenter feature flag"))
 		}
 	}
 
-	if spec.PodIdentityWebhook != nil && spec.PodIdentityWebhook.Enabled {
-		allErrs = append(allErrs, validatePodIdentityWebhook(c, spec.PodIdentityWebhook, fieldPath.Child("podIdentityWebhook"))...)
-	}
-	if spec.CertManager != nil && fi.BoolValue(spec.CertManager.Enabled) {
+	if spec.CertManager != nil && fi.ValueOf(spec.CertManager.Enabled) {
 		allErrs = append(allErrs, validateCertManager(c, spec.CertManager, fieldPath.Child("certManager"))...)
 	}
 
 	return allErrs
 }
 
+func validateAWS(c *kops.Cluster, aws *kops.AWSSpec, path *field.Path) (allErrs field.ErrorList) {
+	if aws.NodeTerminationHandler != nil {
+		allErrs = append(allErrs, validateNodeTerminationHandler(c, aws.NodeTerminationHandler, path.Child("nodeTerminationHandler"))...)
+	}
+
+	if aws.LoadBalancerController != nil {
+		allErrs = append(allErrs, validateAWSLoadBalancerController(c, aws.LoadBalancerController, path.Child("awsLoadBalanceController"))...)
+	}
+
+	if aws.WarmPool != nil {
+		allErrs = append(allErrs, validateWarmPool(aws.WarmPool, path.Child("warmPool"))...)
+	}
+
+	if aws.PodIdentityWebhook != nil && aws.PodIdentityWebhook.Enabled {
+		allErrs = append(allErrs, validatePodIdentityWebhook(c, aws.PodIdentityWebhook, path.Child("podIdentityWebhook"))...)
+	}
+
+	return allErrs
+}
+
 func validateSAExternalPermissions(externalPermissions []kops.ServiceAccountExternalPermission, path *field.Path) (allErrs field.ErrorList) {
 	if len(externalPermissions) == 0 {
 		return allErrs
@@ -404,10 +404,10 @@ func validateIPv6CIDR(cidr string, fieldPath *field.Path) field.ErrorList {
 func validateTopology(c *kops.Cluster, topology *kops.TopologySpec, fieldPath *field.Path) field.ErrorList {
 	allErrs := field.ErrorList{}
 
-	if topology.Masters == "" {
-		allErrs = append(allErrs, field.Required(fieldPath.Child("masters"), ""))
+	if topology.ControlPlane == "" {
+		allErrs = append(allErrs, field.Required(fieldPath.Child("controlPlane"), ""))
 	} else {
-		allErrs = append(allErrs, IsValidValue(fieldPath.Child("masters"), &topology.Masters, kops.SupportedTopologies)...)
+		allErrs = append(allErrs, IsValidValue(fieldPath.Child("controlPlane"), &topology.ControlPlane, kops.SupportedTopologies)...)
 	}
 
 	if topology.Nodes == "" {
@@ -421,21 +421,18 @@ func validateTopology(c *kops.Cluster, topology *kops.TopologySpec, fieldPath *f
 	}
 
 	if topology.Bastion != nil {
-		bastion := topology.Bastion
-		if topology.Masters == kops.TopologyPublic || topology.Nodes == kops.TopologyPublic {
-			allErrs = append(allErrs, field.Forbidden(fieldPath.Child("bastion"), "bastion requires masters and nodes to have private topology"))
-		}
-		if bastion.IdleTimeoutSeconds != nil && *bastion.IdleTimeoutSeconds <= 0 {
-			allErrs = append(allErrs, field.Invalid(fieldPath.Child("bastion", "idleTimeoutSeconds"), *bastion.IdleTimeoutSeconds, "bastion idleTimeoutSeconds should be greater than zero"))
-		}
-		if bastion.IdleTimeoutSeconds != nil && *bastion.IdleTimeoutSeconds > 3600 {
-			allErrs = append(allErrs, field.Invalid(fieldPath.Child("bastion", "idleTimeoutSeconds"), *bastion.IdleTimeoutSeconds, "bastion idleTimeoutSeconds cannot be greater than one hour"))
+		if topology.ControlPlane == kops.TopologyPublic || topology.Nodes == kops.TopologyPublic {
+			allErrs = append(allErrs, field.Forbidden(fieldPath.Child("bastion"), "bastion requires control plane and nodes to have private topology"))
 		}
 	}
 
-	if topology.DNS != nil {
-		value := string(topology.DNS.Type)
+	if topology.DNS != "" {
+		cloud := c.Spec.GetCloudProvider()
+		value := string(topology.DNS)
 		allErrs = append(allErrs, IsValidValue(fieldPath.Child("dns", "type"), &value, kops.SupportedDnsTypes)...)
+		if value == string(kops.DNSTypeNone) && cloud != kops.CloudProviderHetzner && cloud != kops.CloudProviderAWS && cloud != kops.CloudProviderGCE && cloud != kops.CloudProviderOpenstack {
+			allErrs = append(allErrs, field.Invalid(fieldPath.Child("dns", "type"), &value, fmt.Sprintf("not supported for %q", c.Spec.GetCloudProvider())))
+		}
 	}
 
 	return allErrs
@@ -444,7 +441,7 @@ func validateTopology(c *kops.Cluster, topology *kops.TopologySpec, fieldPath *f
 func validateSubnets(cluster *kops.ClusterSpec, fieldPath *field.Path) field.ErrorList {
 	allErrs := field.ErrorList{}
 
-	subnets := cluster.Subnets
+	subnets := cluster.Networking.Subnets
 
 	// cannot be empty
 	if len(subnets) == 0 {
@@ -470,9 +467,9 @@ func validateSubnets(cluster *kops.ClusterSpec, fieldPath *field.Path) field.Err
 
 	// cannot mix subnets with specified ID and without specified id
 	if len(subnets) > 0 {
-		hasID := subnets[0].ProviderID != ""
+		hasID := subnets[0].ID != ""
 		for i := range subnets {
-			if (subnets[i].ProviderID != "") != hasID {
+			if (subnets[i].ID != "") != hasID {
 				allErrs = append(allErrs, field.Forbidden(fieldPath.Index(i).Child("id"), "cannot mix subnets with specified ID and unspecified ID"))
 			}
 		}
@@ -517,7 +514,7 @@ func validateSubnet(subnet *kops.ClusterSubnetSpec, c *kops.ClusterSpec, fieldPa
 		}
 	}
 
-	allErrs = append(allErrs, IsValidValue(fieldPath.Child("type"), fi.String(string(subnet.Type)), []string{
+	allErrs = append(allErrs, IsValidValue(fieldPath.Child("type"), fi.PtrTo(string(subnet.Type)), []string{
 		string(kops.SubnetTypePublic),
 		string(kops.SubnetTypePrivate),
 		string(kops.SubnetTypeDualStack),
@@ -595,8 +592,12 @@ func validateKubeAPIServer(v *kops.KubeAPIServerConfig, c *kops.Cluster, fldPath
 
 	if len(v.AdmissionControl) > 0 {
 		if len(v.DisableAdmissionPlugins) > 0 {
-			allErrs = append(allErrs, field.Forbidden(fldPath.Child("disableAdmissionPlugins"),
-				"disableAdmissionPlugins is mutually exclusive, you cannot use both admissionControl and disableAdmissionPlugins together"))
+			allErrs = append(allErrs, field.Forbidden(fldPath.Child("admissionControl"),
+				"admissionControl is mutually exclusive with disableAdmissionPlugins˚"))
+		}
+
+		if c.IsKubernetesGTE("1.26") {
+			allErrs = append(allErrs, field.Forbidden(fldPath.Child("admissionControl"), "admissionControl has been replaced with enableAdmissionPlugins"))
 		}
 	}
 
@@ -680,7 +681,7 @@ func validateKubeProxy(k *kops.KubeProxyConfig, fldPath *field.Path) field.Error
 
 	for i, x := range k.IPVSExcludeCIDRs {
 		if _, _, err := net.ParseCIDR(x); err != nil {
-			allErrs = append(allErrs, field.Invalid(fldPath.Child("ipvsExcludeCidrs").Index(i), x, "Invalid network CIDR"))
+			allErrs = append(allErrs, field.Invalid(fldPath.Child("ipvsExcludeCIDRs").Index(i), x, "Invalid network CIDR"))
 		}
 	}
 
@@ -740,9 +741,7 @@ func validateKubelet(k *kops.KubeletConfigSpec, c *kops.Cluster, kubeletPath *fi
 		}
 
 		if k.EnableCadvisorJsonEndpoints != nil {
-			if c.IsKubernetesGTE("1.21") {
-				allErrs = append(allErrs, field.Forbidden(kubeletPath.Child("enableCadvisorJsonEndpoints"), "enableCadvisorJsonEndpoints requires Kubernetes 1.18-1.20"))
-			}
+			allErrs = append(allErrs, field.Forbidden(kubeletPath.Child("enableCadvisorJsonEndpoints"), "enableCadvisorJsonEndpoints requires Kubernetes 1.18-1.20"))
 		}
 
 		if k.LogFormat != "" {
@@ -798,6 +797,10 @@ func validateNetworking(cluster *kops.Cluster, v *kops.NetworkingSpec, fldPath *
 		if optionTaken {
 			allErrs = append(allErrs, field.Forbidden(fldPath.Child("external"), "only one networking option permitted"))
 		}
+
+		if cluster.IsKubernetesGTE("1.26") {
+			allErrs = append(allErrs, field.Forbidden(fldPath.Child("external"), "external is not supported for Kubernetes >= 1.26"))
+		}
 		optionTaken = true
 	}
 
@@ -854,9 +857,9 @@ func validateNetworking(cluster *kops.Cluster, v *kops.NetworkingSpec, fldPath *
 		allErrs = append(allErrs, validateNetworkingCanal(cluster, v.Canal, fldPath.Child("canal"))...)
 	}
 
-	if v.Kuberouter != nil {
+	if v.KubeRouter != nil {
 		if optionTaken {
-			allErrs = append(allErrs, field.Forbidden(fldPath.Child("kuberouter"), "only one networking option permitted"))
+			allErrs = append(allErrs, field.Forbidden(fldPath.Child("kubeRouter"), "only one networking option permitted"))
 		}
 		if c.KubeProxy != nil && (c.KubeProxy.Enabled == nil || *c.KubeProxy.Enabled) {
 			allErrs = append(allErrs, field.Forbidden(fldPath.Root().Child("spec", "kubeProxy", "enabled"), "kube-router requires kubeProxy to be disabled"))
@@ -864,7 +867,7 @@ func validateNetworking(cluster *kops.Cluster, v *kops.NetworkingSpec, fldPath *
 		optionTaken = true
 
 		if cluster.Spec.IsIPv6Only() {
-			allErrs = append(allErrs, field.Forbidden(fldPath.Child("kuberouter"), "kube-router does not support IPv6"))
+			allErrs = append(allErrs, field.Forbidden(fldPath.Child("kuberRouter"), "kube-router does not support IPv6"))
 		}
 	}
 
@@ -874,16 +877,16 @@ func validateNetworking(cluster *kops.Cluster, v *kops.NetworkingSpec, fldPath *
 
 	if v.AmazonVPC != nil {
 		if optionTaken {
-			allErrs = append(allErrs, field.Forbidden(fldPath.Child("amazonvpc"), "only one networking option permitted"))
+			allErrs = append(allErrs, field.Forbidden(fldPath.Child("amazonVPC"), "only one networking option permitted"))
 		}
 		optionTaken = true
 
 		if c.GetCloudProvider() != kops.CloudProviderAWS {
-			allErrs = append(allErrs, field.Forbidden(fldPath.Child("amazonvpc"), "amazon-vpc-routed-eni networking is supported only in AWS"))
+			allErrs = append(allErrs, field.Forbidden(fldPath.Child("amazonVPC"), "amazon-vpc-routed-eni networking is supported only in AWS"))
 		}
 
 		if cluster.Spec.IsIPv6Only() {
-			allErrs = append(allErrs, field.Forbidden(fldPath.Child("amazonvpc"), "amazon-vpc-routed-eni networking does not support IPv6"))
+			allErrs = append(allErrs, field.Forbidden(fldPath.Child("amazonVPC"), "amazon-vpc-routed-eni networking does not support IPv6"))
 		}
 
 	}
@@ -976,11 +979,11 @@ func validateNetworkingCilium(cluster *kops.Cluster, v *kops.CiliumNetworkingSpe
 			allErrs = append(allErrs, field.Invalid(versionFld, v.Version, "Could not parse as semantic version"))
 		}
 
-		if version.Minor != 11 && version.Patch < 5 {
-			allErrs = append(allErrs, field.Invalid(versionFld, v.Version, "Only version 1.11 with patch version 5 or higher is supported"))
+		if version.Minor != 12 {
+			allErrs = append(allErrs, field.Invalid(versionFld, v.Version, "Only version 1.12 is supported"))
 		}
 
-		if v.Hubble != nil && fi.BoolValue(v.Hubble.Enabled) {
+		if v.Hubble != nil && fi.ValueOf(v.Hubble.Enabled) {
 			if !components.IsCertManagerEnabled(cluster) {
 				allErrs = append(allErrs, field.Forbidden(fldPath.Child("hubble", "enabled"), "Hubble requires that cert manager is enabled"))
 			}
@@ -1015,7 +1018,15 @@ func validateNetworkingCilium(cluster *kops.Cluster, v *kops.CiliumNetworkingSpe
 		allErrs = append(allErrs, IsValidValue(fldPath.Child("bpfLBAlgorithm"), &v.BPFLBAlgorithm, []string{"random", "maglev"})...)
 	}
 
+	if v.EnableEncryption && c.IsIPv6Only() {
+		allErrs = append(allErrs, field.Forbidden(fldPath.Child("enableEncryption"), "encryption is not supported on IPv6 clusters"))
+	}
+
 	if v.EncryptionType != "" {
+		if !v.EnableEncryption {
+			allErrs = append(allErrs, field.Forbidden(fldPath.Child("encryptionType"), "encryptionType requires enableEncryption"))
+		}
+
 		encryptionType := string(v.EncryptionType)
 		allErrs = append(allErrs, IsValidValue(fldPath.Child("encryptionType"), &encryptionType, []string{"ipsec", "wireguard"})...)
 
@@ -1023,13 +1034,13 @@ func validateNetworkingCilium(cluster *kops.Cluster, v *kops.CiliumNetworkingSpe
 			// Cilium with Wireguard integration follow-up --> https://github.com/cilium/cilium/issues/15462.
 			// The following rule of validation should be deleted as this combination
 			// will be supported on future releases of Cilium (>= v1.11.0).
-			if fi.BoolValue(v.EnableL7Proxy) {
+			if fi.ValueOf(v.EnableL7Proxy) {
 				allErrs = append(allErrs, field.Forbidden(fldPath.Child("enableL7Proxy"), "L7 proxy cannot be enabled if wireguard is enabled."))
 			}
 		}
 	}
 
-	if fi.BoolValue(v.EnableL7Proxy) && v.InstallIptablesRules != nil && !*v.InstallIptablesRules {
+	if fi.ValueOf(v.EnableL7Proxy) && v.InstallIptablesRules != nil && !*v.InstallIptablesRules {
 		allErrs = append(allErrs, field.Forbidden(fldPath.Child("enableL7Proxy"), "Cilium L7 Proxy requires installIptablesRules."))
 	}
 
@@ -1041,8 +1052,8 @@ func validateNetworkingCilium(cluster *kops.Cluster, v *kops.CiliumNetworkingSpe
 			if c.GetCloudProvider() != kops.CloudProviderAWS {
 				allErrs = append(allErrs, field.Forbidden(fldPath.Child("ipam"), "Cilum ENI IPAM is supported only in AWS"))
 			}
-			if v.Masquerade != nil && *v.Masquerade {
-				allErrs = append(allErrs, field.Forbidden(fldPath.Child("masquerade"), "Masquerade must be disabled when ENI IPAM is used"))
+			if v.Masquerade != nil && !*v.Masquerade {
+				allErrs = append(allErrs, field.Forbidden(fldPath.Child("masquerade"), "Masquerade must be enabled when ENI IPAM is used"))
 			}
 			if c.IsIPv6Only() {
 				allErrs = append(allErrs, field.Forbidden(fldPath.Child("ipam"), "Cilium ENI IPAM does not support IPv6"))
@@ -1085,7 +1096,7 @@ func validateAdditionalPolicy(role string, policy string, fldPath *field.Path) f
 
 	var valid []string
 	for _, r := range kops.AllInstanceGroupRoles {
-		valid = append(valid, strings.ToLower(string(r)))
+		valid = append(valid, r.ToLowerString())
 	}
 	allErrs = append(allErrs, IsValidValue(fldPath, &role, valid)...)
 
@@ -1113,7 +1124,7 @@ func validateExternalPolicies(role string, policies []string, fldPath *field.Pat
 
 	var valid []string
 	for _, r := range kops.AllInstanceGroupRoles {
-		valid = append(valid, strings.ToLower(string(r)))
+		valid = append(valid, r.ToLowerString())
 	}
 	allErrs = append(allErrs, IsValidValue(fldPath, &role, valid)...)
 
@@ -1141,7 +1152,7 @@ func validateEtcdClusterSpec(spec kops.EtcdClusterSpec, c *kops.Cluster, fieldPa
 		allErrs = append(allErrs, field.Required(fieldPath.Child("etcdMembers"), "No members defined in etcd cluster"))
 	} else if (len(spec.Members) % 2) == 0 {
 		// Not technically a requirement, but doesn't really make sense to allow
-		allErrs = append(allErrs, field.Invalid(fieldPath.Child("etcdMembers"), len(spec.Members), "Should be an odd number of master-zones for quorum. Use --zones and --master-zones to declare node zones and master zones separately"))
+		allErrs = append(allErrs, field.Invalid(fieldPath.Child("etcdMembers"), len(spec.Members), "Should be an odd number of control-plane-zones for quorum. Use --zones and --control-plane-zones to declare node zones and control-plane zones separately"))
 	}
 	allErrs = append(allErrs, validateEtcdVersion(spec, fieldPath, nil)...)
 	for i, m := range spec.Members {
@@ -1216,7 +1227,7 @@ func validateEtcdMemberSpec(spec kops.EtcdMemberSpec, fieldPath *field.Path) fie
 		allErrs = append(allErrs, field.Required(fieldPath.Child("name"), "etcdMember did not have name"))
 	}
 
-	if fi.StringValue(spec.InstanceGroup) == "" {
+	if fi.ValueOf(spec.InstanceGroup) == "" {
 		allErrs = append(allErrs, field.Required(fieldPath.Child("instanceGroup"), "etcdMember did not have instanceGroup"))
 	}
 
@@ -1227,12 +1238,16 @@ func validateNetworkingCalico(c *kops.ClusterSpec, v *kops.CalicoNetworkingSpec,
 	allErrs := field.ErrorList{}
 
 	if v.AWSSrcDstCheck != "" {
-		valid := []string{"Enable", "Disable", "DoNothing"}
-		allErrs = append(allErrs, IsValidValue(fldPath.Child("awsSrcDstCheck"), &v.AWSSrcDstCheck, valid)...)
+		if c.IsIPv6Only() && v.AWSSrcDstCheck != "DoNothing" {
+			allErrs = append(allErrs, field.Forbidden(fldPath.Child("awsSrcDstCheck"), "awsSrcDstCheck may only be \"DoNothing\" for IPv6 clusters"))
+		} else {
+			valid := []string{"Enable", "Disable", "DoNothing"}
+			allErrs = append(allErrs, IsValidValue(fldPath.Child("awsSrcDstCheck"), &v.AWSSrcDstCheck, valid)...)
+		}
 	}
 
 	if v.CrossSubnet != nil {
-		if fi.BoolValue(v.CrossSubnet) && v.AWSSrcDstCheck != "Disable" {
+		if fi.ValueOf(v.CrossSubnet) && v.AWSSrcDstCheck != "Disable" {
 			field.Invalid(fldPath.Child("crossSubnet"), v.CrossSubnet, "crossSubnet is deprecated, use awsSrcDstCheck instead")
 		}
 	}
@@ -1307,6 +1322,10 @@ func validateNetworkingCalico(c *kops.ClusterSpec, v *kops.CalicoNetworkingSpec,
 				fmt.Sprintf("Unable to set number of Typha replicas to less than 0, you've specified %d", v.TyphaReplicas)))
 	}
 
+	if v.WireguardEnabled && c.IsIPv6Only() {
+		allErrs = append(allErrs, field.Forbidden(fldPath.Child("wireguardEnabled"), `WireGuard is not supported on IPv6 clusters`))
+	}
+
 	return allErrs
 }
 
@@ -1408,13 +1427,13 @@ func validateContainerdConfig(spec *kops.ClusterSpec, config *kops.ContainerdCon
 
 	if config.Packages != nil {
 		if config.Packages.UrlAmd64 != nil && config.Packages.HashAmd64 != nil {
-			u := fi.StringValue(config.Packages.UrlAmd64)
+			u := fi.ValueOf(config.Packages.UrlAmd64)
 			_, err := url.Parse(u)
 			if err != nil {
 				allErrs = append(allErrs, field.Invalid(fldPath.Child("packageUrl"), config.Packages.UrlAmd64,
 					fmt.Sprintf("cannot parse package URL: %v", err)))
 			}
-			h := fi.StringValue(config.Packages.HashAmd64)
+			h := fi.ValueOf(config.Packages.HashAmd64)
 			if len(h) > 64 {
 				allErrs = append(allErrs, field.Invalid(fldPath.Child("packageHash"), config.Packages.HashAmd64,
 					"Package hash must be 64 characters long"))
@@ -1428,13 +1447,13 @@ func validateContainerdConfig(spec *kops.ClusterSpec, config *kops.ContainerdCon
 		}
 
 		if config.Packages.UrlArm64 != nil && config.Packages.HashArm64 != nil {
-			u := fi.StringValue(config.Packages.UrlArm64)
+			u := fi.ValueOf(config.Packages.UrlArm64)
 			_, err := url.Parse(u)
 			if err != nil {
 				allErrs = append(allErrs, field.Invalid(fldPath.Child("packageUrlArm64"), config.Packages.UrlArm64,
 					fmt.Sprintf("cannot parse package URL: %v", err)))
 			}
-			h := fi.StringValue(config.Packages.HashArm64)
+			h := fi.ValueOf(config.Packages.HashArm64)
 			if len(h) > 64 {
 				allErrs = append(allErrs, field.Invalid(fldPath.Child("packageHashArm64"), config.Packages.HashArm64,
 					"Package hash must be 64 characters long"))
@@ -1475,13 +1494,13 @@ func validateDockerConfig(config *kops.DockerConfig, fldPath *field.Path) field.
 
 	if config.Packages != nil {
 		if config.Packages.UrlAmd64 != nil && config.Packages.HashAmd64 != nil {
-			u := fi.StringValue(config.Packages.UrlAmd64)
+			u := fi.ValueOf(config.Packages.UrlAmd64)
 			_, err := url.Parse(u)
 			if err != nil {
 				allErrs = append(allErrs, field.Invalid(fldPath.Child("packageUrl"), config.Packages.UrlAmd64,
 					fmt.Sprintf("unable parse package URL string: %v", err)))
 			}
-			h := fi.StringValue(config.Packages.HashAmd64)
+			h := fi.ValueOf(config.Packages.HashAmd64)
 			if len(h) > 64 {
 				allErrs = append(allErrs, field.Invalid(fldPath.Child("packageHash"), config.Packages.HashAmd64,
 					"Package hash must be 64 characters long"))
@@ -1495,13 +1514,13 @@ func validateDockerConfig(config *kops.DockerConfig, fldPath *field.Path) field.
 		}
 
 		if config.Packages.UrlArm64 != nil && config.Packages.HashArm64 != nil {
-			u := fi.StringValue(config.Packages.UrlArm64)
+			u := fi.ValueOf(config.Packages.UrlArm64)
 			_, err := url.Parse(u)
 			if err != nil {
 				allErrs = append(allErrs, field.Invalid(fldPath.Child("packageUrlArm64"), config.Packages.UrlArm64,
 					fmt.Sprintf("unable parse package URL string: %v", err)))
 			}
-			h := fi.StringValue(config.Packages.HashArm64)
+			h := fi.ValueOf(config.Packages.HashArm64)
 			if len(h) > 64 {
 				allErrs = append(allErrs, field.Invalid(fldPath.Child("packageHashArm64"), config.Packages.HashArm64,
 					"Package hash must be 64 characters long"))
@@ -1527,7 +1546,7 @@ func validateDockerConfig(config *kops.DockerConfig, fldPath *field.Path) field.
 }
 
 func validateNvidiaConfig(spec *kops.ClusterSpec, nvidia *kops.NvidiaGPUConfig, fldPath *field.Path, inClusterConfig bool) (allErrs field.ErrorList) {
-	if !fi.BoolValue(nvidia.Enabled) {
+	if !fi.ValueOf(nvidia.Enabled) {
 		return allErrs
 	}
 	if spec.GetCloudProvider() != kops.CloudProviderAWS && spec.GetCloudProvider() != kops.CloudProviderOpenstack {
@@ -1542,7 +1561,7 @@ func validateNvidiaConfig(spec *kops.ClusterSpec, nvidia *kops.NvidiaGPUConfig,
 	return allErrs
 }
 
-func validateRollingUpdate(rollingUpdate *kops.RollingUpdate, fldpath *field.Path, onMasterInstanceGroup bool) field.ErrorList {
+func validateRollingUpdate(rollingUpdate *kops.RollingUpdate, fldpath *field.Path, onControlPlaneInstanceGroup bool) field.ErrorList {
 	allErrs := field.ErrorList{}
 	var err error
 	unavailable := 1
@@ -1562,8 +1581,8 @@ func validateRollingUpdate(rollingUpdate *kops.RollingUpdate, fldpath *field.Pat
 			allErrs = append(allErrs, field.Invalid(fldpath.Child("maxSurge"), rollingUpdate.MaxSurge,
 				fmt.Sprintf("Unable to parse: %v", err)))
 		}
-		if onMasterInstanceGroup && surge != 0 {
-			allErrs = append(allErrs, field.Forbidden(fldpath.Child("maxSurge"), "Cannot surge instance groups with role \"Master\""))
+		if onControlPlaneInstanceGroup && surge != 0 {
+			allErrs = append(allErrs, field.Forbidden(fldpath.Child("maxSurge"), "Cannot surge instance groups with role \"ControlPlane\""))
 		} else if surge < 0 {
 			allErrs = append(allErrs, field.Invalid(fldpath.Child("maxSurge"), rollingUpdate.MaxSurge, "Cannot be negative"))
 		}
@@ -1585,13 +1604,13 @@ func validateNodeLocalDNS(spec *kops.ClusterSpec, fldpath *field.Path) field.Err
 		}
 	}
 
-	if (spec.KubeProxy != nil && spec.KubeProxy.ProxyMode == "ipvs") || (spec.Networking != nil && spec.Networking.Cilium != nil) {
+	if (spec.KubeProxy != nil && spec.KubeProxy.ProxyMode == "ipvs") || spec.Networking.Cilium != nil {
 		if spec.Kubelet != nil && spec.Kubelet.ClusterDNS != "" && spec.Kubelet.ClusterDNS != spec.KubeDNS.NodeLocalDNS.LocalIP {
 			allErrs = append(allErrs, field.Forbidden(fldpath.Child("kubelet", "clusterDNS"), "Kubelet ClusterDNS must be set to the default IP address for LocalIP"))
 		}
 
-		if spec.MasterKubelet != nil && spec.MasterKubelet.ClusterDNS != "" && spec.MasterKubelet.ClusterDNS != spec.KubeDNS.NodeLocalDNS.LocalIP {
-			allErrs = append(allErrs, field.Forbidden(fldpath.Child("kubelet", "clusterDNS"), "MasterKubelet ClusterDNS must be set to the default IP address for LocalIP"))
+		if spec.ControlPlaneKubelet != nil && spec.ControlPlaneKubelet.ClusterDNS != "" && spec.ControlPlaneKubelet.ClusterDNS != spec.KubeDNS.NodeLocalDNS.LocalIP {
+			allErrs = append(allErrs, field.Forbidden(fldpath.Child("kubelet", "clusterDNS"), "ControlPlaneKubelet ClusterDNS must be set to the default IP address for LocalIP"))
 		}
 	}
 
@@ -1599,9 +1618,11 @@ func validateNodeLocalDNS(spec *kops.ClusterSpec, fldpath *field.Path) field.Err
 }
 
 func validateClusterAutoscaler(cluster *kops.Cluster, spec *kops.ClusterAutoscalerConfig, fldPath *field.Path) (allErrs field.ErrorList) {
-	allErrs = append(allErrs, IsValidValue(fldPath.Child("expander"), spec.Expander, []string{"least-waste", "random", "most-pods", "price", "priority"})...)
+	if spec.Expander != "" {
+		allErrs = append(allErrs, IsValidValue(fldPath.Child("expander"), &spec.Expander, []string{"least-waste", "random", "most-pods", "price", "priority"})...)
+	}
 
-	if fi.StringValue(spec.Expander) == "price" && cluster.Spec.CloudProvider.GCE == nil {
+	if spec.Expander == "price" && cluster.Spec.CloudProvider.GCE == nil {
 		allErrs = append(allErrs, field.Forbidden(fldPath.Child("expander"), "Cluster autoscaler price expander is only supported on GCE"))
 	}
 
@@ -1622,24 +1643,20 @@ func validateExternalDNS(cluster *kops.Cluster, spec *kops.ExternalDNSConfig, fl
 	}
 
 	if spec.Provider == kops.ExternalDNSProviderExternalDNS {
-		if dns.IsGossipHostname(cluster.Spec.MasterInternalName) {
-			allErrs = append(allErrs, field.Forbidden(fldPath.Child("provider"), "external-dns does not support gossip clusters"))
+		if cluster.IsGossip() || cluster.UsesNoneDNS() {
+			allErrs = append(allErrs, field.Forbidden(fldPath.Child("provider"), "external-dns requires public or private DNS topology"))
+		}
+		if cluster.Spec.IsIPv6Only() {
+			allErrs = append(allErrs, field.Forbidden(fldPath.Child("provider"), "external-dns does not support IPv6 clusters"))
 		}
 	}
 
 	return allErrs
 }
 
-func validateNodeTerminationHandler(cluster *kops.Cluster, spec *kops.NodeTerminationHandlerConfig, fldPath *field.Path) (allErrs field.ErrorList) {
-	if cluster.Spec.GetCloudProvider() != kops.CloudProviderAWS {
-		allErrs = append(allErrs, field.Forbidden(fldPath, "Node Termination Handler supports only AWS"))
-	}
-	return allErrs
-}
-
 func validateMetricsServer(cluster *kops.Cluster, spec *kops.MetricsServerConfig, fldPath *field.Path) (allErrs field.ErrorList) {
-	if spec != nil && fi.BoolValue(spec.Enabled) {
-		if !fi.BoolValue(spec.Insecure) && !components.IsCertManagerEnabled(cluster) {
+	if spec != nil && fi.ValueOf(spec.Enabled) {
+		if !fi.ValueOf(spec.Insecure) && !components.IsCertManagerEnabled(cluster) {
 			allErrs = append(allErrs, field.Forbidden(fldPath.Child("insecure"), "Secure metrics server requires that cert manager is enabled"))
 		}
 	}
@@ -1647,8 +1664,23 @@ func validateMetricsServer(cluster *kops.Cluster, spec *kops.MetricsServerConfig
 	return allErrs
 }
 
-func validateAWSLoadBalancerController(cluster *kops.Cluster, spec *kops.AWSLoadBalancerControllerConfig, fldPath *field.Path) (allErrs field.ErrorList) {
-	if spec != nil && fi.BoolValue(spec.Enabled) {
+func validateNodeTerminationHandler(cluster *kops.Cluster, spec *kops.NodeTerminationHandlerSpec, fldPath *field.Path) (allErrs field.ErrorList) {
+	if spec.IsQueueMode() {
+		if spec.EnableSpotInterruptionDraining != nil && !*spec.EnableSpotInterruptionDraining {
+			allErrs = append(allErrs, field.Forbidden(fldPath.Child("enableSpotInterruptionDraining"), "spot interruption draining cannot be disabled in Queue Processor mode"))
+		}
+		if spec.EnableScheduledEventDraining != nil && !*spec.EnableScheduledEventDraining {
+			allErrs = append(allErrs, field.Forbidden(fldPath.Child("enableScheduledEventDraining"), "scheduled event draining cannot be disabled in Queue Processor mode"))
+		}
+		if !fi.ValueOf(spec.EnableRebalanceDraining) && fi.ValueOf(spec.EnableRebalanceMonitoring) {
+			allErrs = append(allErrs, field.Forbidden(fldPath.Child("enableRebalanceMonitoring"), "rebalance events can only drain in Queue Processor mode"))
+		}
+	}
+	return allErrs
+}
+
+func validateAWSLoadBalancerController(cluster *kops.Cluster, spec *kops.LoadBalancerControllerSpec, fldPath *field.Path) (allErrs field.ErrorList) {
+	if spec != nil && fi.ValueOf(spec.Enabled) {
 		if !components.IsCertManagerEnabled(cluster) {
 			allErrs = append(allErrs, field.Forbidden(fldPath, "AWS Load Balancer Controller requires that cert manager is enabled"))
 		}
@@ -1682,7 +1714,7 @@ func validateWarmPool(warmPool *kops.WarmPoolSpec, fldPath *field.Path) (allErrs
 }
 
 func validateSnapshotController(cluster *kops.Cluster, spec *kops.SnapshotControllerConfig, fldPath *field.Path) (allErrs field.ErrorList) {
-	if spec != nil && fi.BoolValue(spec.Enabled) {
+	if spec != nil && fi.ValueOf(spec.Enabled) {
 		if !components.IsCertManagerEnabled(cluster) {
 			allErrs = append(allErrs, field.Forbidden(fldPath.Child("enabled"), "Snapshot controller requires that cert manager is enabled"))
 		}
@@ -1690,7 +1722,7 @@ func validateSnapshotController(cluster *kops.Cluster, spec *kops.SnapshotContro
 	return allErrs
 }
 
-func validatePodIdentityWebhook(cluster *kops.Cluster, spec *kops.PodIdentityWebhookConfig, fldPath *field.Path) (allErrs field.ErrorList) {
+func validatePodIdentityWebhook(cluster *kops.Cluster, spec *kops.PodIdentityWebhookSpec, fldPath *field.Path) (allErrs field.ErrorList) {
 	if spec != nil && spec.Enabled {
 		if !components.IsCertManagerEnabled(cluster) {
 			allErrs = append(allErrs, field.Forbidden(fldPath, "EKS Pod Identity Webhook requires that cert manager is enabled"))
@@ -1702,7 +1734,7 @@ func validatePodIdentityWebhook(cluster *kops.Cluster, spec *kops.PodIdentityWeb
 
 func validateCertManager(cluster *kops.Cluster, spec *kops.CertManagerConfig, fldPath *field.Path) (allErrs field.ErrorList) {
 	if len(spec.HostedZoneIDs) > 0 {
-		if !fi.BoolValue(cluster.Spec.IAM.UseServiceAccountExternalPermissions) {
+		if !fi.ValueOf(cluster.Spec.IAM.UseServiceAccountExternalPermissions) {
 			allErrs = append(allErrs, field.Forbidden(fldPath, "Cert Manager requires that service accounts use external permissions in order to do dns-01 validation"))
 		}
 	}
