@@ -138,14 +138,14 @@ func TestValidateSubnets(t *testing.T) {
 		},
 		{
 			Input: []kops.ClusterSubnetSpec{
-				{Name: "a", ProviderID: "a", Type: kops.SubnetTypePublic},
-				{Name: "b", ProviderID: "b", Type: kops.SubnetTypePublic},
+				{Name: "a", ID: "a", Type: kops.SubnetTypePublic},
+				{Name: "b", ID: "b", Type: kops.SubnetTypePublic},
 			},
 		},
 		{
 			Input: []kops.ClusterSubnetSpec{
-				{Name: "a", ProviderID: "a", Type: kops.SubnetTypePublic},
-				{Name: "b", ProviderID: "", Type: kops.SubnetTypePublic},
+				{Name: "a", ID: "a", Type: kops.SubnetTypePublic},
+				{Name: "b", ID: "", Type: kops.SubnetTypePublic},
 			},
 			ExpectedErrors: []string{"Forbidden::subnets[1].id"},
 		},
@@ -190,7 +190,9 @@ func TestValidateSubnets(t *testing.T) {
 			CloudProvider: kops.CloudProviderSpec{
 				AWS: &kops.AWSSpec{},
 			},
-			Subnets: g.Input,
+			Networking: kops.NetworkingSpec{
+				Subnets: g.Input,
+			},
 		}
 		errs := validateSubnets(cluster, field.NewPath("subnets"))
 
@@ -245,7 +247,7 @@ func TestValidateKubeAPIServer(t *testing.T) {
 		},
 		{
 			Input: kops.KubeAPIServerConfig{
-				AuthorizationMode: fi.String("RBAC"),
+				AuthorizationMode: fi.PtrTo("RBAC"),
 			},
 			Cluster: &kops.Cluster{
 				Spec: kops.ClusterSpec{
@@ -264,7 +266,7 @@ func TestValidateKubeAPIServer(t *testing.T) {
 		},
 		{
 			Input: kops.KubeAPIServerConfig{
-				AuthorizationMode: fi.String("RBAC,Node"),
+				AuthorizationMode: fi.PtrTo("RBAC,Node"),
 			},
 			Cluster: &kops.Cluster{
 				Spec: kops.ClusterSpec{
@@ -280,7 +282,7 @@ func TestValidateKubeAPIServer(t *testing.T) {
 		},
 		{
 			Input: kops.KubeAPIServerConfig{
-				AuthorizationMode: fi.String("RBAC,Node,Bogus"),
+				AuthorizationMode: fi.PtrTo("RBAC,Node,Bogus"),
 			},
 			Cluster: &kops.Cluster{
 				Spec: kops.ClusterSpec{
@@ -384,13 +386,10 @@ func Test_Validate_Networking_Flannel(t *testing.T) {
 		},
 	}
 	for _, g := range grid {
-		networking := &kops.NetworkingSpec{}
-		networking.Flannel = &g.Input
-
 		cluster := &kops.Cluster{}
-		cluster.Spec.Networking = networking
+		cluster.Spec.Networking.Flannel = &g.Input
 
-		errs := validateNetworking(cluster, networking, field.NewPath("networking"))
+		errs := validateNetworking(cluster, &cluster.Spec.Networking, field.NewPath("networking"))
 		testErrors(t, g.Input, errs, g.ExpectedErrors)
 	}
 }
@@ -405,7 +404,7 @@ func Test_Validate_AdditionalPolicies(t *testing.T) {
 		},
 		{
 			Input: map[string]string{
-				"master": `[ { "Action": [ "s3:GetObject" ], "Resource": [ "*" ], "Effect": "Allow" } ]`,
+				"control-plane": `[ { "Action": [ "s3:GetObject" ], "Resource": [ "*" ], "Effect": "Allow" } ]`,
 			},
 		},
 		{
@@ -416,29 +415,31 @@ func Test_Validate_AdditionalPolicies(t *testing.T) {
 		},
 		{
 			Input: map[string]string{
-				"master": `badjson`,
+				"control-plane": `badjson`,
 			},
-			ExpectedErrors: []string{"Invalid value::spec.additionalPolicies[master]"},
+			ExpectedErrors: []string{"Invalid value::spec.additionalPolicies[control-plane]"},
 		},
 		{
 			Input: map[string]string{
-				"master": `[ { "Action": [ "s3:GetObject" ], "Resource": [ "*" ] } ]`,
+				"control-plane": `[ { "Action": [ "s3:GetObject" ], "Resource": [ "*" ] } ]`,
 			},
-			ExpectedErrors: []string{"Required value::spec.additionalPolicies[master][0].Effect"},
+			ExpectedErrors: []string{"Required value::spec.additionalPolicies[control-plane][0].Effect"},
 		},
 		{
 			Input: map[string]string{
-				"master": `[ { "Action": [ "s3:GetObject" ], "Resource": [ "*" ], "Effect": "allow" } ]`,
+				"control-plane": `[ { "Action": [ "s3:GetObject" ], "Resource": [ "*" ], "Effect": "allow" } ]`,
 			},
-			ExpectedErrors: []string{"Unsupported value::spec.additionalPolicies[master][0].Effect"},
+			ExpectedErrors: []string{"Unsupported value::spec.additionalPolicies[control-plane][0].Effect"},
 		},
 	}
 	for _, g := range grid {
 		clusterSpec := &kops.ClusterSpec{
 			KubernetesVersion:  "1.17.0",
 			AdditionalPolicies: &g.Input,
-			Subnets: []kops.ClusterSubnetSpec{
-				{Name: "subnet1", Type: kops.SubnetTypePublic},
+			Networking: kops.NetworkingSpec{
+				Subnets: []kops.ClusterSubnetSpec{
+					{Name: "subnet1", Type: kops.SubnetTypePublic},
+				},
 			},
 			EtcdClusters: []kops.EtcdClusterSpec{
 				{
@@ -446,7 +447,7 @@ func Test_Validate_AdditionalPolicies(t *testing.T) {
 					Members: []kops.EtcdMemberSpec{
 						{
 							Name:          "us-test-1a",
-							InstanceGroup: fi.String("master-us-test-1a"),
+							InstanceGroup: fi.PtrTo("master-us-test-1a"),
 						},
 					},
 				},
@@ -602,6 +603,7 @@ func Test_Validate_Calico(t *testing.T) {
 		{
 			Description: "AWS source/destination checks off",
 			Input: caliInput{
+				Cluster: &kops.ClusterSpec{},
 				Calico: &kops.CalicoNetworkingSpec{
 					AWSSrcDstCheck: "off",
 				},
@@ -611,6 +613,7 @@ func Test_Validate_Calico(t *testing.T) {
 		{
 			Description: "AWS source/destination checks enabled",
 			Input: caliInput{
+				Cluster: &kops.ClusterSpec{},
 				Calico: &kops.CalicoNetworkingSpec{
 					AWSSrcDstCheck: "Enable",
 				},
@@ -619,6 +622,7 @@ func Test_Validate_Calico(t *testing.T) {
 		{
 			Description: "AWS source/destination checks disabled",
 			Input: caliInput{
+				Cluster: &kops.ClusterSpec{},
 				Calico: &kops.CalicoNetworkingSpec{
 					AWSSrcDstCheck: "Disable",
 				},
@@ -627,6 +631,7 @@ func Test_Validate_Calico(t *testing.T) {
 		{
 			Description: "AWS source/destination checks left as is",
 			Input: caliInput{
+				Cluster: &kops.ClusterSpec{},
 				Calico: &kops.CalicoNetworkingSpec{
 					AWSSrcDstCheck: "DoNothing",
 				},
@@ -636,7 +641,9 @@ func Test_Validate_Calico(t *testing.T) {
 			Description: "encapsulation none with IPv4",
 			Input: caliInput{
 				Cluster: &kops.ClusterSpec{
-					NonMasqueradeCIDR: "100.64.0.0/10",
+					Networking: kops.NetworkingSpec{
+						NonMasqueradeCIDR: "100.64.0.0/10",
+					},
 				},
 				Calico: &kops.CalicoNetworkingSpec{
 					EncapsulationMode: "none",
@@ -648,7 +655,9 @@ func Test_Validate_Calico(t *testing.T) {
 			Description: "encapsulation mode IPIP for IPv6",
 			Input: caliInput{
 				Cluster: &kops.ClusterSpec{
-					NonMasqueradeCIDR: "::/0",
+					Networking: kops.NetworkingSpec{
+						NonMasqueradeCIDR: "::/0",
+					},
 				},
 				Calico: &kops.CalicoNetworkingSpec{
 					EncapsulationMode: "ipip",
@@ -660,7 +669,9 @@ func Test_Validate_Calico(t *testing.T) {
 			Description: "encapsulation mode VXLAN for IPv6",
 			Input: caliInput{
 				Cluster: &kops.ClusterSpec{
-					NonMasqueradeCIDR: "::/0",
+					Networking: kops.NetworkingSpec{
+						NonMasqueradeCIDR: "::/0",
+					},
 				},
 				Calico: &kops.CalicoNetworkingSpec{
 					EncapsulationMode: "vxlan",
@@ -707,7 +718,9 @@ func Test_Validate_Calico(t *testing.T) {
 			Description: "Calico IPIP encapsulation mode (explicit) with IPIP IPPool mode (always)",
 			Input: caliInput{
 				Cluster: &kops.ClusterSpec{
-					NonMasqueradeCIDR: "100.64.0.0/10",
+					Networking: kops.NetworkingSpec{
+						NonMasqueradeCIDR: "100.64.0.0/10",
+					},
 				},
 				Calico: &kops.CalicoNetworkingSpec{
 					EncapsulationMode: "ipip",
@@ -719,7 +732,9 @@ func Test_Validate_Calico(t *testing.T) {
 			Description: "Calico IPIP encapsulation mode (explicit) with IPIP IPPool mode (cross-subnet)",
 			Input: caliInput{
 				Cluster: &kops.ClusterSpec{
-					NonMasqueradeCIDR: "100.64.0.0/10",
+					Networking: kops.NetworkingSpec{
+						NonMasqueradeCIDR: "100.64.0.0/10",
+					},
 				},
 				Calico: &kops.CalicoNetworkingSpec{
 					EncapsulationMode: "ipip",
@@ -731,7 +746,9 @@ func Test_Validate_Calico(t *testing.T) {
 			Description: "Calico IPIP encapsulation mode (explicit) with IPIP IPPool mode (never)",
 			Input: caliInput{
 				Cluster: &kops.ClusterSpec{
-					NonMasqueradeCIDR: "100.64.0.0/10",
+					Networking: kops.NetworkingSpec{
+						NonMasqueradeCIDR: "100.64.0.0/10",
+					},
 				},
 				Calico: &kops.CalicoNetworkingSpec{
 					EncapsulationMode: "ipip",
@@ -743,7 +760,9 @@ func Test_Validate_Calico(t *testing.T) {
 			Description: "Calico VXLAN encapsulation mode with IPIP IPPool mode",
 			Input: caliInput{
 				Cluster: &kops.ClusterSpec{
-					NonMasqueradeCIDR: "100.64.0.0/10",
+					Networking: kops.NetworkingSpec{
+						NonMasqueradeCIDR: "100.64.0.0/10",
+					},
 				},
 				Calico: &kops.CalicoNetworkingSpec{
 					EncapsulationMode: "vxlan",
@@ -756,7 +775,9 @@ func Test_Validate_Calico(t *testing.T) {
 			Description: "Calico VXLAN encapsulation mode with IPIP IPPool mode (always)",
 			Input: caliInput{
 				Cluster: &kops.ClusterSpec{
-					NonMasqueradeCIDR: "100.64.0.0/10",
+					Networking: kops.NetworkingSpec{
+						NonMasqueradeCIDR: "100.64.0.0/10",
+					},
 				},
 				Calico: &kops.CalicoNetworkingSpec{
 					EncapsulationMode: "vxlan",
@@ -769,7 +790,9 @@ func Test_Validate_Calico(t *testing.T) {
 			Description: "Calico VXLAN encapsulation mode with IPIP IPPool mode (cross-subnet)",
 			Input: caliInput{
 				Cluster: &kops.ClusterSpec{
-					NonMasqueradeCIDR: "100.64.0.0/10",
+					Networking: kops.NetworkingSpec{
+						NonMasqueradeCIDR: "100.64.0.0/10",
+					},
 				},
 				Calico: &kops.CalicoNetworkingSpec{
 					EncapsulationMode: "vxlan",
@@ -782,7 +805,9 @@ func Test_Validate_Calico(t *testing.T) {
 			Description: "Calico VXLAN encapsulation mode with IPIP IPPool mode (never)",
 			Input: caliInput{
 				Cluster: &kops.ClusterSpec{
-					NonMasqueradeCIDR: "100.64.0.0/10",
+					Networking: kops.NetworkingSpec{
+						NonMasqueradeCIDR: "100.64.0.0/10",
+					},
 				},
 				Calico: &kops.CalicoNetworkingSpec{
 					EncapsulationMode: "vxlan",
@@ -794,7 +819,9 @@ func Test_Validate_Calico(t *testing.T) {
 			Description: "Calico IPv6 without encapsulation",
 			Input: caliInput{
 				Cluster: &kops.ClusterSpec{
-					NonMasqueradeCIDR: "::/0",
+					Networking: kops.NetworkingSpec{
+						NonMasqueradeCIDR: "::/0",
+					},
 				},
 				Calico: &kops.CalicoNetworkingSpec{
 					EncapsulationMode: "none",
@@ -839,7 +866,7 @@ func Test_Validate_Cilium(t *testing.T) {
 		},
 		{
 			Cilium: kops.CiliumNetworkingSpec{
-				Masquerade: fi.Bool(false),
+				Masquerade: fi.PtrTo(true),
 				IPAM:       "eni",
 			},
 			Spec: kops.ClusterSpec{
@@ -856,7 +883,7 @@ func Test_Validate_Cilium(t *testing.T) {
 		},
 		{
 			Cilium: kops.CiliumNetworkingSpec{
-				Masquerade: fi.Bool(true),
+				Masquerade: fi.PtrTo(false),
 				IPAM:       "eni",
 			},
 			Spec: kops.ClusterSpec{
@@ -868,8 +895,8 @@ func Test_Validate_Cilium(t *testing.T) {
 		},
 		{
 			Cilium: kops.CiliumNetworkingSpec{
-				EnableL7Proxy:        fi.Bool(true),
-				InstallIptablesRules: fi.Bool(false),
+				EnableL7Proxy:        fi.PtrTo(true),
+				InstallIptablesRules: fi.PtrTo(false),
 			},
 			Spec: kops.ClusterSpec{
 				CloudProvider: kops.CloudProviderSpec{
@@ -914,27 +941,27 @@ func Test_Validate_Cilium(t *testing.T) {
 			Cilium: kops.CiliumNetworkingSpec{
 				Version: "v1.8.0",
 				Hubble: &kops.HubbleSpec{
-					Enabled: fi.Bool(true),
+					Enabled: fi.PtrTo(true),
 				},
 			},
 			ExpectedErrors: []string{"Forbidden::cilium.hubble.enabled"},
 		},
 		{
 			Cilium: kops.CiliumNetworkingSpec{
-				Version: "v1.11.6",
+				Version: "v1.12.4",
 				Hubble: &kops.HubbleSpec{
-					Enabled: fi.Bool(true),
+					Enabled: fi.PtrTo(true),
 				},
 			},
 			Spec: kops.ClusterSpec{
 				CertManager: &kops.CertManagerConfig{
-					Enabled: fi.Bool(true),
+					Enabled: fi.PtrTo(true),
 				},
 			},
 		},
 	}
 	for _, g := range grid {
-		g.Spec.Networking = &kops.NetworkingSpec{
+		g.Spec.Networking = kops.NetworkingSpec{
 			Cilium: &g.Cilium,
 		}
 		if g.Spec.KubernetesVersion == "" {
@@ -1101,7 +1128,7 @@ func Test_Validate_NodeLocalDNS(t *testing.T) {
 				KubeDNS: &kops.KubeDNSConfig{
 					Provider: "CoreDNS",
 					NodeLocalDNS: &kops.NodeLocalDNSConfig{
-						Enabled: fi.Bool(true),
+						Enabled: fi.PtrTo(true),
 					},
 				},
 			},
@@ -1118,7 +1145,7 @@ func Test_Validate_NodeLocalDNS(t *testing.T) {
 				KubeDNS: &kops.KubeDNSConfig{
 					Provider: "CoreDNS",
 					NodeLocalDNS: &kops.NodeLocalDNSConfig{
-						Enabled: fi.Bool(true),
+						Enabled: fi.PtrTo(true),
 					},
 				},
 			},
@@ -1135,10 +1162,10 @@ func Test_Validate_NodeLocalDNS(t *testing.T) {
 				KubeDNS: &kops.KubeDNSConfig{
 					Provider: "CoreDNS",
 					NodeLocalDNS: &kops.NodeLocalDNSConfig{
-						Enabled: fi.Bool(true),
+						Enabled: fi.PtrTo(true),
 					},
 				},
-				Networking: &kops.NetworkingSpec{
+				Networking: kops.NetworkingSpec{
 					Cilium: &kops.CiliumNetworkingSpec{},
 				},
 			},
@@ -1155,11 +1182,11 @@ func Test_Validate_NodeLocalDNS(t *testing.T) {
 				KubeDNS: &kops.KubeDNSConfig{
 					Provider: "CoreDNS",
 					NodeLocalDNS: &kops.NodeLocalDNSConfig{
-						Enabled: fi.Bool(true),
+						Enabled: fi.PtrTo(true),
 						LocalIP: "169.254.20.10",
 					},
 				},
-				Networking: &kops.NetworkingSpec{
+				Networking: kops.NetworkingSpec{
 					Cilium: &kops.CiliumNetworkingSpec{},
 				},
 			},
@@ -1187,13 +1214,13 @@ func Test_Validate_CloudConfiguration(t *testing.T) {
 		{
 			Description: "all false",
 			Input: kops.CloudConfiguration{
-				ManageStorageClasses: fi.Bool(false),
+				ManageStorageClasses: fi.PtrTo(false),
 			},
 		},
 		{
 			Description: "all true",
 			Input: kops.CloudConfiguration{
-				ManageStorageClasses: fi.Bool(true),
+				ManageStorageClasses: fi.PtrTo(true),
 			},
 		},
 		{
@@ -1202,7 +1229,7 @@ func Test_Validate_CloudConfiguration(t *testing.T) {
 			CloudProvider: kops.CloudProviderSpec{
 				Openstack: &kops.OpenstackSpec{
 					BlockStorage: &kops.OpenstackBlockStorageConfig{
-						CreateStorageClass: fi.Bool(false),
+						CreateStorageClass: fi.PtrTo(false),
 					},
 				},
 			},
@@ -1213,7 +1240,7 @@ func Test_Validate_CloudConfiguration(t *testing.T) {
 			CloudProvider: kops.CloudProviderSpec{
 				Openstack: &kops.OpenstackSpec{
 					BlockStorage: &kops.OpenstackBlockStorageConfig{
-						CreateStorageClass: fi.Bool(true),
+						CreateStorageClass: fi.PtrTo(true),
 					},
 				},
 			},
@@ -1221,12 +1248,12 @@ func Test_Validate_CloudConfiguration(t *testing.T) {
 		{
 			Description: "all false, os false",
 			Input: kops.CloudConfiguration{
-				ManageStorageClasses: fi.Bool(false),
+				ManageStorageClasses: fi.PtrTo(false),
 			},
 			CloudProvider: kops.CloudProviderSpec{
 				Openstack: &kops.OpenstackSpec{
 					BlockStorage: &kops.OpenstackBlockStorageConfig{
-						CreateStorageClass: fi.Bool(false),
+						CreateStorageClass: fi.PtrTo(false),
 					},
 				},
 			},
@@ -1234,12 +1261,12 @@ func Test_Validate_CloudConfiguration(t *testing.T) {
 		{
 			Description: "all false, os true",
 			Input: kops.CloudConfiguration{
-				ManageStorageClasses: fi.Bool(false),
+				ManageStorageClasses: fi.PtrTo(false),
 			},
 			CloudProvider: kops.CloudProviderSpec{
 				Openstack: &kops.OpenstackSpec{
 					BlockStorage: &kops.OpenstackBlockStorageConfig{
-						CreateStorageClass: fi.Bool(true),
+						CreateStorageClass: fi.PtrTo(true),
 					},
 				},
 			},
@@ -1248,12 +1275,12 @@ func Test_Validate_CloudConfiguration(t *testing.T) {
 		{
 			Description: "all true, os false",
 			Input: kops.CloudConfiguration{
-				ManageStorageClasses: fi.Bool(true),
+				ManageStorageClasses: fi.PtrTo(true),
 			},
 			CloudProvider: kops.CloudProviderSpec{
 				Openstack: &kops.OpenstackSpec{
 					BlockStorage: &kops.OpenstackBlockStorageConfig{
-						CreateStorageClass: fi.Bool(false),
+						CreateStorageClass: fi.PtrTo(false),
 					},
 				},
 			},
@@ -1262,12 +1289,12 @@ func Test_Validate_CloudConfiguration(t *testing.T) {
 		{
 			Description: "all true, os true",
 			Input: kops.CloudConfiguration{
-				ManageStorageClasses: fi.Bool(true),
+				ManageStorageClasses: fi.PtrTo(true),
 			},
 			CloudProvider: kops.CloudProviderSpec{
 				Openstack: &kops.OpenstackSpec{
 					BlockStorage: &kops.OpenstackBlockStorageConfig{
-						CreateStorageClass: fi.Bool(true),
+						CreateStorageClass: fi.PtrTo(true),
 					},
 				},
 			},
@@ -1382,7 +1409,7 @@ func Test_Validate_Nvidia_Cluster(t *testing.T) {
 			Input: kops.ClusterSpec{
 				Containerd: &kops.ContainerdConfig{
 					NvidiaGPU: &kops.NvidiaGPUConfig{
-						Enabled: fi.Bool(true),
+						Enabled: fi.PtrTo(true),
 					},
 				},
 				CloudProvider: kops.CloudProviderSpec{
@@ -1395,7 +1422,7 @@ func Test_Validate_Nvidia_Cluster(t *testing.T) {
 			Input: kops.ClusterSpec{
 				Containerd: &kops.ContainerdConfig{
 					NvidiaGPU: &kops.NvidiaGPUConfig{
-						Enabled: fi.Bool(true),
+						Enabled: fi.PtrTo(true),
 					},
 				},
 				CloudProvider: kops.CloudProviderSpec{
@@ -1409,7 +1436,7 @@ func Test_Validate_Nvidia_Cluster(t *testing.T) {
 			Input: kops.ClusterSpec{
 				Containerd: &kops.ContainerdConfig{
 					NvidiaGPU: &kops.NvidiaGPUConfig{
-						Enabled: fi.Bool(true),
+						Enabled: fi.PtrTo(true),
 					},
 				},
 				CloudProvider: kops.CloudProviderSpec{
@@ -1423,7 +1450,7 @@ func Test_Validate_Nvidia_Cluster(t *testing.T) {
 			Input: kops.ClusterSpec{
 				Containerd: &kops.ContainerdConfig{
 					NvidiaGPU: &kops.NvidiaGPUConfig{
-						Enabled: fi.Bool(true),
+						Enabled: fi.PtrTo(true),
 					},
 				},
 				CloudProvider: kops.CloudProviderSpec{
@@ -1449,7 +1476,7 @@ func Test_Validate_Nvidia_Ig(t *testing.T) {
 			Input: kops.ClusterSpec{
 				Containerd: &kops.ContainerdConfig{
 					NvidiaGPU: &kops.NvidiaGPUConfig{
-						Enabled: fi.Bool(true),
+						Enabled: fi.PtrTo(true),
 					},
 				},
 				CloudProvider: kops.CloudProviderSpec{
@@ -1462,7 +1489,7 @@ func Test_Validate_Nvidia_Ig(t *testing.T) {
 			Input: kops.ClusterSpec{
 				Containerd: &kops.ContainerdConfig{
 					NvidiaGPU: &kops.NvidiaGPUConfig{
-						Enabled: fi.Bool(true),
+						Enabled: fi.PtrTo(true),
 					},
 				},
 				CloudProvider: kops.CloudProviderSpec{
@@ -1475,7 +1502,7 @@ func Test_Validate_Nvidia_Ig(t *testing.T) {
 			Input: kops.ClusterSpec{
 				Containerd: &kops.ContainerdConfig{
 					NvidiaGPU: &kops.NvidiaGPUConfig{
-						Enabled: fi.Bool(true),
+						Enabled: fi.PtrTo(true),
 					},
 				},
 				CloudProvider: kops.CloudProviderSpec{
@@ -1489,7 +1516,7 @@ func Test_Validate_Nvidia_Ig(t *testing.T) {
 			Input: kops.ClusterSpec{
 				Containerd: &kops.ContainerdConfig{
 					NvidiaGPU: &kops.NvidiaGPUConfig{
-						Enabled: fi.Bool(true),
+						Enabled: fi.PtrTo(true),
 					},
 				},
 				CloudProvider: kops.CloudProviderSpec{
