@@ -18,8 +18,12 @@ package bootstrap
 
 import (
 	"context"
+	"errors"
+	"net/http"
 )
 
+var ErrAlreadyExists = errors.New("node already exists")
+
 // Authenticator generates authentication credentials for requests.
 type Authenticator interface {
 	CreateToken(body []byte) (string, error)
@@ -39,5 +43,5 @@ type VerifyResult struct {
 
 // Verifier verifies authentication credentials for requests.
 type Verifier interface {
-	VerifyToken(ctx context.Context, token string, body []byte, useInstanceIDForNodeName bool) (*VerifyResult, error)
+	VerifyToken(ctx context.Context, rawRequest *http.Request, token string, body []byte, useInstanceIDForNodeName bool) (*VerifyResult, error)
 }
