@@ -51,35 +51,33 @@ func (b *AWSCloudControllerManagerOptionsBuilder) BuildOptions(o interface{}) er
 
 	// No significant downside to always doing a leader election.
 	// Also, having multiple control plane nodes requires leader election.
-	eccm.LeaderElection = &kops.LeaderElectionConfiguration{LeaderElect: fi.Bool(true)}
+	eccm.LeaderElection = &kops.LeaderElectionConfiguration{LeaderElect: fi.PtrTo(true)}
 
 	eccm.ClusterName = b.ClusterName
 
-	eccm.ClusterCIDR = clusterSpec.NonMasqueradeCIDR
+	eccm.ClusterCIDR = clusterSpec.Networking.NonMasqueradeCIDR
 
-	eccm.AllocateNodeCIDRs = fi.Bool(true)
-	eccm.ConfigureCloudRoutes = fi.Bool(false)
+	eccm.AllocateNodeCIDRs = fi.PtrTo(true)
+	eccm.ConfigureCloudRoutes = fi.PtrTo(false)
 
 	// TODO: we want to consolidate this with the logic from KCM
-	networking := clusterSpec.Networking
-	if networking == nil {
-		eccm.ConfigureCloudRoutes = fi.Bool(true)
-	} else if networking.Kubenet != nil {
-		eccm.ConfigureCloudRoutes = fi.Bool(true)
+	networking := &clusterSpec.Networking
+	if networking.Kubenet != nil {
+		eccm.ConfigureCloudRoutes = fi.PtrTo(true)
 	} else if networking.GCE != nil {
-		eccm.ConfigureCloudRoutes = fi.Bool(false)
-		eccm.CIDRAllocatorType = fi.String("CloudAllocator")
+		eccm.ConfigureCloudRoutes = fi.PtrTo(false)
+		eccm.CIDRAllocatorType = fi.PtrTo("CloudAllocator")
 
 		if eccm.ClusterCIDR == "" {
-			eccm.ClusterCIDR = clusterSpec.PodCIDR
+			eccm.ClusterCIDR = clusterSpec.Networking.PodCIDR
 		}
 	} else if networking.External != nil {
-		eccm.ConfigureCloudRoutes = fi.Bool(false)
+		eccm.ConfigureCloudRoutes = fi.PtrTo(false)
 	} else if UsesCNI(networking) {
-		eccm.ConfigureCloudRoutes = fi.Bool(false)
+		eccm.ConfigureCloudRoutes = fi.PtrTo(false)
 	} else if networking.Kopeio != nil {
 		// Kopeio is based on kubenet / external
-		eccm.ConfigureCloudRoutes = fi.Bool(false)
+		eccm.ConfigureCloudRoutes = fi.PtrTo(false)
 	} else {
 		return fmt.Errorf("no networking mode set")
 	}
@@ -87,25 +85,25 @@ func (b *AWSCloudControllerManagerOptionsBuilder) BuildOptions(o interface{}) er
 	if eccm.Image == "" {
 		// See https://us.gcr.io/k8s-artifacts-prod/provider-aws/cloud-controller-manager
 		switch b.KubernetesVersion.Minor {
-		case 20:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.20.1"
 		case 21:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.21.3"
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.21.6"
 		case 22:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.22.2"
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.22.7"
 		case 23:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.23.2"
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.23.6"
 		case 24:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.24.1"
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.24.3"
 		case 25:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.25.1"
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.25.2"
+		case 26:
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.26.0"
 		default:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.24.1"
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.26.0"
 		}
 	}
 
 	if b.IsKubernetesGTE("1.24") && b.IsKubernetesLT("1.25") {
-		eccm.EnableLeaderMigration = fi.Bool(true)
+		eccm.EnableLeaderMigration = fi.PtrTo(true)
 	}
 
 	return nil
