@@ -25,7 +25,6 @@ import (
 	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/apis/kops/model"
 	"k8s.io/kops/pkg/apis/kops/util"
-	"k8s.io/kops/pkg/dns"
 	"k8s.io/kops/pkg/kubemanifest"
 	"k8s.io/kops/pkg/model/components"
 	"k8s.io/kops/pkg/model/iam"
@@ -62,8 +61,8 @@ func (b *KopsModelContext) GatherSubnets(ig *kops.InstanceGroup) ([]*kops.Cluste
 
 	for _, subnetName := range ig.Spec.Subnets {
 		var matches []*kops.ClusterSubnetSpec
-		for i := range b.Cluster.Spec.Subnets {
-			clusterSubnet := &b.Cluster.Spec.Subnets[i]
+		for i := range b.Cluster.Spec.Networking.Subnets {
+			clusterSubnet := &b.Cluster.Spec.Networking.Subnets[i]
 			if clusterSubnet.Name == subnetName {
 				matches = append(matches, clusterSubnet)
 			}
@@ -114,7 +113,7 @@ func (b *KopsModelContext) FindZonesForInstanceGroup(ig *kops.InstanceGroup) ([]
 func (b *KopsModelContext) MasterInstanceGroups() []*kops.InstanceGroup {
 	var groups []*kops.InstanceGroup
 	for _, ig := range b.InstanceGroups {
-		if !ig.IsMaster() {
+		if !ig.IsControlPlane() {
 			continue
 		}
 		groups = append(groups, ig)
@@ -148,10 +147,12 @@ func (b *KopsModelContext) CloudTagsForInstanceGroup(ig *kops.InstanceGroup) (ma
 		labels[k] = v
 	}
 
-	// Apply NTH Labels
-	nth := b.Cluster.Spec.NodeTerminationHandler
-	if nth != nil && fi.BoolValue(nth.Enabled) && fi.BoolValue(nth.EnableSQSTerminationDraining) {
-		labels[fi.StringValue(nth.ManagedASGTag)] = ""
+	if b.Cluster.Spec.CloudProvider.AWS != nil {
+		// Apply NTH Labels
+		nth := b.Cluster.Spec.CloudProvider.AWS.NodeTerminationHandler
+		if nth.IsQueueMode() {
+			labels[fi.ValueOf(nth.ManagedASGTag)] = ""
+		}
 	}
 
 	// Apply labels for cluster autoscaler node labels
@@ -169,8 +170,9 @@ func (b *KopsModelContext) CloudTagsForInstanceGroup(ig *kops.InstanceGroup) (ma
 
 	// The system tags take priority because the cluster likely breaks without them...
 
-	if ig.Spec.Role == kops.InstanceGroupRoleMaster {
-		labels[awstasks.CloudTagInstanceGroupRolePrefix+strings.ToLower(string(kops.InstanceGroupRoleMaster))] = "1"
+	if ig.Spec.Role == kops.InstanceGroupRoleControlPlane {
+		labels[awstasks.CloudTagInstanceGroupRolePrefix+"master"] = "1"
+		labels[awstasks.CloudTagInstanceGroupRolePrefix+kops.InstanceGroupRoleControlPlane.ToLowerString()] = "1"
 	}
 
 	if ig.Spec.Role == kops.InstanceGroupRoleAPIServer {
@@ -247,12 +249,12 @@ func (b *KopsModelContext) UseBootstrapTokens() bool {
 		return false
 	}
 
-	return fi.BoolValue(b.Cluster.Spec.KubeAPIServer.EnableBootstrapAuthToken)
+	return fi.ValueOf(b.Cluster.Spec.KubeAPIServer.EnableBootstrapAuthToken)
 }
 
 // UsesBastionDns checks if we should use a specific name for the bastion dns
 func (b *KopsModelContext) UsesBastionDns() bool {
-	if b.Cluster.Spec.Topology.Bastion != nil && b.Cluster.Spec.Topology.Bastion.PublicName != "" {
+	if b.Cluster.Spec.Networking.Topology.Bastion != nil && b.Cluster.Spec.Networking.Topology.Bastion.PublicName != "" {
 		return true
 	}
 	return false
@@ -271,9 +273,6 @@ func (b *KopsModelContext) UsesSSHBastion() bool {
 
 // UseLoadBalancerForAPI checks if we are using a load balancer for the kubeapi
 func (b *KopsModelContext) UseLoadBalancerForAPI() bool {
-	if b.Cluster.Spec.API == nil {
-		return false
-	}
 	return b.Cluster.Spec.API.LoadBalancer != nil
 }
 
@@ -287,31 +286,12 @@ func (b *KopsModelContext) UseLoadBalancerForInternalAPI() bool {
 
 // APILoadBalancerClass returns which type of load balancer to use for the api
 func (b *KopsModelContext) APILoadBalancerClass() kops.LoadBalancerClass {
-	if b.Cluster.Spec.API != nil && b.Cluster.Spec.API.LoadBalancer != nil {
+	if b.Cluster.Spec.API.LoadBalancer != nil {
 		return b.Cluster.Spec.API.LoadBalancer.Class
 	}
 	return kops.LoadBalancerClassClassic
 }
 
-// UsePrivateDNS checks if we are using private DNS
-func (b *KopsModelContext) UsePrivateDNS() bool {
-	topology := b.Cluster.Spec.Topology
-	if topology != nil && topology.DNS != nil {
-		switch topology.DNS.Type {
-		case kops.DNSTypePublic:
-			return false
-		case kops.DNSTypePrivate:
-			return true
-
-		default:
-			klog.Warningf("Unknown DNS type %q", topology.DNS.Type)
-			return false
-		}
-	}
-
-	return false
-}
-
 // UseClassicLoadBalancer checks if we are using Classic LoadBalancer
 func (b *KopsModelContext) UseClassicLoadBalancer() bool {
 	return b.Cluster.Spec.API.LoadBalancer.Class == kops.LoadBalancerClassClassic
@@ -365,11 +345,11 @@ func (b *KopsModelContext) IsIPv6Only() bool {
 
 func (b *KopsModelContext) UseIPv6ForAPI() bool {
 	for _, ig := range b.InstanceGroups {
-		if ig.Spec.Role != kops.InstanceGroupRoleMaster && ig.Spec.Role != kops.InstanceGroupRoleAPIServer {
+		if ig.Spec.Role != kops.InstanceGroupRoleControlPlane && ig.Spec.Role != kops.InstanceGroupRoleAPIServer {
 			break
 		}
 		for _, igSubnetName := range ig.Spec.Subnets {
-			for _, clusterSubnet := range b.Cluster.Spec.Subnets {
+			for _, clusterSubnet := range b.Cluster.Spec.Networking.Subnets {
 				if igSubnetName != clusterSubnet.Name {
 					continue
 				}
@@ -406,20 +386,15 @@ func (b *KopsModelContext) NodePortRange() (utilnet.PortRange, error) {
 // UseServiceAccountExternalPermissions returns true if we are using service-account bound IAM roles.
 func (b *KopsModelContext) UseServiceAccountExternalPermissions() bool {
 	return b.Cluster.Spec.IAM != nil &&
-		fi.BoolValue(b.Cluster.Spec.IAM.UseServiceAccountExternalPermissions)
+		fi.ValueOf(b.Cluster.Spec.IAM.UseServiceAccountExternalPermissions)
 }
 
 // NetworkingIsCalico returns true if we are using calico networking
 func (b *KopsModelContext) NetworkingIsCalico() bool {
-	return b.Cluster.Spec.Networking != nil && b.Cluster.Spec.Networking.Calico != nil
+	return b.Cluster.Spec.Networking.Calico != nil
 }
 
 // NetworkingIsCilium returns true if we are using cilium networking
 func (b *KopsModelContext) NetworkingIsCilium() bool {
-	return b.Cluster.Spec.Networking != nil && b.Cluster.Spec.Networking.Cilium != nil
-}
-
-// IsGossip returns true if we are using gossip instead of "real" DNS
-func (b *KopsModelContext) IsGossip() bool {
-	return dns.IsGossipHostname(b.Cluster.Name)
+	return b.Cluster.Spec.Networking.Cilium != nil
 }
