@@ -18,6 +18,7 @@ package gcemodel
 
 import (
 	"fmt"
+	"strconv"
 
 	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/wellknownports"
@@ -32,11 +33,11 @@ type APILoadBalancerBuilder struct {
 	Lifecycle fi.Lifecycle
 }
 
-var _ fi.ModelBuilder = &APILoadBalancerBuilder{}
+var _ fi.CloudupModelBuilder = &APILoadBalancerBuilder{}
 
 // createPublicLB validates the existence of a target pool with the given name,
 // and creates an IP address and forwarding rule pointing to that target pool.
-func createPublicLB(b *APILoadBalancerBuilder, c *fi.ModelBuilderContext) error {
+func createPublicLB(b *APILoadBalancerBuilder, c *fi.CloudupModelBuilderContext) error {
 	// TODO: point target pool to instance group managers, as done in internal LB.
 	targetPool := &gcetasks.TargetPool{
 		Name:      s(b.NameForTargetPool("api")),
@@ -49,7 +50,6 @@ func createPublicLB(b *APILoadBalancerBuilder, c *fi.ModelBuilderContext) error
 		Port:      i64(wellknownports.KubeAPIServerHealthCheck),
 		Lifecycle: b.Lifecycle,
 	}
-
 	c.AddTask(healthCheck)
 
 	poolHealthCheck := &gcetasks.PoolHealthCheck{
@@ -61,28 +61,32 @@ func createPublicLB(b *APILoadBalancerBuilder, c *fi.ModelBuilderContext) error
 	c.AddTask(poolHealthCheck)
 
 	ipAddress := &gcetasks.Address{
-		Name:      s(b.NameForIPAddress("api")),
-		Lifecycle: b.Lifecycle,
+		Name:         s(b.NameForIPAddress("api")),
+		ForAPIServer: true,
+		Lifecycle:    b.Lifecycle,
 	}
 	c.AddTask(ipAddress)
 
-	forwardingRule := &gcetasks.ForwardingRule{
+	c.AddTask(&gcetasks.ForwardingRule{
 		Name:       s(b.NameForForwardingRule("api")),
 		Lifecycle:  b.Lifecycle,
-		PortRange:  s("443-443"),
+		PortRange:  s(strconv.Itoa(wellknownports.KubeAPIServer) + "-" + strconv.Itoa(wellknownports.KubeAPIServer)),
 		TargetPool: targetPool,
 		IPAddress:  ipAddress,
 		IPProtocol: "TCP",
+	})
+	if b.Cluster.UsesNoneDNS() {
+		c.AddTask(&gcetasks.ForwardingRule{
+			Name:       s(b.NameForForwardingRule("kops-controller")),
+			Lifecycle:  b.Lifecycle,
+			PortRange:  s(strconv.Itoa(wellknownports.KopsControllerPort) + "-" + strconv.Itoa(wellknownports.KopsControllerPort)),
+			TargetPool: targetPool,
+			IPAddress:  ipAddress,
+			IPProtocol: "TCP",
+		})
 	}
 
-	c.AddTask(forwardingRule)
-
-	{
-		// Ensure the IP address is included in our certificate
-		ipAddress.ForAPIServer = true
-	}
-
-	// Allow traffic into the API (port 443) from KubernetesAPIAccess CIDRs
+	// Allow traffic into the API from KubernetesAPIAccess CIDRs
 	{
 		network, err := b.LinkToNetwork()
 		if err != nil {
@@ -91,10 +95,31 @@ func createPublicLB(b *APILoadBalancerBuilder, c *fi.ModelBuilderContext) error
 		b.AddFirewallRulesTasks(c, "https-api", &gcetasks.FirewallRule{
 			Lifecycle:    b.Lifecycle,
 			Network:      network,
-			SourceRanges: b.Cluster.Spec.KubernetesAPIAccess,
-			TargetTags:   []string{b.GCETagForRole(kops.InstanceGroupRoleMaster)},
-			Allowed:      []string{"tcp:443"},
+			SourceRanges: b.Cluster.Spec.API.Access,
+			TargetTags:   []string{b.GCETagForRole(kops.InstanceGroupRoleControlPlane)},
+			Allowed:      []string{"tcp:" + strconv.Itoa(wellknownports.KubeAPIServer)},
 		})
+
+		if b.NetworkingIsIPAlias() {
+			c.AddTask(&gcetasks.FirewallRule{
+				Name:         s(b.NameForFirewallRule("pod-cidrs-to-https-api")),
+				Lifecycle:    b.Lifecycle,
+				Network:      network,
+				SourceRanges: []string{b.Cluster.Spec.Networking.PodCIDR},
+				TargetTags:   []string{b.GCETagForRole(kops.InstanceGroupRoleControlPlane)},
+				Allowed:      []string{"tcp:" + strconv.Itoa(wellknownports.KubeAPIServer)},
+			})
+		}
+
+		if b.Cluster.UsesNoneDNS() {
+			b.AddFirewallRulesTasks(c, "kops-controller", &gcetasks.FirewallRule{
+				Lifecycle:    b.Lifecycle,
+				Network:      network,
+				SourceRanges: b.Cluster.Spec.API.Access,
+				TargetTags:   []string{b.GCETagForRole(kops.InstanceGroupRoleControlPlane)},
+				Allowed:      []string{"tcp:" + strconv.Itoa(wellknownports.KopsControllerPort)},
+			})
+		}
 	}
 	return nil
 
@@ -103,24 +128,24 @@ func createPublicLB(b *APILoadBalancerBuilder, c *fi.ModelBuilderContext) error
 // createInternalLB creates an internal load balancer for the cluster.  In
 // GCP this entails creating a health check, backend service, and one forwarding rule
 // per specified subnet pointing to that backend service.
-func createInternalLB(b *APILoadBalancerBuilder, c *fi.ModelBuilderContext) error {
+func createInternalLB(b *APILoadBalancerBuilder, c *fi.CloudupModelBuilderContext) error {
 	lbSpec := b.Cluster.Spec.API.LoadBalancer
 	hc := &gcetasks.HealthCheck{
 		Name:      s(b.NameForHealthCheck("api")),
-		Port:      443,
+		Port:      wellknownports.KubeAPIServer,
 		Lifecycle: b.Lifecycle,
 	}
 	c.AddTask(hc)
 	var igms []*gcetasks.InstanceGroupManager
 	for _, ig := range b.InstanceGroups {
-		if ig.Spec.Role != kops.InstanceGroupRoleMaster {
+		if ig.Spec.Role != kops.InstanceGroupRoleControlPlane {
 			continue
 		}
 		if len(ig.Spec.Zones) > 1 {
-			return fmt.Errorf("Instance group %q has %d zones, which is not yet supported for GCP.", ig.GetName(), len(ig.Spec.Zones))
+			return fmt.Errorf("instance group %q has %d zones, which is not yet supported for GCP", ig.GetName(), len(ig.Spec.Zones))
 		}
 		if len(ig.Spec.Zones) == 0 {
-			return fmt.Errorf("Instance group %q must specify exactly one zone.", ig.GetName())
+			return fmt.Errorf("instance group %q must specify exactly one zone", ig.GetName())
 		}
 		zone := ig.Spec.Zones[0]
 		igms = append(igms, &gcetasks.InstanceGroupManager{Name: s(gce.NameForInstanceGroupManager(b.Cluster, ig, zone)), Zone: s(zone)})
@@ -149,26 +174,39 @@ func createInternalLB(b *APILoadBalancerBuilder, c *fi.ModelBuilderContext) erro
 			Lifecycle: fi.LifecycleExistsAndWarnIfChanges,
 		}
 		// TODO: automatically associate forwarding rule to subnets if no subnets are specified here.
-		if subnetNotSpecified(sn, b.Cluster.Spec.Subnets) {
+		if subnetNotSpecified(sn, b.Cluster.Spec.Networking.Subnets) {
 			c.AddTask(subnet)
 		}
 		c.AddTask(&gcetasks.ForwardingRule{
 			Name:                s(b.NameForForwardingRule(sn.Name)),
 			Lifecycle:           b.Lifecycle,
 			BackendService:      bs,
-			Ports:               []string{"443"},
+			Ports:               []string{strconv.Itoa(wellknownports.KubeAPIServer)},
 			RuleIPAddress:       sn.PrivateIPv4Address,
 			IPProtocol:          "TCP",
 			LoadBalancingScheme: s("INTERNAL"),
 			Network:             network,
 			Subnetwork:          subnet,
 		})
+		if b.Cluster.UsesNoneDNS() {
+			c.AddTask(&gcetasks.ForwardingRule{
+				Name:                s(b.NameForForwardingRule("kops-controller-" + sn.Name)),
+				Lifecycle:           b.Lifecycle,
+				BackendService:      bs,
+				Ports:               []string{strconv.Itoa(wellknownports.KopsControllerPort)},
+				RuleIPAddress:       sn.PrivateIPv4Address,
+				IPProtocol:          "TCP",
+				LoadBalancingScheme: s("INTERNAL"),
+				Network:             network,
+				Subnetwork:          subnet,
+			})
+		}
 	}
 
 	return nil
 }
 
-func (b *APILoadBalancerBuilder) Build(c *fi.ModelBuilderContext) error {
+func (b *APILoadBalancerBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 	if !b.UseLoadBalancerForAPI() {
 		return nil
 	}
@@ -194,7 +232,7 @@ func (b *APILoadBalancerBuilder) Build(c *fi.ModelBuilderContext) error {
 // subnetNotSpecified returns true if the given LB subnet is not listed in the list of cluster subnets.
 func subnetNotSpecified(sn kops.LoadBalancerSubnetSpec, subnets []kops.ClusterSubnetSpec) bool {
 	for _, csn := range subnets {
-		if csn.Name == sn.Name || csn.ProviderID == sn.Name {
+		if csn.Name == sn.Name || csn.ID == sn.Name {
 			return false
 		}
 	}
