@@ -49,22 +49,26 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 					Name: "cluster",
 				},
 				Spec: kops.ClusterSpec{
-					MasterPublicName: "master-public-name",
+					API: kops.APISpec{
+						PublicName: "master-public-name",
+					},
 					CloudProvider: kops.CloudProviderSpec{
 						Openstack: &kops.OpenstackSpec{
 							Router: &kops.OpenstackRouter{
-								ExternalNetwork: fi.String("test"),
+								ExternalNetwork: fi.PtrTo("test"),
 							},
 							Metadata: &kops.OpenstackMetadata{
-								ConfigDrive: fi.Bool(false),
+								ConfigDrive: fi.PtrTo(false),
 							},
 						},
 					},
 					KubernetesVersion: "1.24.0",
-					Subnets: []kops.ClusterSubnetSpec{
-						{
-							Name:   "subnet",
-							Region: "region",
+					Networking: kops.NetworkingSpec{
+						Subnets: []kops.ClusterSubnetSpec{
+							{
+								Name:   "subnet",
+								Region: "region",
+							},
 						},
 					},
 				},
@@ -75,7 +79,7 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 						Name: "master",
 					},
 					Spec: kops.InstanceGroupSpec{
-						Role:        kops.InstanceGroupRoleMaster,
+						Role:        kops.InstanceGroupRoleControlPlane,
 						Image:       "image-master",
 						MinSize:     i32(1),
 						MaxSize:     i32(1),
@@ -107,31 +111,35 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 					Name: "cluster",
 				},
 				Spec: kops.ClusterSpec{
-					MasterPublicName: "master-public-name",
+					API: kops.APISpec{
+						PublicName: "master-public-name",
+					},
 					CloudProvider: kops.CloudProviderSpec{
 						Openstack: &kops.OpenstackSpec{
 							Router: &kops.OpenstackRouter{
-								ExternalNetwork: fi.String("test"),
+								ExternalNetwork: fi.PtrTo("test"),
 							},
 							Metadata: &kops.OpenstackMetadata{
-								ConfigDrive: fi.Bool(false),
+								ConfigDrive: fi.PtrTo(false),
 							},
 						},
 					},
 					KubernetesVersion: "1.24.0",
-					Subnets: []kops.ClusterSubnetSpec{
-						{
-							Name:   "subnet",
-							Region: "region",
+					Networking: kops.NetworkingSpec{
+						Subnets: []kops.ClusterSubnetSpec{
+							{
+								Name:   "subnet",
+								Region: "region",
+							},
+							{
+								Name:   "utility-subnet",
+								Region: "region",
+							},
 						},
-						{
-							Name:   "utility-subnet",
-							Region: "region",
+						Topology: &kops.TopologySpec{
+							Nodes: "private",
 						},
 					},
-					Topology: &kops.TopologySpec{
-						Nodes: "private",
-					},
 				},
 			},
 			instanceGroups: []*kops.InstanceGroup{
@@ -140,7 +148,7 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 						Name: "master",
 					},
 					Spec: kops.InstanceGroupSpec{
-						Role:        kops.InstanceGroupRoleMaster,
+						Role:        kops.InstanceGroupRoleControlPlane,
 						Image:       "image",
 						MinSize:     i32(1),
 						MaxSize:     i32(1),
@@ -193,30 +201,34 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 					Name: "cluster",
 				},
 				Spec: kops.ClusterSpec{
-					MasterPublicName: "master-public-name",
+					API: kops.APISpec{
+						PublicName: "master-public-name",
+					},
 					CloudProvider: kops.CloudProviderSpec{
 						Openstack: &kops.OpenstackSpec{
 							Router: &kops.OpenstackRouter{
-								ExternalNetwork: fi.String("test"),
+								ExternalNetwork: fi.PtrTo("test"),
 							},
 							Metadata: &kops.OpenstackMetadata{
-								ConfigDrive: fi.Bool(false),
+								ConfigDrive: fi.PtrTo(false),
 							},
 						},
 					},
 					KubernetesVersion: "1.24.0",
-					Subnets: []kops.ClusterSubnetSpec{
-						{
-							Name:   "subnet-a",
-							Region: "region",
-						},
-						{
-							Name:   "subnet-b",
-							Region: "region",
-						},
-						{
-							Name:   "subnet-c",
-							Region: "region",
+					Networking: kops.NetworkingSpec{
+						Subnets: []kops.ClusterSubnetSpec{
+							{
+								Name:   "subnet-a",
+								Region: "region",
+							},
+							{
+								Name:   "subnet-b",
+								Region: "region",
+							},
+							{
+								Name:   "subnet-c",
+								Region: "region",
+							},
 						},
 					},
 				},
@@ -227,7 +239,7 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 						Name: "master-a",
 					},
 					Spec: kops.InstanceGroupSpec{
-						Role:        kops.InstanceGroupRoleMaster,
+						Role:        kops.InstanceGroupRoleControlPlane,
 						Image:       "image",
 						MinSize:     i32(1),
 						MaxSize:     i32(1),
@@ -255,7 +267,7 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 						Name: "master-b",
 					},
 					Spec: kops.InstanceGroupSpec{
-						Role:        kops.InstanceGroupRoleMaster,
+						Role:        kops.InstanceGroupRoleControlPlane,
 						Image:       "image",
 						MinSize:     i32(1),
 						MaxSize:     i32(1),
@@ -283,7 +295,7 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 						Name: "master-c",
 					},
 					Spec: kops.InstanceGroupSpec{
-						Role:        kops.InstanceGroupRoleMaster,
+						Role:        kops.InstanceGroupRoleControlPlane,
 						Image:       "image",
 						MinSize:     i32(1),
 						MaxSize:     i32(1),
@@ -315,22 +327,26 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 					Name: "tom-software-dev-playground-real33-k8s-local",
 				},
 				Spec: kops.ClusterSpec{
-					MasterPublicName: "master-public-name",
+					API: kops.APISpec{
+						PublicName: "master-public-name",
+					},
 					CloudProvider: kops.CloudProviderSpec{
 						Openstack: &kops.OpenstackSpec{
 							Router: &kops.OpenstackRouter{
-								ExternalNetwork: fi.String("test"),
+								ExternalNetwork: fi.PtrTo("test"),
 							},
 							Metadata: &kops.OpenstackMetadata{
-								ConfigDrive: fi.Bool(false),
+								ConfigDrive: fi.PtrTo(false),
 							},
 						},
 					},
 					KubernetesVersion: "1.24.0",
-					Subnets: []kops.ClusterSubnetSpec{
-						{
-							Name:   "subnet",
-							Region: "region",
+					Networking: kops.NetworkingSpec{
+						Subnets: []kops.ClusterSubnetSpec{
+							{
+								Name:   "subnet",
+								Region: "region",
+							},
 						},
 					},
 				},
@@ -341,7 +357,7 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 						Name: "master",
 					},
 					Spec: kops.InstanceGroupSpec{
-						Role:        kops.InstanceGroupRoleMaster,
+						Role:        kops.InstanceGroupRoleControlPlane,
 						Image:       "image-master",
 						MinSize:     i32(1),
 						MaxSize:     i32(1),
@@ -373,37 +389,41 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 					Name: "cluster",
 				},
 				Spec: kops.ClusterSpec{
-					MasterPublicName: "master-public-name",
+					API: kops.APISpec{
+						PublicName: "master-public-name",
+					},
 					CloudProvider: kops.CloudProviderSpec{
 						Openstack: &kops.OpenstackSpec{
 							Loadbalancer: &kops.OpenstackLoadbalancerConfig{},
 							Router: &kops.OpenstackRouter{
-								ExternalNetwork: fi.String("test"),
+								ExternalNetwork: fi.PtrTo("test"),
 							},
 							Metadata: &kops.OpenstackMetadata{
-								ConfigDrive: fi.Bool(false),
+								ConfigDrive: fi.PtrTo(false),
 							},
 						},
 					},
-					Topology: &kops.TopologySpec{
-						Masters: kops.TopologyPrivate,
-					},
 					KubernetesVersion: "1.24.0",
-					Subnets: []kops.ClusterSubnetSpec{
-						{
-							Name:   "subnet-a",
-							Region: "region",
-							Type:   kops.SubnetTypePrivate,
+					Networking: kops.NetworkingSpec{
+						Subnets: []kops.ClusterSubnetSpec{
+							{
+								Name:   "subnet-a",
+								Region: "region",
+								Type:   kops.SubnetTypePrivate,
+							},
+							{
+								Name:   "subnet-b",
+								Region: "region",
+								Type:   kops.SubnetTypePrivate,
+							},
+							{
+								Name:   "subnet-c",
+								Region: "region",
+								Type:   kops.SubnetTypePrivate,
+							},
 						},
-						{
-							Name:   "subnet-b",
-							Region: "region",
-							Type:   kops.SubnetTypePrivate,
-						},
-						{
-							Name:   "subnet-c",
-							Region: "region",
-							Type:   kops.SubnetTypePrivate,
+						Topology: &kops.TopologySpec{
+							ControlPlane: kops.TopologyPrivate,
 						},
 					},
 				},
@@ -414,7 +434,7 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 						Name: "master-a",
 					},
 					Spec: kops.InstanceGroupSpec{
-						Role:        kops.InstanceGroupRoleMaster,
+						Role:        kops.InstanceGroupRoleControlPlane,
 						Image:       "image",
 						MinSize:     i32(1),
 						MaxSize:     i32(1),
@@ -442,7 +462,7 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 						Name: "master-b",
 					},
 					Spec: kops.InstanceGroupSpec{
-						Role:        kops.InstanceGroupRoleMaster,
+						Role:        kops.InstanceGroupRoleControlPlane,
 						Image:       "image",
 						MinSize:     i32(1),
 						MaxSize:     i32(1),
@@ -470,7 +490,7 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 						Name: "master-c",
 					},
 					Spec: kops.InstanceGroupSpec{
-						Role:        kops.InstanceGroupRoleMaster,
+						Role:        kops.InstanceGroupRoleControlPlane,
 						Image:       "image",
 						MinSize:     i32(1),
 						MaxSize:     i32(1),
@@ -496,33 +516,74 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 			},
 		},
 		{
-			desc: "multizone setup 3 masters 3 nodes without external router",
+			desc: "multizone setup 3 masters 3 nodes without bastion with API loadbalancer dns none",
 			cluster: &kops.Cluster{
 				ObjectMeta: metav1.ObjectMeta{
 					Name: "cluster",
 				},
 				Spec: kops.ClusterSpec{
-					MasterPublicName: "master-public-name",
+					API: kops.APISpec{
+						LoadBalancer: &kops.LoadBalancerAccessSpec{
+							Type: kops.LoadBalancerTypePublic,
+						},
+					},
 					CloudProvider: kops.CloudProviderSpec{
 						Openstack: &kops.OpenstackSpec{
+							BlockStorage: &kops.OpenstackBlockStorageConfig{
+								Version:            fi.PtrTo("v3"),
+								IgnoreAZ:           fi.PtrTo(false),
+								CreateStorageClass: fi.PtrTo(false),
+								CSITopologySupport: fi.PtrTo(true),
+							},
+							Loadbalancer: &kops.OpenstackLoadbalancerConfig{
+								FloatingNetwork: fi.PtrTo("test"),
+								FloatingSubnet:  fi.PtrTo("test-lb-subnet"),
+								Method:          fi.PtrTo("ROUND_ROBIN"),
+								Provider:        fi.PtrTo("amphora"),
+								UseOctavia:      fi.PtrTo(true),
+							},
+							Monitor: &kops.OpenstackMonitor{
+								Delay:      fi.PtrTo("1m"),
+								MaxRetries: fi.PtrTo(3),
+								Timeout:    fi.PtrTo("30s"),
+							},
+							Network: &kops.OpenstackNetwork{
+								AvailabilityZoneHints: []*string{fi.PtrTo("zone-1"), fi.PtrTo("zone-2"), fi.PtrTo("zone-3")},
+							},
+							Router: &kops.OpenstackRouter{
+								DNSServers:            fi.PtrTo("8.8.8.8,8.8.4.4"),
+								ExternalSubnet:        fi.PtrTo("test-router-subnet"),
+								ExternalNetwork:       fi.PtrTo("test"),
+								AvailabilityZoneHints: []*string{fi.PtrTo("ha-zone")},
+							},
 							Metadata: &kops.OpenstackMetadata{
-								ConfigDrive: fi.Bool(false),
+								ConfigDrive: fi.PtrTo(false),
 							},
 						},
 					},
-					KubernetesVersion: "1.24.0",
-					Subnets: []kops.ClusterSubnetSpec{
-						{
-							Name:   "subnet-a",
-							Region: "region",
+					KubernetesVersion: "1.25.0",
+					Networking: kops.NetworkingSpec{
+						Subnets: []kops.ClusterSubnetSpec{
+							{
+								Name: "subnet-1",
+								Zone: "zone-1",
+								Type: kops.SubnetTypePrivate,
+							},
+							{
+								Name: "subnet-2",
+								Zone: "zone-2",
+								Type: kops.SubnetTypePrivate,
+							},
+							{
+								Name: "subnet-3",
+								Zone: "zone-3",
+								Type: kops.SubnetTypePrivate,
+							},
 						},
-						{
-							Name:   "subnet-b",
-							Region: "region",
-						},
-						{
-							Name:   "subnet-c",
-							Region: "region",
+						Topology: &kops.TopologySpec{
+							ControlPlane: kops.TopologyPrivate,
+							DNS:          kops.DNSTypeNone,
+							Nodes:        kops.TopologyPrivate,
 						},
 					},
 				},
@@ -533,7 +594,130 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 						Name: "master-a",
 					},
 					Spec: kops.InstanceGroupSpec{
-						Role:        kops.InstanceGroupRoleMaster,
+						Role:        kops.InstanceGroupRoleControlPlane,
+						Image:       "image",
+						MinSize:     i32(1),
+						MaxSize:     i32(1),
+						MachineType: "blc.1-2",
+						Subnets:     []string{"subnet-1"},
+						Zones:       []string{"zone-1"},
+					},
+				},
+				{
+					ObjectMeta: metav1.ObjectMeta{
+						Name: "node-a",
+					},
+					Spec: kops.InstanceGroupSpec{
+						Role:        kops.InstanceGroupRoleNode,
+						Image:       "image",
+						MinSize:     i32(1),
+						MaxSize:     i32(1),
+						MachineType: "blc.1-2",
+						Subnets:     []string{"subnet-1"},
+						Zones:       []string{"zone-1"},
+					},
+				},
+				{
+					ObjectMeta: metav1.ObjectMeta{
+						Name: "master-b",
+					},
+					Spec: kops.InstanceGroupSpec{
+						Role:        kops.InstanceGroupRoleControlPlane,
+						Image:       "image",
+						MinSize:     i32(1),
+						MaxSize:     i32(1),
+						MachineType: "blc.1-2",
+						Subnets:     []string{"subnet-2"},
+						Zones:       []string{"zone-2"},
+					},
+				},
+				{
+					ObjectMeta: metav1.ObjectMeta{
+						Name: "node-b",
+					},
+					Spec: kops.InstanceGroupSpec{
+						Role:        kops.InstanceGroupRoleNode,
+						Image:       "image",
+						MinSize:     i32(1),
+						MaxSize:     i32(1),
+						MachineType: "blc.1-2",
+						Subnets:     []string{"subnet-2"},
+						Zones:       []string{"zone-2"},
+					},
+				},
+				{
+					ObjectMeta: metav1.ObjectMeta{
+						Name: "master-c",
+					},
+					Spec: kops.InstanceGroupSpec{
+						Role:        kops.InstanceGroupRoleControlPlane,
+						Image:       "image",
+						MinSize:     i32(1),
+						MaxSize:     i32(1),
+						MachineType: "blc.1-2",
+						Subnets:     []string{"subnet-3"},
+						Zones:       []string{"zone-3"},
+					},
+				},
+				{
+					ObjectMeta: metav1.ObjectMeta{
+						Name: "node-c",
+					},
+					Spec: kops.InstanceGroupSpec{
+						Role:        kops.InstanceGroupRoleNode,
+						Image:       "image",
+						MinSize:     i32(1),
+						MaxSize:     i32(1),
+						MachineType: "blc.1-2",
+						Subnets:     []string{"subnet-3"},
+						Zones:       []string{"zone-3"},
+					},
+				},
+			},
+		},
+		{
+			desc: "multizone setup 3 masters 3 nodes without external router",
+			cluster: &kops.Cluster{
+				ObjectMeta: metav1.ObjectMeta{
+					Name: "cluster",
+				},
+				Spec: kops.ClusterSpec{
+					API: kops.APISpec{
+						PublicName: "master-public-name",
+					},
+					CloudProvider: kops.CloudProviderSpec{
+						Openstack: &kops.OpenstackSpec{
+							Metadata: &kops.OpenstackMetadata{
+								ConfigDrive: fi.PtrTo(false),
+							},
+						},
+					},
+					KubernetesVersion: "1.24.0",
+					Networking: kops.NetworkingSpec{
+						Subnets: []kops.ClusterSubnetSpec{
+							{
+								Name:   "subnet-a",
+								Region: "region",
+							},
+							{
+								Name:   "subnet-b",
+								Region: "region",
+							},
+							{
+								Name:   "subnet-c",
+								Region: "region",
+							},
+						},
+					},
+				},
+			},
+			instanceGroups: []*kops.InstanceGroup{
+				{
+					ObjectMeta: metav1.ObjectMeta{
+						Name: "master-a",
+					},
+					Spec: kops.InstanceGroupSpec{
+						Role:        kops.InstanceGroupRoleControlPlane,
 						Image:       "image",
 						MinSize:     i32(1),
 						MaxSize:     i32(1),
@@ -561,7 +745,7 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 						Name: "master-b",
 					},
 					Spec: kops.InstanceGroupSpec{
-						Role:        kops.InstanceGroupRoleMaster,
+						Role:        kops.InstanceGroupRoleControlPlane,
 						Image:       "image",
 						MinSize:     i32(1),
 						MaxSize:     i32(1),
@@ -589,7 +773,7 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 						Name: "master-c",
 					},
 					Spec: kops.InstanceGroupSpec{
-						Role:        kops.InstanceGroupRoleMaster,
+						Role:        kops.InstanceGroupRoleControlPlane,
 						Image:       "image",
 						MinSize:     i32(1),
 						MaxSize:     i32(1),
@@ -621,30 +805,34 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 					Name: "cluster",
 				},
 				Spec: kops.ClusterSpec{
-					MasterPublicName: "master-public-name",
+					API: kops.APISpec{
+						PublicName: "master-public-name",
+					},
 					CloudProvider: kops.CloudProviderSpec{
 						Openstack: &kops.OpenstackSpec{
 							Router: &kops.OpenstackRouter{
-								ExternalNetwork: fi.String("test"),
+								ExternalNetwork: fi.PtrTo("test"),
 							},
 							Metadata: &kops.OpenstackMetadata{
-								ConfigDrive: fi.Bool(false),
+								ConfigDrive: fi.PtrTo(false),
 							},
 						},
 					},
 					KubernetesVersion: "1.24.0",
-					Subnets: []kops.ClusterSubnetSpec{
-						{
-							Name:   "subnet-a",
-							Region: "region",
-						},
-						{
-							Name:   "subnet-b",
-							Region: "region",
-						},
-						{
-							Name:   "subnet-c",
-							Region: "region",
+					Networking: kops.NetworkingSpec{
+						Subnets: []kops.ClusterSubnetSpec{
+							{
+								Name:   "subnet-a",
+								Region: "region",
+							},
+							{
+								Name:   "subnet-b",
+								Region: "region",
+							},
+							{
+								Name:   "subnet-c",
+								Region: "region",
+							},
 						},
 					},
 				},
@@ -655,7 +843,7 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 						Name: "master",
 					},
 					Spec: kops.InstanceGroupSpec{
-						Role:        kops.InstanceGroupRoleMaster,
+						Role:        kops.InstanceGroupRoleControlPlane,
 						Image:       "image",
 						MinSize:     i32(3),
 						MaxSize:     i32(3),
@@ -703,22 +891,26 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 					Name: "cluster",
 				},
 				Spec: kops.ClusterSpec{
-					MasterPublicName: "master-public-name",
+					API: kops.APISpec{
+						PublicName: "master-public-name",
+					},
 					CloudProvider: kops.CloudProviderSpec{
 						Openstack: &kops.OpenstackSpec{
 							Router: &kops.OpenstackRouter{
-								ExternalNetwork: fi.String("test"),
+								ExternalNetwork: fi.PtrTo("test"),
 							},
 							Metadata: &kops.OpenstackMetadata{
-								ConfigDrive: fi.Bool(false),
+								ConfigDrive: fi.PtrTo(false),
 							},
 						},
 					},
 					KubernetesVersion: "1.24.0",
-					Subnets: []kops.ClusterSubnetSpec{
-						{
-							Name:   "subnet",
-							Region: "region",
+					Networking: kops.NetworkingSpec{
+						Subnets: []kops.ClusterSubnetSpec{
+							{
+								Name:   "subnet",
+								Region: "region",
+							},
 						},
 					},
 				},
@@ -729,14 +921,14 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 						Name: "master",
 					},
 					Spec: kops.InstanceGroupSpec{
-						Role:              kops.InstanceGroupRoleMaster,
+						Role:              kops.InstanceGroupRoleControlPlane,
 						Image:             "image-master",
 						MinSize:           i32(1),
 						MaxSize:           i32(1),
 						MachineType:       "blc.1-2",
 						Subnets:           []string{"subnet"},
 						Zones:             []string{"zone-1"},
-						AssociatePublicIP: fi.Bool(false),
+						AssociatePublicIP: fi.PtrTo(false),
 					},
 				},
 				{
@@ -751,7 +943,7 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 						MachineType:       "blc.2-4",
 						Subnets:           []string{"subnet"},
 						Zones:             []string{"zone-1"},
-						AssociatePublicIP: fi.Bool(false),
+						AssociatePublicIP: fi.PtrTo(false),
 					},
 				},
 			},
@@ -763,26 +955,30 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 					Name: "cluster",
 				},
 				Spec: kops.ClusterSpec{
-					MasterPublicName: "master-public-name",
+					API: kops.APISpec{
+						PublicName: "master-public-name",
+					},
 					CloudProvider: kops.CloudProviderSpec{
 						Openstack: &kops.OpenstackSpec{
 							Router: &kops.OpenstackRouter{
-								ExternalNetwork: fi.String("test"),
+								ExternalNetwork: fi.PtrTo("test"),
 							},
 							Metadata: &kops.OpenstackMetadata{
-								ConfigDrive: fi.Bool(false),
+								ConfigDrive: fi.PtrTo(false),
 							},
 						},
 					},
 					KubernetesVersion: "1.24.0",
-					Subnets: []kops.ClusterSubnetSpec{
-						{
-							Name:   "subnet",
-							Region: "region",
-						},
-						{
-							Name:   "utility-subnet",
-							Region: "region",
+					Networking: kops.NetworkingSpec{
+						Subnets: []kops.ClusterSubnetSpec{
+							{
+								Name:   "subnet",
+								Region: "region",
+							},
+							{
+								Name:   "utility-subnet",
+								Region: "region",
+							},
 						},
 					},
 				},
@@ -793,14 +989,14 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 						Name: "master",
 					},
 					Spec: kops.InstanceGroupSpec{
-						Role:              kops.InstanceGroupRoleMaster,
+						Role:              kops.InstanceGroupRoleControlPlane,
 						Image:             "image",
 						MinSize:           i32(1),
 						MaxSize:           i32(1),
 						MachineType:       "blc.1-2",
 						Subnets:           []string{"subnet"},
 						Zones:             []string{"zone-1"},
-						AssociatePublicIP: fi.Bool(false),
+						AssociatePublicIP: fi.PtrTo(false),
 					},
 				},
 				{
@@ -815,7 +1011,7 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 						MachineType:       "blc.1-2",
 						Subnets:           []string{"subnet"},
 						Zones:             []string{"zone-1"},
-						AssociatePublicIP: fi.Bool(false),
+						AssociatePublicIP: fi.PtrTo(false),
 					},
 				},
 				{
@@ -837,7 +1033,7 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 						MachineType:       "blc.1-2",
 						Subnets:           []string{"utility-subnet"},
 						Zones:             []string{"zone-1"},
-						AssociatePublicIP: fi.Bool(false),
+						AssociatePublicIP: fi.PtrTo(false),
 					},
 				},
 			},
@@ -849,19 +1045,23 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 					Name: "cluster",
 				},
 				Spec: kops.ClusterSpec{
-					MasterPublicName: "master-public-name",
+					API: kops.APISpec{
+						PublicName: "master-public-name",
+					},
 					CloudProvider: kops.CloudProviderSpec{
 						Openstack: &kops.OpenstackSpec{
 							Metadata: &kops.OpenstackMetadata{
-								ConfigDrive: fi.Bool(false),
+								ConfigDrive: fi.PtrTo(false),
 							},
 						},
 					},
 					KubernetesVersion: "1.24.0",
-					Subnets: []kops.ClusterSubnetSpec{
-						{
-							Name:   "subnet",
-							Region: "region",
+					Networking: kops.NetworkingSpec{
+						Subnets: []kops.ClusterSubnetSpec{
+							{
+								Name:   "subnet",
+								Region: "region",
+							},
 						},
 					},
 				},
@@ -893,19 +1093,23 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 					Name: "cluster",
 				},
 				Spec: kops.ClusterSpec{
-					MasterPublicName: "master-public-name",
+					API: kops.APISpec{
+						PublicName: "master-public-name",
+					},
 					CloudProvider: kops.CloudProviderSpec{
 						Openstack: &kops.OpenstackSpec{
 							Metadata: &kops.OpenstackMetadata{
-								ConfigDrive: fi.Bool(false),
+								ConfigDrive: fi.PtrTo(false),
 							},
 						},
 					},
 					KubernetesVersion: "1.24.0",
-					Subnets: []kops.ClusterSubnetSpec{
-						{
-							Name:   "subnet",
-							Region: "region",
+					Networking: kops.NetworkingSpec{
+						Subnets: []kops.ClusterSubnetSpec{
+							{
+								Name:   "subnet",
+								Region: "region",
+							},
 						},
 					},
 				},
@@ -939,19 +1143,23 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 					Name: "cluster",
 				},
 				Spec: kops.ClusterSpec{
-					MasterPublicName: "master-public-name",
+					API: kops.APISpec{
+						PublicName: "master-public-name",
+					},
 					CloudProvider: kops.CloudProviderSpec{
 						Openstack: &kops.OpenstackSpec{
 							Metadata: &kops.OpenstackMetadata{
-								ConfigDrive: fi.Bool(false),
+								ConfigDrive: fi.PtrTo(false),
 							},
 						},
 					},
 					KubernetesVersion: "1.24.0",
-					Subnets: []kops.ClusterSubnetSpec{
-						{
-							Name:   "subnet",
-							Region: "region",
+					Networking: kops.NetworkingSpec{
+						Subnets: []kops.ClusterSubnetSpec{
+							{
+								Name:   "subnet",
+								Region: "region",
+							},
 						},
 					},
 				},
@@ -983,19 +1191,23 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 					Name: "cluster",
 				},
 				Spec: kops.ClusterSpec{
-					MasterPublicName: "master-public-name",
+					API: kops.APISpec{
+						PublicName: "master-public-name",
+					},
 					CloudProvider: kops.CloudProviderSpec{
 						Openstack: &kops.OpenstackSpec{
 							Metadata: &kops.OpenstackMetadata{
-								ConfigDrive: fi.Bool(false),
+								ConfigDrive: fi.PtrTo(false),
 							},
 						},
 					},
 					KubernetesVersion: "1.24.0",
-					Subnets: []kops.ClusterSubnetSpec{
-						{
-							Name:   "subnet",
-							Region: "region",
+					Networking: kops.NetworkingSpec{
+						Subnets: []kops.ClusterSubnetSpec{
+							{
+								Name:   "subnet",
+								Region: "region",
+							},
 						},
 					},
 					CloudLabels: map[string]string{
@@ -1027,19 +1239,23 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 					Name: "cluster",
 				},
 				Spec: kops.ClusterSpec{
-					MasterPublicName: "master-public-name",
+					API: kops.APISpec{
+						PublicName: "master-public-name",
+					},
 					CloudProvider: kops.CloudProviderSpec{
 						Openstack: &kops.OpenstackSpec{
 							Metadata: &kops.OpenstackMetadata{
-								ConfigDrive: fi.Bool(false),
+								ConfigDrive: fi.PtrTo(false),
 							},
 						},
 					},
 					KubernetesVersion: "1.24.0",
-					Subnets: []kops.ClusterSubnetSpec{
-						{
-							Name:   "subnet",
-							Region: "region",
+					Networking: kops.NetworkingSpec{
+						Subnets: []kops.ClusterSubnetSpec{
+							{
+								Name:   "subnet",
+								Region: "region",
+							},
 						},
 					},
 				},
@@ -1071,19 +1287,23 @@ func getServerGroupModelBuilderTestInput() []serverGroupModelBuilderTestInput {
 					Name: "cluster",
 				},
 				Spec: kops.ClusterSpec{
-					MasterPublicName: "master-public-name",
+					API: kops.APISpec{
+						PublicName: "master-public-name",
+					},
 					CloudProvider: kops.CloudProviderSpec{
 						Openstack: &kops.OpenstackSpec{
 							Metadata: &kops.OpenstackMetadata{
-								ConfigDrive: fi.Bool(false),
+								ConfigDrive: fi.PtrTo(false),
 							},
 						},
 					},
 					KubernetesVersion: "1.24.0",
-					Subnets: []kops.ClusterSubnetSpec{
-						{
-							Name:   "subnet",
-							Region: "region",
+					Networking: kops.NetworkingSpec{
+						Subnets: []kops.ClusterSubnetSpec{
+							{
+								Name:   "subnet",
+								Region: "region",
+							},
 						},
 					},
 				},
@@ -1151,9 +1371,6 @@ func RunGoldenTest(t *testing.T, basedir string, testCase serverGroupModelBuilde
 	testutils.SetupMockOpenstack()
 
 	clusterLifecycle := fi.LifecycleSync
-	if testCase.cluster.Spec.Networking == nil {
-		testCase.cluster.Spec.Networking = &kops.NetworkingSpec{}
-	}
 	bootstrapScriptBuilder := &model.BootstrapScriptBuilder{
 		KopsModelContext: &model.KopsModelContext{
 			IAMModelContext: iam.IAMModelContext{Cluster: testCase.cluster},
@@ -1175,14 +1392,14 @@ func RunGoldenTest(t *testing.T, basedir string, testCase serverGroupModelBuilde
 
 	builder := createBuilderForCluster(testCase.cluster, testCase.instanceGroups, clusterLifecycle, bootstrapScriptBuilder)
 
-	context := &fi.ModelBuilderContext{
-		Tasks:              make(map[string]fi.Task),
+	context := &fi.CloudupModelBuilderContext{
+		Tasks:              make(map[string]fi.CloudupTask),
 		LifecycleOverrides: map[string]fi.Lifecycle{},
 	}
 
 	// We need the CA and service-account for the bootstrap script
 	caTask := &fitasks.Keypair{
-		Name:    fi.String(fi.CertificateIDCA),
+		Name:    fi.PtrTo(fi.CertificateIDCA),
 		Subject: "cn=kubernetes",
 		Type:    "ca",
 	}
@@ -1197,7 +1414,7 @@ func RunGoldenTest(t *testing.T, basedir string, testCase serverGroupModelBuilde
 		"service-account",
 	} {
 		task := &fitasks.Keypair{
-			Name:    fi.String(keypair),
+			Name:    fi.PtrTo(keypair),
 			Subject: "cn=" + keypair,
 			Type:    "ca",
 		}
@@ -1208,7 +1425,7 @@ func RunGoldenTest(t *testing.T, basedir string, testCase serverGroupModelBuilde
 		"kube-proxy",
 	} {
 		task := &fitasks.Keypair{
-			Name:    fi.String(keypair),
+			Name:    fi.PtrTo(keypair),
 			Subject: "cn=" + keypair,
 			Signer:  caTask,
 			Type:    "client",
