@@ -202,16 +202,16 @@ func TestAutoscalingGroupTerraformRender(t *testing.T) {
 	cases := []*renderTest{
 		{
 			Resource: &AutoscalingGroup{
-				Name:           fi.String("test"),
-				Granularity:    fi.String("5min"),
-				LaunchTemplate: &LaunchTemplate{Name: fi.String("test_lc")},
-				MaxSize:        fi.Int64(10),
+				Name:           fi.PtrTo("test"),
+				Granularity:    fi.PtrTo("5min"),
+				LaunchTemplate: &LaunchTemplate{Name: fi.PtrTo("test_lc")},
+				MaxSize:        fi.PtrTo(int64(10)),
 				Metrics:        []string{"test"},
-				MinSize:        fi.Int64(1),
+				MinSize:        fi.PtrTo(int64(1)),
 				Subnets: []*Subnet{
 					{
-						Name: fi.String("test-sg"),
-						ID:   fi.String("sg-1111"),
+						Name: fi.PtrTo("test-sg"),
+						ID:   fi.PtrTo("sg-1111"),
 					},
 				},
 				Tags: map[string]string{
@@ -260,19 +260,19 @@ terraform {
 		},
 		{
 			Resource: &AutoscalingGroup{
-				Name:                        fi.String("test1"),
-				LaunchTemplate:              &LaunchTemplate{Name: fi.String("test_lt")},
-				MaxSize:                     fi.Int64(10),
+				Name:                        fi.PtrTo("test1"),
+				LaunchTemplate:              &LaunchTemplate{Name: fi.PtrTo("test_lt")},
+				MaxSize:                     fi.PtrTo(int64(10)),
 				Metrics:                     []string{"test"},
-				MinSize:                     fi.Int64(5),
+				MinSize:                     fi.PtrTo(int64(5)),
 				MixedInstanceOverrides:      []string{"t2.medium", "t2.large"},
-				MixedOnDemandBase:           fi.Int64(4),
-				MixedOnDemandAboveBase:      fi.Int64(30),
-				MixedSpotAllocationStrategy: fi.String("capacity-optimized"),
+				MixedOnDemandBase:           fi.PtrTo(int64(4)),
+				MixedOnDemandAboveBase:      fi.PtrTo(int64(30)),
+				MixedSpotAllocationStrategy: fi.PtrTo("capacity-optimized"),
 				Subnets: []*Subnet{
 					{
-						Name: fi.String("test-sg"),
-						ID:   fi.String("sg-1111"),
+						Name: fi.PtrTo("test-sg"),
+						ID:   fi.PtrTo("sg-1111"),
 					},
 				},
 				Tags: map[string]string{
@@ -321,6 +321,90 @@ resource "aws_autoscaling_group" "test1" {
   vpc_zone_identifier = [aws_subnet.test-sg.id]
 }
 
+terraform {
+  required_version = ">= 0.15.0"
+  required_providers {
+    aws = {
+      "configuration_aliases" = [aws.files]
+      "source"                = "hashicorp/aws"
+      "version"               = ">= 4.0.0"
+    }
+  }
+}
+`,
+		},
+		{
+			Resource: &AutoscalingGroup{
+				Name:                        fi.PtrTo("test1"),
+				LaunchTemplate:              &LaunchTemplate{Name: fi.PtrTo("test_lt")},
+				MaxSize:                     fi.PtrTo(int64(10)),
+				Metrics:                     []string{"test"},
+				MinSize:                     fi.PtrTo(int64(5)),
+				MixedInstanceOverrides:      []string{"t2.medium", "t2.large"},
+				MixedOnDemandBase:           fi.PtrTo(int64(4)),
+				MixedOnDemandAboveBase:      fi.PtrTo(int64(30)),
+				MixedSpotAllocationStrategy: fi.PtrTo("capacity-optimized"),
+				WarmPool: &WarmPool{
+					Enabled: fi.PtrTo(true),
+					MinSize: 3,
+					MaxSize: fi.PtrTo(int64(5)),
+				},
+				Subnets: []*Subnet{
+					{
+						Name: fi.PtrTo("test-sg"),
+						ID:   fi.PtrTo("sg-1111"),
+					},
+				},
+				Tags: map[string]string{
+					"test":    "tag",
+					"cluster": "test",
+				},
+			},
+			Expected: `provider "aws" {
+  region = "eu-west-2"
+}
+
+resource "aws_autoscaling_group" "test1" {
+  enabled_metrics = ["test"]
+  max_size        = 10
+  min_size        = 5
+  mixed_instances_policy {
+    instances_distribution {
+      on_demand_base_capacity                  = 4
+      on_demand_percentage_above_base_capacity = 30
+      spot_allocation_strategy                 = "capacity-optimized"
+    }
+    launch_template {
+      launch_template_specification {
+        launch_template_id = aws_launch_template.test_lt.id
+        version            = aws_launch_template.test_lt.latest_version
+      }
+      override {
+        instance_type = "t2.medium"
+      }
+      override {
+        instance_type = "t2.large"
+      }
+    }
+  }
+  name = "test1"
+  tag {
+    key                 = "cluster"
+    propagate_at_launch = true
+    value               = "test"
+  }
+  tag {
+    key                 = "test"
+    propagate_at_launch = true
+    value               = "tag"
+  }
+  vpc_zone_identifier = [aws_subnet.test-sg.id]
+  warm_pool {
+    max_group_prepared_capacity = 5
+    min_size                    = 3
+  }
+}
+
 terraform {
   required_version = ">= 0.15.0"
   required_providers {
