@@ -22,7 +22,7 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/Azure/azure-sdk-for-go/services/compute/mgmt/2020-06-01/compute"
+	"github.com/Azure/azure-sdk-for-go/services/compute/mgmt/2022-08-01/compute"
 	"github.com/Azure/go-autorest/autorest/to"
 	"k8s.io/klog/v2"
 	"k8s.io/kops/upup/pkg/fi"
@@ -113,13 +113,15 @@ type VMScaleSet struct {
 	// AdmnUser specifies the name of the administrative account.
 	AdminUser    *string
 	SSHPublicKey *string
-	// CustomData is the user data configuration
-	CustomData  fi.Resource
+	// UserData is the user data configuration
+	UserData    fi.Resource
 	Tags        map[string]*string
 	Zones       []string
 	PrincipalID *string
 }
 
+var _ fi.CloudupTaskNormalize = &VMScaleSet{}
+
 // VMScaleSetStorageProfile wraps *compute.VirtualMachineScaleSetStorageProfile
 // and implements fi.HasDependencies.
 //
@@ -131,15 +133,15 @@ type VMScaleSetStorageProfile struct {
 	*compute.VirtualMachineScaleSetStorageProfile
 }
 
-var _ fi.HasDependencies = &VMScaleSetStorageProfile{}
+var _ fi.CloudupHasDependencies = &VMScaleSetStorageProfile{}
 
 // GetDependencies returns a slice of tasks on which the tasks depends on.
-func (p *VMScaleSetStorageProfile) GetDependencies(tasks map[string]fi.Task) []fi.Task {
+func (p *VMScaleSetStorageProfile) GetDependencies(tasks map[string]fi.CloudupTask) []fi.CloudupTask {
 	return nil
 }
 
 var (
-	_ fi.Task          = &VMScaleSet{}
+	_ fi.CloudupTask   = &VMScaleSet{}
 	_ fi.CompareWithID = &VMScaleSet{}
 )
 
@@ -149,19 +151,12 @@ func (s *VMScaleSet) CompareWithID() *string {
 }
 
 // Find discovers the VMScaleSet in the cloud provider.
-func (s *VMScaleSet) Find(c *fi.Context) (*VMScaleSet, error) {
-	cloud := c.Cloud.(azure.AzureCloud)
-	l, err := cloud.VMScaleSet().List(context.TODO(), *s.ResourceGroup.Name)
-	if err != nil {
+func (s *VMScaleSet) Find(c *fi.CloudupContext) (*VMScaleSet, error) {
+	cloud := c.T.Cloud.(azure.AzureCloud)
+	found, err := cloud.VMScaleSet().Get(context.TODO(), *s.ResourceGroup.Name, *s.Name)
+	if err != nil && !strings.Contains(err.Error(), "ResourceNotFound") {
 		return nil, err
 	}
-	var found *compute.VirtualMachineScaleSet
-	for _, v := range l {
-		if *v.Name == *s.Name {
-			found = &v
-			break
-		}
-	}
 	if found == nil {
 		return nil, nil
 	}
@@ -202,9 +197,11 @@ func (s *VMScaleSet) Find(c *fi.Context) (*VMScaleSet, error) {
 		return nil, fmt.Errorf("unexpected number of SSH keys found for VM ScaleSet %s: %d", *s.Name, len(sshKeys))
 	}
 
-	// TODO(kenji): Do not check custom data as Azure doesn't
-	// populate (https://github.com/Azure/azure-cli/issues/5866).
-	// Find a way to work around this.
+	userData, err := base64.StdEncoding.DecodeString(*profile.UserData)
+	if err != nil {
+		return nil, fmt.Errorf("failed to decode user data: %w", err)
+	}
+
 	vmss := &VMScaleSet{
 		Name:      s.Name,
 		Lifecycle: s.Lifecycle,
@@ -226,6 +223,7 @@ func (s *VMScaleSet) Find(c *fi.Context) (*VMScaleSet, error) {
 		ComputerNamePrefix: osProfile.ComputerNamePrefix,
 		AdminUser:          osProfile.AdminUsername,
 		SSHPublicKey:       sshKeys[0].KeyData,
+		UserData:           fi.NewBytesResource(userData),
 		Tags:               found.Tags,
 		PrincipalID:        found.Identity.PrincipalID,
 	}
@@ -237,13 +235,18 @@ func (s *VMScaleSet) Find(c *fi.Context) (*VMScaleSet, error) {
 	if found.Zones != nil {
 		vmss.Zones = *found.Zones
 	}
+	s.PrincipalID = found.Identity.PrincipalID
 	return vmss, nil
 }
 
+func (s *VMScaleSet) Normalize(c *fi.CloudupContext) error {
+	c.T.Cloud.(azure.AzureCloud).AddClusterTags(s.Tags)
+	return nil
+}
+
 // Run implements fi.Task.Run.
-func (s *VMScaleSet) Run(c *fi.Context) error {
-	c.Cloud.(azure.AzureCloud).AddClusterTags(s.Tags)
-	return fi.DefaultDeltaRunMethod(s, c)
+func (s *VMScaleSet) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(s, c)
 }
 
 // CheckChanges returns an error if a change is not allowed.
@@ -266,18 +269,18 @@ func (s *VMScaleSet) CheckChanges(a, e, changes *VMScaleSet) error {
 // RenderAzure creates or updates a VM Scale Set.
 func (s *VMScaleSet) RenderAzure(t *azure.AzureAPITarget, a, e, changes *VMScaleSet) error {
 	if a == nil {
-		klog.Infof("Creating a new VM Scale Set with name: %s", fi.StringValue(e.Name))
+		klog.Infof("Creating a new VM Scale Set with name: %s", fi.ValueOf(e.Name))
 	} else {
-		klog.Infof("Updating a VM Scale Set with name: %s", fi.StringValue(e.Name))
+		klog.Infof("Updating a VM Scale Set with name: %s", fi.ValueOf(e.Name))
 	}
 
 	name := *e.Name
 
 	var customData *string
-	if e.CustomData != nil {
-		d, err := fi.ResourceAsBytes(e.CustomData)
+	if e.UserData != nil {
+		d, err := fi.ResourceAsBytes(e.UserData)
 		if err != nil {
-			return fmt.Errorf("error rendering CustomData: %s", err)
+			return fmt.Errorf("error rendering UserData: %s", err)
 		}
 		customData = to.StringPtr(base64.StdEncoding.EncodeToString(d))
 	}
@@ -285,7 +288,6 @@ func (s *VMScaleSet) RenderAzure(t *azure.AzureAPITarget, a, e, changes *VMScale
 	osProfile := &compute.VirtualMachineScaleSetOSProfile{
 		ComputerNamePrefix: e.ComputerNamePrefix,
 		AdminUsername:      e.AdminUser,
-		CustomData:         customData,
 		LinuxConfiguration: &compute.LinuxConfiguration{
 			SSH: &compute.SSHConfiguration{
 				PublicKeys: &[]compute.SSHPublicKey{
@@ -360,6 +362,7 @@ func (s *VMScaleSet) RenderAzure(t *azure.AzureAPITarget, a, e, changes *VMScale
 			VirtualMachineProfile: &compute.VirtualMachineScaleSetVMProfile{
 				OsProfile:      osProfile,
 				StorageProfile: e.StorageProfile.VirtualMachineScaleSetStorageProfile,
+				UserData:       customData,
 				NetworkProfile: &compute.VirtualMachineScaleSetNetworkProfile{
 					NetworkInterfaceConfigurations: &[]compute.VirtualMachineScaleSetNetworkConfiguration{
 						networkConfig,
