@@ -31,6 +31,7 @@ import (
 	"k8s.io/kops/upup/pkg/fi/cloudup/gce"
 	"k8s.io/kops/upup/pkg/fi/cloudup/hetzner"
 	"k8s.io/kops/upup/pkg/fi/cloudup/openstack"
+	"k8s.io/kops/upup/pkg/fi/cloudup/scaleway"
 )
 
 func BuildCloud(cluster *kops.Cluster) (fi.Cloud, error) {
@@ -42,7 +43,7 @@ func BuildCloud(cluster *kops.Cluster) (fi.Cloud, error) {
 	switch cluster.Spec.GetCloudProvider() {
 	case kops.CloudProviderGCE:
 		{
-			for _, subnet := range cluster.Spec.Subnets {
+			for _, subnet := range cluster.Spec.Networking.Subnets {
 				if subnet.Region != "" {
 					region = subnet.Region
 				}
@@ -51,7 +52,7 @@ func BuildCloud(cluster *kops.Cluster) (fi.Cloud, error) {
 				return nil, fmt.Errorf("on GCE, subnets must include Regions")
 			}
 
-			project = cluster.Spec.Project
+			project = cluster.Spec.CloudProvider.GCE.Project
 			if project == "" {
 				return nil, fmt.Errorf("project is required for GCE - try gcloud config get-value project")
 			}
@@ -86,7 +87,7 @@ func BuildCloud(cluster *kops.Cluster) (fi.Cloud, error) {
 			}
 
 			var zoneNames []string
-			for _, subnet := range cluster.Spec.Subnets {
+			for _, subnet := range cluster.Spec.Networking.Subnets {
 				zoneNames = append(zoneNames, subnet.Zone)
 			}
 			err = awsup.ValidateZones(zoneNames, awsCloud)
@@ -100,7 +101,7 @@ func BuildCloud(cluster *kops.Cluster) (fi.Cloud, error) {
 			// for development purposes we're going to assume
 			// single region setups for DO. Reconsider this logic
 			// when setting up multi-region kubernetes clusters on DO
-			region := cluster.Spec.Subnets[0].Zone
+			region := cluster.Spec.Networking.Subnets[0].Zone
 			doCloud, err := do.NewDOCloud(region)
 			if err != nil {
 				return nil, fmt.Errorf("error initializing digitalocean cloud: %s", err)
@@ -126,13 +127,12 @@ func BuildCloud(cluster *kops.Cluster) (fi.Cloud, error) {
 
 	case kops.CloudProviderOpenstack:
 		{
-			cloudTags := map[string]string{openstack.TagClusterName: cluster.ObjectMeta.Name}
-			osc, err := openstack.NewOpenstackCloud(cloudTags, &cluster.Spec, "build-cloud")
+			osc, err := openstack.NewOpenstackCloud(cluster, "build-cloud")
 			if err != nil {
 				return nil, err
 			}
 			var zoneNames []string
-			for _, subnet := range cluster.Spec.Subnets {
+			for _, subnet := range cluster.Spec.Networking.Subnets {
 				if !fi.ArrayContains(zoneNames, subnet.Zone) {
 					zoneNames = append(zoneNames, subnet.Zone)
 				}
@@ -143,7 +143,7 @@ func BuildCloud(cluster *kops.Cluster) (fi.Cloud, error) {
 
 	case kops.CloudProviderAzure:
 		{
-			for _, subnet := range cluster.Spec.Subnets {
+			for _, subnet := range cluster.Spec.Networking.Subnets {
 				if subnet.Region != "" {
 					region = subnet.Region
 				}
@@ -161,6 +161,17 @@ func BuildCloud(cluster *kops.Cluster) (fi.Cloud, error) {
 
 			cloud = azureCloud
 		}
+	case kops.CloudProviderScaleway:
+		{
+			cloudTags := map[string]string{scaleway.TagClusterName: cluster.ObjectMeta.Name}
+
+			scwCloud, err := scaleway.NewScwCloud(cloudTags)
+			if err != nil {
+				return nil, fmt.Errorf("error initializing scaleway cloud: %s", err)
+			}
+
+			cloud = scwCloud
+		}
 	default:
 		return nil, fmt.Errorf("unknown CloudProvider %q", cluster.Spec.GetCloudProvider())
 	}
@@ -195,7 +206,7 @@ func FindDNSHostedZone(dns dnsprovider.Interface, clusterDNSName string, dnsType
 				hostedZone := awsZone.Route53HostedZone()
 				if hostedZone.Config != nil {
 					zoneDNSType := kops.DNSTypePublic
-					if fi.BoolValue(hostedZone.Config.PrivateZone) {
+					if fi.ValueOf(hostedZone.Config.PrivateZone) {
 						zoneDNSType = kops.DNSTypePrivate
 					}
 					if zoneDNSType != dnsType {
